@@ -14,6 +14,7 @@ program draw
   integer, dimension(1), parameter :: lidx=(/5/), ltyp=(/1/)
   integer, dimension(1), parameter :: pidx=(/9/), ptyp=(/11/)
   real, dimension(1), parameter :: psiz=(/0.06/)
+  character(70), parameter :: FONTNAME='Nimbus Sans L Bold 12'
 
   integer :: i, j, k
   integer :: nx, ny, nl
@@ -58,7 +59,8 @@ program draw
   allocate(val3(nx,ny))
   allocate(val4(nx,ny))
 
-  call SGISET('IFONT',2 )
+  call SGISET( 'IFONT', 1 )
+  call SWLSET( 'LSYSFNT', .true. )
   call UZFACT( 0.6 )
   call GLLSET('LMISS',.TRUE.)
   call DclSetParm( 'ENABLE_CONTOUR_MESSAGE', .false. )
@@ -160,6 +162,8 @@ write(*,*) "draw", trim(draw_title)
 
   call DclOpenGraphics(IWS)
 
+  CALL SWCSET('FONTNAME', FONTNAME)
+
   if(fig_type==1)then
      if(txtname/='')then
      call Dcl_2D_cont_shade( trim(draw_title),  &
