@@ -232,12 +232,16 @@ program adjust_2d
      call grad_2d( ini_x, ini_y, old_v, dvdx, dvdy )
 
      if(regist_flag(1:1)=='o')then
-        call laplacian_1d( ini_x, old_h, dh2dx )
-        call laplacian_1d( ini_x, old_u, du2dx )
-        call laplacian_1d( ini_x, old_v, dv2dx )
-        call laplacian_1d( ini_y, old_h, dh2dy )
-        call laplacian_1d( ini_y, old_u, du2dy )
-        call laplacian_1d( ini_y, old_v, dv2dy )
+        do j=1,ny
+           call laplacian_1d( ini_x, old_h(:,j), dh2dx(:,j) )
+           call laplacian_1d( ini_x, old_u(:,j), du2dx(:,j) )
+           call laplacian_1d( ini_x, old_v(:,j), dv2dx(:,j) )
+        end do
+        do i=1,nx
+           call laplacian_1d( ini_y, old_h(i,:), dh2dy(i,:) )
+           call laplacian_1d( ini_y, old_u(i,:), du2dy(i,:) )
+           call laplacian_1d( ini_y, old_v(i,:), dv2dy(i,:) )
+        end do
      end if
 
      do j=1,ny
