@@ -3,13 +3,13 @@ program sound_2d
 ! ꥹȺκݤ 00Z ǻϤޤ, 00Z ǽ褦˺뤳.
 ! ­ʤʬ unknown 䤦.
 
-  use dcl
-  use Dcl_Automatic
   use file_operate
   use basis
   use Statistics
   use Thermo_Function
   use Max_Min
+  use dcl
+  use Dcl_Automatic
 
   implicit none
 
@@ -25,6 +25,7 @@ program sound_2d
   integer :: i_counter_c  ! 󥿡
   integer :: snum, cnum  ! 顼ο
   integer :: cont_flag, shade_flag  ! 顼, ѥե饰ѿ
+  integer :: cmap  ! 顼ޥå
   integer :: izmin, izmax
   integer, allocatable, dimension(:) :: year_v    ! ǯ
   integer, allocatable, dimension(:) :: month_v   ! 
@@ -34,6 +35,8 @@ program sound_2d
   integer, allocatable, dimension(:) :: i_flag  ! 
   integer, allocatable, dimension(:) :: o_flag  ! 
   integer, allocatable, dimension(:) :: c_flag  ! 
+  integer :: fixsn(100)  ! 顼ʪ̤б륫顼ޥå
+
 !-- tmp
   integer :: nttmp, i, j, k, i_undef, i_tmp
 !-- parameter
@@ -60,29 +63,32 @@ program sound_2d
   real, allocatable, dimension(:,:,:) :: val_draw   ! ѿ
   real :: undef
   real :: conv_undef
-  real :: ymin, ymax
+  real :: ymin, ymax, vx_new(2), vy_new(2)
   real :: unitfactv(2)
+  real :: fixs(100)  ! 顼ʪ
+  !  fixs(snum+1), fixsn(snum+2)  fixsn(1), fixsn(snum+2) ǾΥ顼
+
 !-- tmp
   real, dimension(2) :: pt_tmp, ept_tmp, sept_tmp, rh_tmp, s_int, c_int
 
 !-- character
-  character(80) :: flist         ! եꥹ̾
-  character(80) :: conv_dat      ! sound_1d ǽϤήѥ᡼ǡ
-  character(80) :: title_txt     ! ȥ̾
+  character(1000) :: flist         ! եꥹ̾
+  character(1000) :: conv_dat      ! sound_1d ǽϤήѥ᡼ǡ
+  character(1000) :: title_txt     ! ȥ̾
   character(10) :: cont_val      ! ѿ̾
   character(10) :: shade_val     ! 顼ѿ̾
   character(10) :: conv_list     ! ǡե饰
-  character(80), allocatable, dimension(:,:) :: fname  ! ե̾
-  character(20), allocatable, dimension(:,:) :: val_w  ! ƥȥǡ
+  character(1000), allocatable, dimension(:,:) :: fname  ! ե̾
+  character(1000), allocatable, dimension(:,:) :: val_w  ! ƥȥǡ
   character(70) :: sysfont
   character(10) :: unitval     ! value of unit vector [m/s]
   character(20) :: unititle   ! unit vector title
 !-- tmp
-  character(80) :: tmp_c
+  character(1000) :: tmp_c
 
 !-- logical
   logical :: vec_val       ! ѿ̾
-  logical :: fflag
+  logical :: fflag, fixs_flag
 
 !-- type
   type(dtime) :: start_day, end_day
@@ -90,10 +96,10 @@ program sound_2d
 
 !-- namelist reading
   namelist /input /flist, conv_dat, conv_list, conv_undef, dz, z_bot,  &
-  &                z_top, iz_ref, IWS, title_txt,  &
+  &                z_top, iz_ref, IWS, title_txt, cmap,  &
   &                cmin, cmax, smin, smax, cont_val, shade_val,  &
   &                vec_val, cnum, snum, undef, sysfont, ntnum, nznum,  &
-  &                unitval
+  &                unitval, fixs_flag, fixs, fixsn
   read(5,nml=input)
 
   fflag=.false.
@@ -353,8 +359,18 @@ program sound_2d
 
 !-- DCL part
 !-- ޤ, -
-  call color_setting( snum, s_int, col_min=15, col_max=85,  &
-  &                   min_tab=10999, max_tab=99999 )
+  if(fixs_flag.eqv..true.)then
+call sgscmn( cmap )
+     call color_setting( snum, s_int,  &
+  &                      min_tab=fixsn(1), max_tab=fixsn(snum+2),  &
+  &                      col_min=fixsn(1), col_max=fixsn(snum+2),  &
+  &                      col_tab=cmap,  &
+  &                      val_spec=fixs(1:snum+1),  &
+  &                      col_spec=fixsn(2:snum+1) )
+  else
+     call color_setting( snum, s_int, col_min=15, col_max=85,  &
+  &                      col_tab=cmap, min_tab=10999, max_tab=99999 )
+  end if
 
   call DclOpenGraphics(IWS)
 
@@ -371,7 +387,7 @@ program sound_2d
   &       c_int, s_int,  &
   &       (/'            ', 'altitude (m)'/), stime, days, (/'(f6.1)', '(f6.1)'/),  &
   &       viewx_int=vxint, viewy_int=vyint,  &
-  &       c_num=(/cnum, snum/), trigleg='a' )
+  &       c_num=(/cnum, snum/), no_tone=.true. )
   else
      call Dcl_2D_Cont_Shade_vec_Calendar( trim(title_txt),  &
   &       time, z(izmin:izmax),  &
@@ -382,12 +398,32 @@ program sound_2d
   &       (/'            ', 'altitude (m)'/), stime, days,  &
   &       (/'(f6.1)', '(f6.1)'/),  &
   &       viewx_int=vxint, viewy_int=vyint,  &
-  &       c_num=(/cnum, snum/), trigleg='a',  &
+  &       c_num=(/cnum, snum/), no_tone=.true.,  &
   &       unitv=.true., vfact=unitfactv, unit_fact=unitfact,  &
   &       unit_fact_sign=.false.,  &
   &       unit_title=(/trim(adjustl(unititle)), '                    '/) )
   end if
 
+  call DclSetParm( "GRAPH:LCLIP", .true. )
+  call DclDrawMarker( (/0.0/), (/0.0/) )
+  CALL SGQVPT( vx_new(1), vx_new(2), vy_new(1), vy_new(2) )
+  call DclSetParm( "GRAPH:LCLIP", .false. )
+  if(fixs_flag.eqv..true.)then
+     call tone_bar( snum, s_int,  &
+  &                 (/vx_new(2)+0.025, vx_new(2)+0.05/),  &
+  &                 (/vy_new(1)+0.05, vy_new(2)/),  &
+  &                 '(f6.1)', col_mem_num=10,  &
+  &                 trigle='a', col_spec=fixs(1:snum+1),  &
+  &                 val_spec=fixsn(2:snum+1) )
+  else
+     call tone_bar( snum, s_int,  &
+  &                 (/vx_new(2)+0.025, vx_new(2)+0.05/),  &
+  &                 (/vy_new(1)+0.05, vy_new(2)/),  &
+  &                 '(f6.1)', col_mem_num=10,  &
+  &                 trigle='a' )
+  end if
+  call DclSetParm( "GRAPH:LCLIP", .true. )
+
 !-- ʹ, ήѥ᡼ѿλǡ񤭽Ф
 
   deallocate(fname)
