@@ -14,7 +14,7 @@ program fft_test
   integer, dimension(5) :: prim
 
   real :: period
-  real, allocatable :: sp(:,:)
+  real, allocatable :: sp(:,:), ren(:,:)
   real, allocatable :: val(:,:)
 
   complex, allocatable :: co(:,:)
@@ -50,6 +50,7 @@ write(*,*) "nl check", nl
 write(*,*) "nl check", nl
      allocate(cval(na,nl))
      allocate(val(nl,na))
+     allocate(ren(nl,na))
 
      call read_file_text( trim(fname), na, nl, cval )
 
@@ -69,11 +70,12 @@ write(*,*) "nl check", nl
      nl=100
 
      allocate(val(nl,na))
+     allocate(ren(nl,na))
 
      do i=1,nl
-        val(i,1)=sin(2.0*pi*(real(i-1)/real(nl-1)))
-        val(i,2)=val(i,1)+sin(4.0*pi*(real(i-1)/real(nl-1)))
-        val(i,3)=val(i,1)+val(i,2)+sin(6.0*pi*(real(i-1)/real(nl-1)))
+        val(i,1)=1.0+sin(2.0*pi*(real(i-1)/real(nl)))
+        val(i,2)=1.0+sin(4.0*pi*(real(i-1)/real(nl)))
+        val(i,3)=1.0+sin(6.0*pi*(real(i-1)/real(nl)))
      end do
 
   end if
@@ -104,16 +106,22 @@ write(*,*) "nl check", nl
 
 
   do j=1,na
-     call r2c_ffttp_1d( nl, val(1:nl,j), co(1:nl,j),  &
+     call r2c_ffttp_1d( nl, val(1:nl,j), co(1:nl/2,j),  &
   &                     prim='o', prim_fact=prim,  &
   &                     omega_fix=omegar, omegan_fix=omeganr )
-!     call c2r_ffttp_1d( nl, co, ren(1:nl,j), prim='o', prim_fact=prim,  &
-!  &                     omega_fix=omegai, omegan_fix=omegani )
+     call c2r_ffttp_1d( nl, co(1:nl/2,j), ren(1:nl,j), prim='o',  &
+  &                     prim_fact=prim,  &
+  &                     omega_fix=omegai, omegan_fix=omegani )
      do i=2,nl/2
         sp(i,j)=abs(co(i,j))
      end do
-     sp(1,j)=abs(real(co(1,j)))
-     sp(nl/2+1,j)=abs(aimag(co(1,j)))
+     sp(1,j)=abs(co(1,j))
+!     sp(1,j)=abs(real(co(1,j)))
+!     sp(nl/2+1,j)=abs(aimag(co(1,j)))
+  end do
+
+  do i=1,nl
+     write(*,*) val(i,1), ren(i,1), val(i,2), ren(i,2), val(i,3), ren(i,3)
   end do
 
   write(*,*) "### Finished calculating."
@@ -146,7 +154,7 @@ write(*,*) "check a format", trim(fom)
 
      write(11,trim(fom)) 0.0, 0.0, period, (sp(1,i),i=1,na)
 
-     do j=2,nl/2+1
+     do j=2,nl/2
         write(11,trim(fom)) real(j-1), real(j-1)/period, period/real(j-1),  &
   &                         (sp(j,i),i=1,na)
      end do
