@@ -2,8 +2,8 @@
 ! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 
-module Algebra   ! 黻˹Ԥ⥸塼
-! ͭͷ׻, 黻, ٥ȥ黻˹Ԥ.
+module Algebra   ! 代数演算を主に行うモジュール
+! 固有値計算, 行列演算, ベクトル演算を主に行う.
 
   use Basis
 
@@ -59,14 +59,14 @@ end interface vec_prod_3d
 
 contains
 
-subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
-  ! ֳ֤Ǥ׻ǽǤ뤬, ٤ݾڤʤ.
+subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 次元台形積分
+  ! 不等間隔でも計算可能であるが, 精度は保証しない.
   implicit none
-  real, intent(in) :: bot  ! ʬֺü
-  real, intent(in) :: top  ! ʬֱü
-  real, intent(in) :: x(:)  ! ʬѿ
-  real, intent(in) :: y(size(x))  ! ʬؿ
-  real, intent(inout) :: res  ! ʬʬ
+  real, intent(in) :: bot  ! 積分区間左端
+  real, intent(in) :: top  ! 積分区間右端
+  real, intent(in) :: x(:)  ! 積分変数
+  real, intent(in) :: y(size(x))  ! 非積分関数
+  real, intent(inout) :: res  ! 台形積分の積分値
   real, intent(in), optional :: undeff
   integer :: i, nx, i_bot, i_top
   real :: y_bot, y_top
@@ -80,22 +80,22 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
 
   res=0.0
 
-!-- bot < top ǤʤХ顼
+!-- bot < top でなければエラー
   if(bot>top)then
      write(*,*) "#### ERROR (algebra:rectangle_int) ####"
      write(*,*) "integrated interval must be bot < top. STOP"
      stop
   end if
 
-!-- ʲʬ
-!-- ºݤˤ, ʬ˺Ƕ᤹
+!-- 以下で積分域を決定
+!-- 実際には, 積分境界に最近する点
 
   if(present(undeff))then
      do i=1,nx
         if(x(i)/=undeff)then
            if(x(i)>bot)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the bot in the x(i)."  ! ΤȤ, i_bot=1ȤƤƤ, x(1)=bot ʤΤ, ;ʬ׻ϥȤʤƶϤʤ.
+              write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
            end if
            exit
         end if
@@ -105,7 +105,7 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
         if(x(i)/=undeff)then
            if(x(i)<top)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the top in the x(i)."  ! ΤȤ, i_top=nx ȤƤ, x(nx)=top ʤΤ, ;ʬ׻ϥȤʤ.
+              write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
            end if
            exit
         end if
@@ -113,7 +113,7 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
 
      do i=1,nx
         if(x(i)/=undeff)then
-           if(x(i)>=bot)then  ! i_bot  bot - top κǤ bot ˶Ťʻ
+           if(x(i)>=bot)then  ! i_bot は bot - top 内の最も bot に近づく格子
               i_bot=i
               exit
            end if
@@ -122,7 +122,7 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
 
      do i=nx,1,-1
         if(x(i)/=undeff)then
-           if(x(i)<=top)then  ! i_top  bot - top κǤ top ˶Ťʻ
+           if(x(i)<=top)then  ! i_top は bot - top 内の最も top に近づく格子
               i_top=i
               exit
            end if
@@ -133,22 +133,22 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
 
      if(x(1)>bot)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the bot in the x(i)."  ! ΤȤ, i_bot=1ȤƤƤ, x(1)=bot ʤΤ, ;ʬ׻ϥȤʤƶϤʤ.
+        write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
      end if
      if(x(nx)<top)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the top in the x(i)."  ! ΤȤ, i_top=nx ȤƤ, x(nx)=top ʤΤ, ;ʬ׻ϥȤʤ.
+        write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
      end if
 
      do i=1,nx
-        if(x(i)>=bot)then  ! i_bot  bot - top κǤ bot ˶Ťʻ
+        if(x(i)>=bot)then  ! i_bot は bot - top 内の最も bot に近づく格子
            i_bot=i
            exit
         end if
      end do
 
      do i=nx,1,-1
-        if(x(i)<=top)then  ! i_top  bot - top κǤ top ˶Ťʻ
+        if(x(i)<=top)then  ! i_top は bot - top 内の最も top に近づく格子
            i_top=i
            exit
         end if
@@ -156,17 +156,17 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
 
   end if
 
-!-- ʲǳʻҤƤϤޤʤʬޤ䴰
+!-- 以下で格子に当てはまらない部分を内挿で補完
   if(present(undeff))then
      if(i_bot/=1)then
         if(y(i_bot)/=undeff.and.y(i_bot-1)/=undeff.and.x(i_bot)/=x(i_bot-1))then
            y_bot=y(i_bot-1)  &
      &           +((y(i_bot)-y(i_bot-1))/(x(i_bot)-x(i_bot-1)))*(bot-x(i_bot-1))
         else
-           y_bot=-y(i_bot)  ! Ǹʬǥˤ뤿
+           y_bot=-y(i_bot)  ! 最後の積分でゼロにするための措置
         end if
      else
-        y_bot=-y(i_bot)  ! Ǹʬǥˤ뤿
+        y_bot=-y(i_bot)  ! 最後の積分でゼロにするための措置
      end if
      if(i_top/=nx)then
         if(y(i_top)/=undeff.and.y(i_top+1)/=undeff.and.x(i_top+1)/=x(i_top))then
@@ -176,39 +176,39 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 ʬ
            y_top=-y(i_top)
         end if
      else
-        y_top=-y(i_top)  ! Ǹʬǥˤ뤿
+        y_top=-y(i_top)  ! 最後の積分でゼロにするための措置
      end if
   else
      if(i_bot/=1)then
         y_bot=y(i_bot-1)  &
      &        +((y(i_bot)-y(i_bot-1))/(x(i_bot)-x(i_bot-1)))*(bot-x(i_bot-1))
      else
-        y_bot=-y(i_bot)  ! Ǹʬǥˤ뤿
+        y_bot=-y(i_bot)  ! 最後の積分でゼロにするための措置
      end if
      if(i_top/=nx)then
         y_top=y(i_top)  &
      &        +((y(i_top+1)-y(i_top))/(x(i_top+1)-x(i_top)))*(x(i_top+1)-top)
      else
-        y_top=-y(i_top)  ! Ǹʬǥˤ뤿
+        y_top=-y(i_top)  ! 最後の積分でゼロにするための措置
      end if
   end if
 
-  if(i_bot<i_top)then  ! ʬ˳ʻҤ 2 İʾ夢Ȥ
+  if(i_bot<i_top)then  ! 積分区間内に格子が 2 つ以上あるとき
 
      if(present(undeff))then
-        res=res+0.5*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
+        res=res+0.5*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! 下端の余り短冊分
         do i=i_bot,i_top-1
            if(y(i+1)/=undeff.and.y(i)/=undeff)then
-              res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
+              res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! 通常の短冊
            end if
         end do
-        res=res+0.5*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
+        res=res+0.5*(top-x(i_top))*(y_top+y(i_top))  ! 上端の余りのみ
      else
-        res=res+0.5*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
+        res=res+0.5*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! 下端の余り短冊分
         do i=i_bot,i_top-1
-           res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
+           res=res+0.5*(x(i+1)-x(i))*(y(i+1)+y(i))  ! 通常の短冊
         end do
-        res=res+0.5*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
+        res=res+0.5*(top-x(i_top))*(y_top+y(i_top))  ! 上端の余りのみ
      end if
   else
      if(present(undeff))then
@@ -229,14 +229,14 @@ end subroutine rectangle_intf
 !------------------------------------------
 !------------------------------------------
 
-subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
-  ! ֳ֤Ǥ׻ǽǤ뤬, ٤ݾڤʤ.
+subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 次元台形積分
+  ! 不等間隔でも計算可能であるが, 精度は保証しない.
   implicit none
-  double precision, intent(in) :: bot  ! ʬֺü
-  double precision, intent(in) :: top  ! ʬֱü
-  double precision, intent(in) :: x(:)  ! ʬѿ
-  double precision, intent(in) :: y(size(x))  ! ʬؿ
-  double precision, intent(inout) :: res  ! ʬʬ
+  double precision, intent(in) :: bot  ! 積分区間左端
+  double precision, intent(in) :: top  ! 積分区間右端
+  double precision, intent(in) :: x(:)  ! 積分変数
+  double precision, intent(in) :: y(size(x))  ! 非積分関数
+  double precision, intent(inout) :: res  ! 台形積分の積分値
   double precision, intent(in), optional :: undeff
   integer :: i, nx, i_bot, i_top
   double precision :: y_bot, y_top
@@ -250,22 +250,22 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
 
   res=0.0d0
 
-!-- bot < top ǤʤХ顼
+!-- bot < top でなければエラー
   if(bot>top)then
      write(*,*) "#### ERROR (algebra:rectangle_int) ####"
      write(*,*) "integrated interval must be bot < top. STOP"
      stop
   end if
 
-!-- ʲʬ
-!-- ºݤˤ, ʬ˺Ƕ᤹
+!-- 以下で積分域を決定
+!-- 実際には, 積分境界に最近する点
 
   if(present(undeff))then
      do i=1,nx
         if(x(i)/=undeff)then
            if(x(i)>bot)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the bot in the x(i)."  ! ΤȤ, i_bot=1ȤƤƤ, x(1)=bot ʤΤ, ;ʬ׻ϥȤʤƶϤʤ.
+              write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
            end if
            exit
         end if
@@ -275,7 +275,7 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
         if(x(i)/=undeff)then
            if(x(i)<top)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the top in the x(i)."  ! ΤȤ, i_top=nx ȤƤ, x(nx)=top ʤΤ, ;ʬ׻ϥȤʤ.
+              write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
            end if
            exit
         end if
@@ -283,7 +283,7 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
 
      do i=1,nx
         if(x(i)/=undeff)then
-           if(x(i)>=bot)then  ! i_bot  bot - top κǤ bot ˶Ťʻ
+           if(x(i)>=bot)then  ! i_bot は bot - top 内の最も bot に近づく格子
               i_bot=i
               exit
            end if
@@ -292,7 +292,7 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
 
      do i=nx,1,-1
         if(x(i)/=undeff)then
-           if(x(i)<=top)then  ! i_top  bot - top κǤ top ˶Ťʻ
+           if(x(i)<=top)then  ! i_top は bot - top 内の最も top に近づく格子
               i_top=i
               exit
            end if
@@ -303,22 +303,22 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
 
      if(x(1)>bot)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the bot in the x(i)."  ! ΤȤ, i_bot=1ȤƤƤ, x(1)=bot ʤΤ, ;ʬ׻ϥȤʤƶϤʤ.
+        write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
      end if
      if(x(nx)<top)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the top in the x(i)."  ! ΤȤ, i_top=nx ȤƤ, x(nx)=top ʤΤ, ;ʬ׻ϥȤʤ.
+        write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
      end if
 
      do i=1,nx
-        if(x(i)>=bot)then  ! i_bot  bot - top κǤ bot ˶Ťʻ
+        if(x(i)>=bot)then  ! i_bot は bot - top 内の最も bot に近づく格子
            i_bot=i
            exit
         end if
      end do
 
      do i=nx,1,-1
-        if(x(i)<=top)then  ! i_top  bot - top κǤ top ˶Ťʻ
+        if(x(i)<=top)then  ! i_top は bot - top 内の最も top に近づく格子
            i_top=i
            exit
         end if
@@ -326,17 +326,17 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
 
   end if
 
-!-- ʲǳʻҤƤϤޤʤʬޤ䴰
+!-- 以下で格子に当てはまらない部分を内挿で補完
   if(present(undeff))then
      if(i_bot/=1)then
         if(y(i_bot)/=undeff.and.y(i_bot-1)/=undeff.and.x(i_bot)/=x(i_bot-1))then
            y_bot=y(i_bot-1)  &
      &           +((y(i_bot)-y(i_bot-1))/(x(i_bot)-x(i_bot-1)))*(bot-x(i_bot-1))
         else
-           y_bot=-y(i_bot)  ! Ǹʬǥˤ뤿
+           y_bot=-y(i_bot)  ! 最後の積分でゼロにするための措置
         end if
      else
-        y_bot=-y(i_bot)  ! Ǹʬǥˤ뤿
+        y_bot=-y(i_bot)  ! 最後の積分でゼロにするための措置
      end if
      if(i_top/=nx)then
         if(y(i_top)/=undeff.and.y(i_top+1)/=undeff.and.x(i_top+1)/=x(i_top))then
@@ -346,39 +346,39 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 ʬ
            y_top=-y(i_top)
         end if
      else
-        y_top=-y(i_top)  ! Ǹʬǥˤ뤿
+        y_top=-y(i_top)  ! 最後の積分でゼロにするための措置
      end if
   else
      if(i_bot/=1)then
         y_bot=y(i_bot-1)  &
      &        +((y(i_bot)-y(i_bot-1))/(x(i_bot)-x(i_bot-1)))*(bot-x(i_bot-1))
      else
-        y_bot=-y(i_bot)  ! Ǹʬǥˤ뤿
+        y_bot=-y(i_bot)  ! 最後の積分でゼロにするための措置
      end if
      if(i_top/=nx)then
         y_top=y(i_top)  &
      &        +((y(i_top+1)-y(i_top))/(x(i_top+1)-x(i_top)))*(x(i_top+1)-top)
      else
-        y_top=-y(i_top)  ! Ǹʬǥˤ뤿
+        y_top=-y(i_top)  ! 最後の積分でゼロにするための措置
      end if
   end if
 
-  if(i_bot<i_top)then  ! ʬ˳ʻҤ 2 İʾ夢Ȥ
+  if(i_bot<i_top)then  ! 積分区間内に格子が 2 つ以上あるとき
 
      if(present(undeff))then
-        res=res+0.5d0*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
+        res=res+0.5d0*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! 下端の余り短冊分
         do i=i_bot,i_top-1
            if(y(i+1)/=undeff.and.y(i)/=undeff)then
-              res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
+              res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! 通常の短冊
            end if
         end do
-        res=res+0.5d0*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
+        res=res+0.5d0*(top-x(i_top))*(y_top+y(i_top))  ! 上端の余りのみ
      else
-        res=res+0.5d0*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! ü;ûʬ
+        res=res+0.5d0*(x(i_bot)-bot)*(y(i_bot)+y_bot)  ! 下端の余り短冊分
         do i=i_bot,i_top-1
-           res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! ̾û
+           res=res+0.5d0*(x(i+1)-x(i))*(y(i+1)+y(i))  ! 通常の短冊
         end do
-        res=res+0.5d0*(top-x(i_top))*(y_top+y(i_top))  ! ü;Τ
+        res=res+0.5d0*(top-x(i_top))*(y_top+y(i_top))  ! 上端の余りのみ
      end if
   else
      if(present(undeff))then
@@ -400,21 +400,21 @@ end subroutine rectangle_intd
 !------------------------------------------
 
 subroutine rectangle_int_2d( x, y, z, botx, topx, boty, topy, res, undeff )
-  ! 2 ʬ
-  ! ֳ֤Ǥ׻ǽǤ뤬, ٤ݾڤʤ.
-  ! ʤ, ʬ롼ʬ֤֤˰¸ʤʬˤΤбƤ.
-  ! Ĥޤ, \int^{y_2}_{y_1}{\int^{x_2}_{x_1}{f(x,y)dxdy}}
-  ! ׻Ȥ, y_1, y_2, x_1, x_2 줾 x, y ˰¸ʤȤǤ.
+  ! 2 次元台形積分
+  ! 不等間隔でも計算可能であるが, 精度は保証しない.
+  ! なお, 本積分ルーチンは積分区間が空間に依存しない矩形積分にのみ対応している.
+  ! つまり, \int^{y_2}_{y_1}{\int^{x_2}_{x_1}{f(x,y)dxdy}}
+  ! を計算するときの, y_1, y_2, x_1, x_2 がそれぞれ x, y に依存しないことが条件である.
 
   implicit none
-  real, intent(in) :: x(:)  ! ʬѿ 1
-  real, intent(in) :: y(:)  ! ʬѿ 2
-  real, intent(in) :: botx  ! ʬ 1 ü
-  real, intent(in) :: topx  ! ʬ 1 ü
-  real, intent(in) :: boty  ! ʬ 2 ü
-  real, intent(in) :: topy  ! ʬ 2 ü
-  real, intent(in) :: z(size(x),size(y))  ! ʬؿ
-  real, intent(inout) :: res  ! ʬʬ
+  real, intent(in) :: x(:)  ! 積分変数 1
+  real, intent(in) :: y(:)  ! 積分変数 2
+  real, intent(in) :: botx  ! 積分区間 1 左端
+  real, intent(in) :: topx  ! 積分区間 1 右端
+  real, intent(in) :: boty  ! 積分区間 2 左端
+  real, intent(in) :: topy  ! 積分区間 2 右端
+  real, intent(in) :: z(size(x),size(y))  ! 非積分関数
+  real, intent(inout) :: res  ! 台形積分の積分値
   real, intent(in), optional :: undeff
   integer :: i, j, nx, ny, i_bot, i_top
   real :: resy(size(y))
@@ -430,37 +430,37 @@ subroutine rectangle_int_2d( x, y, z, botx, topx, boty, topy, res, undeff )
   resy=0.0
   res=0.0
 
-!-- ʲʬ
-!-- ºݤˤ, ʬ˺Ƕ᤹
+!-- 以下で積分域を決定
+!-- 実際には, 積分境界に最近する点
 
   if(y(1)>boty)then
      write(*,*) "#### WARNING ####"
-     write(*,*) "there is NOT the bot in the y(i)."  ! ΤȤ, i_bot=1ȤƤƤ, x(1)=bot ʤΤ, ;ʬ׻ϥȤʤƶϤʤ.
+     write(*,*) "there is NOT the bot in the y(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
   end if
   if(y(ny)<topy)then
      write(*,*) "#### WARNING ####"
-     write(*,*) "there is NOT the top in the y(i)."  ! ΤȤ, i_top=nx ȤƤ, x(nx)=top ʤΤ, ;ʬ׻ϥȤʤ.
+     write(*,*) "there is NOT the top in the y(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
   end if
 
   do i=1,ny
-     if(y(i)>=boty)then  ! i_bot  bot - top κǤ bot ˶Ťʻ
+     if(y(i)>=boty)then  ! i_bot は bot - top 内の最も bot に近づく格子
         i_bot=i
         exit
      end if
   end do
 
-  if(i_bot>1)then  ! ΰ 1 ʻҳ¦ꤷƤ.
+  if(i_bot>1)then  ! 領域の 1 格子外側を指定しておく.
      i_bot=i_bot-1
   end if
 
   do i=ny,1,-1
-     if(y(i)<=topy)then  ! i_top  bot - top κǤ top ˶Ťʻ
+     if(y(i)<=topy)then  ! i_top は bot - top 内の最も top に近づく格子
         i_top=i
         exit
      end if
   end do
 
-  if(i_top<ny)then  ! ΰ 1 ʻҳ¦ꤷƤ.
+  if(i_top<ny)then  ! 領域の 1 格子外側を指定しておく.
      i_top=i_top+1
   end if
 
@@ -486,11 +486,11 @@ end subroutine rectangle_int_2d
 !------------------------------------------
 
 subroutine abst_2df(x,y,dis)
-  ! 2 ٥ȥͤ׻롼
+  ! 2 次元ベクトルの絶対値を計算するルーチン
   implicit none
-  real, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
-  real, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  real, intent(inout) :: dis(size(x,1),size(x,2))  ! Ǥͥ٥ȥ
+  real, intent(in) :: x(:,:)  ! x 方向のベクトル成分
+  real, intent(in) :: y(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  real, intent(inout) :: dis(size(x,1),size(x,2))  ! 各点での絶対値ベクトル
   integer :: i, j, nx, ny
 
   nx=size(x,1)
@@ -515,11 +515,11 @@ end subroutine abst_2df
 !------------------------------------------
 
 subroutine abst_2dd(x,y,dis)
-  ! 2 ٥ȥͤ׻롼
+  ! 2 次元ベクトルの絶対値を計算するルーチン
   implicit none
-  double precision, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
-  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  double precision, intent(inout) :: dis(size(x,1),size(x,2))  ! Ǥͥ٥ȥ
+  double precision, intent(in) :: x(:,:)  ! x 方向のベクトル成分
+  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  double precision, intent(inout) :: dis(size(x,1),size(x,2))  ! 各点での絶対値ベクトル
   integer :: i, j, nx, ny
 
   nx=size(x,1)
@@ -543,13 +543,13 @@ end subroutine abst_2dd
 !------------------------------------------
 !------------------------------------------
 
-subroutine abst_3df(x,y,z,dis)  ! 3 ٥ȥͤ׻롼
-  ! Ĵ뤳Ȥˤ, 2 Ǥη׻ǽ.
+subroutine abst_3df(x,y,z,dis)  ! 3 次元ベクトルの絶対値を計算するルーチン
+  ! 配列数を調整することにより, 2 次元での計算も可能.
   implicit none
-  real, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
-  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  real, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  real, intent(inout) :: dis(size(x,1),size(x,2),size(x,3))  ! Ǥͥ٥ȥ
+  real, intent(in) :: x(:,:,:)  ! x 方向のベクトル成分
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  real, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  real, intent(inout) :: dis(size(x,1),size(x,2),size(x,3))  ! 各点での絶対値ベクトル
   integer :: i, j, k, nx, ny, nz
 
   nx=size(x,1)
@@ -582,13 +582,13 @@ end subroutine abst_3df
 !------------------------------------------
 !------------------------------------------
 
-subroutine abst_3dd(x,y,z,dis)  ! 3 ٥ȥͤ׻롼
-  ! Ĵ뤳Ȥˤ, 2 Ǥη׻ǽ.
+subroutine abst_3dd(x,y,z,dis)  ! 3 次元ベクトルの絶対値を計算するルーチン
+  ! 配列数を調整することにより, 2 次元での計算も可能.
   implicit none
-  double precision, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
-  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  double precision, intent(inout) :: dis(size(x,1),size(x,2),size(x,3))  ! Ǥͥ٥ȥ
+  double precision, intent(in) :: x(:,:,:)  ! x 方向のベクトル成分
+  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  double precision, intent(inout) :: dis(size(x,1),size(x,2),size(x,3))  ! 各点での絶対値ベクトル
   integer :: i, j, k, nx, ny, nz
 
   nx=size(x,1)
@@ -622,16 +622,16 @@ end subroutine abst_3dd
 !------------------------------------------
 
 subroutine calc_radius(xp,yp,zp,x,y,z,rad)
-  ! ֤εΥ׻롼
-  ! Ĵ뤳Ȥˤ, 2 Ǥη׻ǽ.
+  ! ある位置からの距離を計算するルーチン
+  ! 配列数を調整することにより, 2 次元での計算も可能.
   implicit none
-  real, intent(in) :: xp  ! 濴ֺɸ x ʬ
-  real, intent(in) :: yp  ! 濴ֺɸ y ʬ
-  real, intent(in) :: zp  ! 濴ֺɸ z ʬ
-  real, intent(in) :: x(:)  ! x ΰֺɸ
-  real, intent(in) :: y(:)  ! y ΰֺɸ
-  real, intent(in) :: z(:)  ! z ΰֺɸ
-  real, intent(inout) :: rad(size(x),size(y),size(z))  ! Υ
+  real, intent(in) :: xp  ! 中心位置座標の x 成分
+  real, intent(in) :: yp  ! 中心位置座標の y 成分
+  real, intent(in) :: zp  ! 中心位置座標の z 成分
+  real, intent(in) :: x(:)  ! x 方向の位置座標
+  real, intent(in) :: y(:)  ! y 方向の位置座標
+  real, intent(in) :: z(:)  ! z 方向の位置座標
+  real, intent(inout) :: rad(size(x),size(y),size(z))  ! 距離
   integer :: i, j, k, nx, ny, nz
 
   nx=size(x)
@@ -662,15 +662,15 @@ end subroutine calc_radius
 !------------------------------------------
 
 subroutine dot_prod_2df(x,y,u,v,dot,undeff)
-  ! 2٥ȥѷ׻롼
-  ! dot_prod  2 
+  ! 2ベクトルの内積計算ルーチン
+  ! dot_prod の 2 次元版
   implicit none
-  real, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
-  real, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  real, intent(in) :: u(size(x,1),size(x,2))  ! x Υ٥ȥʬ
-  real, intent(in) :: v(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  real, intent(inout) :: dot(size(x,1),size(x,2))  ! 
-  real, intent(in), optional :: undeff        ! ̤
+  real, intent(in) :: x(:,:)  ! x 方向のベクトル成分
+  real, intent(in) :: y(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  real, intent(in) :: u(size(x,1),size(x,2))  ! x 方向のベクトル成分
+  real, intent(in) :: v(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  real, intent(inout) :: dot(size(x,1),size(x,2))  ! 内積
+  real, intent(in), optional :: undeff        ! 未定義値
   integer :: i, j, nx, ny
 
   nx=size(x,1)
@@ -716,15 +716,15 @@ end subroutine dot_prod_2df
 !------------------------------------------
 
 subroutine dot_prod_2dd(x,y,u,v,dot,undeff)
-  ! 2٥ȥѷ׻롼
-  ! dot_prod  2 
+  ! 2ベクトルの内積計算ルーチン
+  ! dot_prod の 2 次元版
   implicit none
-  double precision, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
-  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  double precision, intent(in) :: u(size(x,1),size(x,2))  ! x Υ٥ȥʬ
-  double precision, intent(in) :: v(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  double precision, intent(inout) :: dot(size(x,1),size(x,2))  ! 
-  double precision, intent(in), optional :: undeff        ! ̤
+  double precision, intent(in) :: x(:,:)  ! x 方向のベクトル成分
+  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  double precision, intent(in) :: u(size(x,1),size(x,2))  ! x 方向のベクトル成分
+  double precision, intent(in) :: v(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  double precision, intent(inout) :: dot(size(x,1),size(x,2))  ! 内積
+  double precision, intent(in), optional :: undeff        ! 未定義値
   integer :: i, j, nx, ny
 
   nx=size(x,1)
@@ -770,16 +770,16 @@ end subroutine dot_prod_2dd
 !------------------------------------------
 
 subroutine dot_prod_3df(x,y,z,u,v,w,dot,undeff)
-  ! 2٥ȥѷ׻롼
-  ! פ, 2 ǤѤ׻뤳Ȥǽ
+  ! 2ベクトルの内積計算ルーチン
+  ! 配列を工夫すると, 2 次元での内積を計算することも可能
   implicit none
-  real, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
-  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  real, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  real, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x Υ٥ȥʬ
-  real, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  real, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  real, intent(inout) :: dot(size(x,1),size(x,2),size(x,3))  ! 
+  real, intent(in) :: x(:,:,:)  ! x 方向のベクトル成分
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  real, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  real, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x 方向のベクトル成分
+  real, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  real, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  real, intent(inout) :: dot(size(x,1),size(x,2),size(x,3))  ! 内積
   real, intent(in), optional :: undeff
   integer :: i, j, k, nx, ny, nz
 
@@ -842,16 +842,16 @@ end subroutine dot_prod_3df
 !------------------------------------------
 
 subroutine dot_prod_3dd(x,y,z,u,v,w,dot,undeff)
-  ! 2٥ȥѷ׻롼
-  ! פ, 2 ǤѤ׻뤳Ȥǽ
+  ! 2ベクトルの内積計算ルーチン
+  ! 配列を工夫すると, 2 次元での内積を計算することも可能
   implicit none
-  double precision, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
-  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  double precision, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x Υ٥ȥʬ
-  double precision, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  double precision, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  double precision, intent(inout) :: dot(size(x,1),size(x,2),size(x,3))  ! 
+  double precision, intent(in) :: x(:,:,:)  ! x 方向のベクトル成分
+  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  double precision, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x 方向のベクトル成分
+  double precision, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  double precision, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  double precision, intent(inout) :: dot(size(x,1),size(x,2),size(x,3))  ! 内積
   double precision, intent(in), optional :: undeff
   integer :: i, j, k, nx, ny, nz
 
@@ -914,16 +914,16 @@ end subroutine dot_prod_3dd
 !------------------------------------------
 
 subroutine vec_prod_2df(x,y,u,v,vecz,undeff)
-  ! 2٥ȥγѷ׻롼
-  ! vec_prod  2 
-  ! ѤʤΤ, 2 Ƿ׻, Ѥ 1 ʬʤΤ,
-  ! intent(inout) ΰ 1 ĤʤȤ.
+  ! 2ベクトルの外積計算ルーチン
+  ! vec_prod の 2 次元版
+  ! 外積なので, 2 次元で計算すると, 外積の 1 成分しか現れないので,
+  ! intent(inout) の引数が 1 つしかないことに注意.
   implicit none
-  real, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
-  real, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  real, intent(in) :: u(size(x,1),size(x,2))  ! x Υ٥ȥʬ
-  real, intent(in) :: v(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  real, intent(inout) :: vecz(size(x,1),size(x,2))  ! Ѥľʬ
+  real, intent(in) :: x(:,:)  ! x 方向のベクトル成分
+  real, intent(in) :: y(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  real, intent(in) :: u(size(x,1),size(x,2))  ! x 方向のベクトル成分
+  real, intent(in) :: v(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  real, intent(inout) :: vecz(size(x,1),size(x,2))  ! 外積の直交成分
   real, intent(in), optional :: undeff
   integer :: i, j, nx, ny
 
@@ -970,16 +970,16 @@ end subroutine vec_prod_2df
 !------------------------------------------
 
 subroutine vec_prod_2dd(x,y,u,v,vecz,undeff)
-  ! 2٥ȥγѷ׻롼
-  ! vec_prod  2 
-  ! ѤʤΤ, 2 Ƿ׻, Ѥ 1 ʬʤΤ,
-  ! intent(inout) ΰ 1 ĤʤȤ.
+  ! 2ベクトルの外積計算ルーチン
+  ! vec_prod の 2 次元版
+  ! 外積なので, 2 次元で計算すると, 外積の 1 成分しか現れないので,
+  ! intent(inout) の引数が 1 つしかないことに注意.
   implicit none
-  double precision, intent(in) :: x(:,:)  ! x Υ٥ȥʬ
-  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  double precision, intent(in) :: u(size(x,1),size(x,2))  ! x Υ٥ȥʬ
-  double precision, intent(in) :: v(size(x,1),size(x,2))  ! y Υ٥ȥʬ
-  double precision, intent(inout) :: vecz(size(x,1),size(x,2))  ! Ѥľʬ
+  double precision, intent(in) :: x(:,:)  ! x 方向のベクトル成分
+  double precision, intent(in) :: y(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  double precision, intent(in) :: u(size(x,1),size(x,2))  ! x 方向のベクトル成分
+  double precision, intent(in) :: v(size(x,1),size(x,2))  ! y 方向のベクトル成分
+  double precision, intent(inout) :: vecz(size(x,1),size(x,2))  ! 外積の直交成分
   double precision, intent(in), optional :: undeff
   integer :: i, j, nx, ny
 
@@ -1026,17 +1026,17 @@ end subroutine vec_prod_2dd
 !-----------------------------------------
 
 subroutine vec_prod_3df(x,y,z,u,v,w,vecx,vecy,vecz,undeff)
-  ! 2٥ȥγѷ׻롼
+  ! 2ベクトルの外積計算ルーチン
   implicit none
-  real, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
-  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  real, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  real, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x Υ٥ȥʬ
-  real, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  real, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  real, intent(inout) :: vecx(size(x,1),size(x,2),size(x,3))  ! Ѥ x ʬ
-  real, intent(inout) :: vecy(size(x,1),size(x,2),size(x,3))  ! Ѥ y ʬ
-  real, intent(inout) :: vecz(size(x,1),size(x,2),size(x,3))  ! Ѥ z ʬ
+  real, intent(in) :: x(:,:,:)  ! x 方向のベクトル成分
+  real, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  real, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  real, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x 方向のベクトル成分
+  real, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  real, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  real, intent(inout) :: vecx(size(x,1),size(x,2),size(x,3))  ! 外積の x 成分
+  real, intent(inout) :: vecy(size(x,1),size(x,2),size(x,3))  ! 外積の y 成分
+  real, intent(inout) :: vecz(size(x,1),size(x,2),size(x,3))  ! 外積の z 成分
   real, intent(in), optional :: undeff
   integer :: i, j, k, nx, ny, nz
 
@@ -1110,17 +1110,17 @@ end subroutine vec_prod_3df
 !-----------------------------------------
 
 subroutine vec_prod_3dd(x,y,z,u,v,w,vecx,vecy,vecz,undeff)
-  ! 2٥ȥγѷ׻롼
+  ! 2ベクトルの外積計算ルーチン
   implicit none
-  double precision, intent(in) :: x(:,:,:)  ! x Υ٥ȥʬ
-  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  double precision, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x Υ٥ȥʬ
-  double precision, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y Υ٥ȥʬ
-  double precision, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z Υ٥ȥʬ
-  double precision, intent(inout) :: vecx(size(x,1),size(x,2),size(x,3))  ! Ѥ x ʬ
-  double precision, intent(inout) :: vecy(size(x,1),size(x,2),size(x,3))  ! Ѥ y ʬ
-  double precision, intent(inout) :: vecz(size(x,1),size(x,2),size(x,3))  ! Ѥ z ʬ
+  double precision, intent(in) :: x(:,:,:)  ! x 方向のベクトル成分
+  double precision, intent(in) :: y(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  double precision, intent(in) :: z(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  double precision, intent(in) :: u(size(x,1),size(x,2),size(x,3))  ! x 方向のベクトル成分
+  double precision, intent(in) :: v(size(x,1),size(x,2),size(x,3))  ! y 方向のベクトル成分
+  double precision, intent(in) :: w(size(x,1),size(x,2),size(x,3))  ! z 方向のベクトル成分
+  double precision, intent(inout) :: vecx(size(x,1),size(x,2),size(x,3))  ! 外積の x 成分
+  double precision, intent(inout) :: vecy(size(x,1),size(x,2),size(x,3))  ! 外積の y 成分
+  double precision, intent(inout) :: vecz(size(x,1),size(x,2),size(x,3))  ! 外積の z 成分
   double precision, intent(in), optional :: undeff
   integer :: i, j, k, nx, ny, nz
 
