@@ -2,7 +2,7 @@
 ! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 module Map_Function
-!  Ͽ޺ɸϤˤ뤤餫Ѵؿ
+!  地図座標系におけるいくらかの変換関数
 
 interface ll2rt
   module procedure ll2rt_f, ll2rt_d
@@ -67,21 +67,21 @@ end interface Lambert_coe
 contains
 
 subroutine ll2rt_f( lon0, lat0, lon1, lat1, r, theta )
-! ϵε̺ɸϤˤ, (lon0, lat0) ΰ֤Ȥ (r,\theta) ɸ
-! ŸȤ, (lon1, lat1) ΰ֤ˤΥ r, Ʊ̳ theta 
-! ׻. Υ r ϵ̾α߸̵ΥȤ, theta = 90, 270 deg ̤
-! Ҹ̤̾褦 theta ֤.
-! rt2ll εմؿ, Υ ll2radi ѤФ褤.
-! ϿƤȤƤ, ̿ˡ˳.
+! 地球の球面座標系において, (lon0, lat0) の位置を原点とした (r,\theta) 座標を
+! 展開したとき, (lon1, lat1) の位置における距離 r, 同位角 theta を
+! 計算する. 距離 r は球面上の円弧距離とし, theta = 90, 270 deg が球面の
+! 子午面上を通るように theta は配置される.
+! rt2ll の逆関数, 距離だけ求める場合は ll2radi を用いればよい.
+! 地図投影としては, 正距方位図法に該当する.
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: lon0          ! ˺ɸη [rad]
-  real, intent(in) :: lat0          ! ˺ɸΰ [rad]
-  real, intent(in) :: lon1          ! ׻줿 [rad]
-  real, intent(in) :: lat1          ! ׻줿 [rad]
-  real, intent(inout) :: r          ! lon0 α߸̵Υ [m]
-  real, intent(inout) :: theta      ! lon0 ǤƱ̳ [rad]
+  real, intent(in) :: lon0          ! 極座標原点の経度 [rad]
+  real, intent(in) :: lat0          ! 極座標原点の緯度 [rad]
+  real, intent(in) :: lon1          ! 計算された経度 [rad]
+  real, intent(in) :: lat1          ! 計算された緯度 [rad]
+  real, intent(inout) :: r          ! lon0 からの円弧距離 [m]
+  real, intent(inout) :: theta      ! lon0 での同位角 [rad]
   real :: tmpcos, tmpsin, tmptan
 
   r=ll2radi_f( lon0, lat0, lon1, lat1 )
@@ -124,21 +124,21 @@ end subroutine ll2rt_f
 !-----------------------------------------------
 
 subroutine ll2rt_d( lon0, lat0, lon1, lat1, r, theta )
-! ϵε̺ɸϤˤ, (lon0, lat0) ΰ֤Ȥ (r,\theta) ɸ
-! ŸȤ, (lon1, lat1) ΰ֤ˤΥ r, Ʊ̳ theta 
-! ׻. Υ r ϵ̾α߸̵ΥȤ, theta = 90, 270 deg ̤
-! Ҹ̤̾褦 theta ֤.
-! rt2ll εմؿ, Υ ll2radi ѤФ褤.
-! ϿƤȤƤ, ̿ˡ˳.
+! 地球の球面座標系において, (lon0, lat0) の位置を原点とした (r,\theta) 座標を
+! 展開したとき, (lon1, lat1) の位置における距離 r, 同位角 theta を
+! 計算する. 距離 r は球面上の円弧距離とし, theta = 90, 270 deg が球面の
+! 子午面上を通るように theta は配置される.
+! rt2ll の逆関数, 距離だけ求める場合は ll2radi を用いればよい.
+! 地図投影としては, 正距方位図法に該当する.
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: lon0          ! ˺ɸη [rad]
-  double precision, intent(in) :: lat0          ! ˺ɸΰ [rad]
-  double precision, intent(in) :: lon1          ! ׻줿 [rad]
-  double precision, intent(in) :: lat1          ! ׻줿 [rad]
-  double precision, intent(inout) :: r          ! lon0 α߸̵Υ [m]
-  double precision, intent(inout) :: theta      ! lon0 ǤƱ̳ [rad]
+  double precision, intent(in) :: lon0          ! 極座標原点の経度 [rad]
+  double precision, intent(in) :: lat0          ! 極座標原点の緯度 [rad]
+  double precision, intent(in) :: lon1          ! 計算された経度 [rad]
+  double precision, intent(in) :: lat1          ! 計算された緯度 [rad]
+  double precision, intent(inout) :: r          ! lon0 からの円弧距離 [m]
+  double precision, intent(inout) :: theta      ! lon0 での同位角 [rad]
   double precision :: tmpcos, tmpsin, tmptan
 
   r=ll2radi_d( lon0, lat0, lon1, lat1 )
@@ -181,20 +181,20 @@ end subroutine ll2rt_d
 !-----------------------------------------------
 
 subroutine rt2ll_f( r, theta, lon0, lat0, lon, lat )
-! ϵε̺ɸϤˤ, (lon0, lat0) ΰ֤Ȥ (r,\theta) ɸ
-! ŸȤ, Υ r, Ʊ̳ theta ΰ֤ˤ̾Ǥη٤
-! ׻. Υ r ϵ̾α߸̵ΥȤ, theta = 90, 270 deg ̤
-! Ҹ̤̾褦 theta ֤.
-! ϿƤȤƤ, ̿ˡ˳.
+! 地球の球面座標系において, (lon0, lat0) の位置を原点とした (r,\theta) 座標を
+! 展開したとき, 距離 r, 同位角 theta の位置における球面上での経度を
+! 計算する. 距離 r は球面上の円弧距離とし, theta = 90, 270 deg が球面の
+! 子午面上を通るように theta は配置される.
+! 地図投影としては, 正距方位図法に該当する.
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: r          ! lon0 α߸̵Υ [m]
-  real, intent(in) :: theta      ! lon0 ǤƱ̳ [rad]
-  real, intent(in) :: lon0       ! ˺ɸη [rad]
-  real, intent(in) :: lat0       ! ˺ɸΰ [rad]
-  real, intent(inout) :: lon     ! ׻줿 [rad]
-  real, intent(inout) :: lat     ! ׻줿 [rad]
+  real, intent(in) :: r          ! lon0 からの円弧距離 [m]
+  real, intent(in) :: theta      ! lon0 での同位角 [rad]
+  real, intent(in) :: lon0       ! 極座標原点の経度 [rad]
+  real, intent(in) :: lat0       ! 極座標原点の緯度 [rad]
+  real, intent(inout) :: lon     ! 計算された経度 [rad]
+  real, intent(inout) :: lat     ! 計算された緯度 [rad]
   real :: thetad, lond, latd, tmplon, tmplat, rratio
 
   thetad=180.0*theta/pi
@@ -237,20 +237,20 @@ end subroutine rt2ll_f
 !-----------------------------------------------
 
 subroutine rt2ll_d( r, theta, lon0, lat0, lon, lat )
-! ϵε̺ɸϤˤ, (lon0, lat0) ΰ֤Ȥ (r,\theta) ɸ
-! ŸȤ, Υ r, Ʊ̳ theta ΰ֤ˤ̾Ǥη٤
-! ׻. Υ r ϵ̾α߸̵ΥȤ, theta = 90, 270 deg ̤
-! Ҹ̤̾褦 theta ֤.
-! ϿƤȤƤ, ̿ˡ˳.
+! 地球の球面座標系において, (lon0, lat0) の位置を原点とした (r,\theta) 座標を
+! 展開したとき, 距離 r, 同位角 theta の位置における球面上での経度を
+! 計算する. 距離 r は球面上の円弧距離とし, theta = 90, 270 deg が球面の
+! 子午面上を通るように theta は配置される.
+! 地図投影としては, 正距方位図法に該当する.
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: r          ! lon0 α߸̵Υ [m]
-  double precision, intent(in) :: theta      ! lon0 ǤƱ̳ [rad]
-  double precision, intent(in) :: lon0       ! ˺ɸη [rad]
-  double precision, intent(in) :: lat0       ! ˺ɸΰ [rad]
-  double precision, intent(inout) :: lon     ! ׻줿 [rad]
-  double precision, intent(inout) :: lat     ! ׻줿 [rad]
+  double precision, intent(in) :: r          ! lon0 からの円弧距離 [m]
+  double precision, intent(in) :: theta      ! lon0 での同位角 [rad]
+  double precision, intent(in) :: lon0       ! 極座標原点の経度 [rad]
+  double precision, intent(in) :: lat0       ! 極座標原点の緯度 [rad]
+  double precision, intent(inout) :: lon     ! 計算された経度 [rad]
+  double precision, intent(inout) :: lat     ! 計算された緯度 [rad]
   double precision :: thetad, lond, latd, tmplon, tmplat, rratio
 
   thetad=180.0d0*theta/pi_dp
@@ -293,14 +293,14 @@ end subroutine rt2ll_d
 !-----------------------------------------------
 
 real function ll2radi_f( lon1, lat1, lon2, lat2 )
-! ̾Ǥ 2 Ǥΰ, ٤򸵤, 򽪻Ȥ߸̤εΥ
-! ׻.
+! ある球面上での 2 点での緯度, 経度を元に, それらを終始点とする円弧の距離を
+! 計算する.
   use Phys_Const
   implicit none
-  real, intent(in) :: lon1    !  1 Ǥη [rad]
-  real, intent(in) :: lat1    !  1 Ǥΰ [rad]
-  real, intent(in) :: lon2    !  2 Ǥη [rad]
-  real, intent(in) :: lat2    !  2 Ǥΰ [rad]
+  real, intent(in) :: lon1    ! 点 1 での経度 [rad]
+  real, intent(in) :: lat1    ! 点 1 での緯度 [rad]
+  real, intent(in) :: lon2    ! 点 2 での経度 [rad]
+  real, intent(in) :: lat2    ! 点 2 での緯度 [rad]
   double precision :: lond1, lond2, latd1, latd2, tmp
 
   lond1=dble(lon1)
@@ -326,14 +326,14 @@ end function ll2radi_f
 !-----------------------------------------------
 
 real function ll2radi_d( lon1, lat1, lon2, lat2 )
-! ̾Ǥ 2 Ǥΰ, ٤򸵤, 򽪻Ȥ߸̤εΥ
-! ׻.
+! ある球面上での 2 点での緯度, 経度を元に, それらを終始点とする円弧の距離を
+! 計算する.
   use Phys_Const
   implicit none
-  double precision, intent(in) :: lon1    !  1 Ǥη [rad]
-  double precision, intent(in) :: lat1    !  1 Ǥΰ [rad]
-  double precision, intent(in) :: lon2    !  2 Ǥη [rad]
-  double precision, intent(in) :: lat2    !  2 Ǥΰ [rad]
+  double precision, intent(in) :: lon1    ! 点 1 での経度 [rad]
+  double precision, intent(in) :: lat1    ! 点 1 での緯度 [rad]
+  double precision, intent(in) :: lon2    ! 点 2 での経度 [rad]
+  double precision, intent(in) :: lat2    ! 点 2 での緯度 [rad]
   double precision :: lond1, lond2, latd1, latd2, tmp
 
   lond1=lon1
@@ -359,15 +359,15 @@ end function ll2radi_d
 !-----------------------------------------------
 
 real function dis2lon_f( x, lon0, phi0 )
-!   lon0 ֵΥ x [m] Υ줿֤ˤ [rad].
-!  ,  phi0 [rad] ƱپǷ¬ΥѤ.
-!  x ˷׻ݤ, ˷׻ݤͤͿз׻ǽ.
+!  基準経度 lon0 から空間距離 x [m] 離れた位置における経度 [rad].
+!  ただし, 基準緯度 phi0 [rad] から同緯度上で計測した距離を用いる.
+!  x は東に計算する際は正値, 西に計算する際は負値を与えれば計算可能.
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: x     !  lon0 ζֵΥ [m] ()
-  real, intent(in) :: lon0  !  [rad]
-  real, intent(in) :: phi0  !  [rad]
+  real, intent(in) :: x     ! 基準経度 lon0 からの空間距離 [m] (東向きが正)
+  real, intent(in) :: lon0  ! 基準経度 [rad]
+  real, intent(in) :: phi0  ! 基準緯度 [rad]
 
   dis2lon_f=x/(radius*cos(phi0))+lon0
 
@@ -377,15 +377,15 @@ end function
 !-----------------------------------------------
 
 double precision function dis2lon_d( x, lon0, phi0 )
-!   lon0 ֵΥ x [m] Υ줿֤ˤ [rad].
-!  ,  phi0 [rad] ƱپǷ¬ΥѤ.
-!  x ˷׻ݤ, ˷׻ݤͤͿз׻ǽ.
+!  基準経度 lon0 から空間距離 x [m] 離れた位置における経度 [rad].
+!  ただし, 基準緯度 phi0 [rad] から同緯度上で計測した距離を用いる.
+!  x は東に計算する際は正値, 西に計算する際は負値を与えれば計算可能.
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: x     !  lon0 ζֵΥ [m] ()
-  double precision, intent(in) :: lon0  !  [rad]
-  double precision, intent(in) :: phi0  !  [rad]
+  double precision, intent(in) :: x     ! 基準経度 lon0 からの空間距離 [m] (東向きが正)
+  double precision, intent(in) :: lon0  ! 基準経度 [rad]
+  double precision, intent(in) :: phi0  ! 基準緯度 [rad]
 
   dis2lon_d=x/(radius_dp*cos(phi0))+lon0
 
@@ -397,13 +397,13 @@ end function
 !---------------------------------
 
 real function dis2lat_f( y, phi0 )
-!   phi0 ֵΥ y [m] Υ줿֤ˤ [rad].
-!  y ̤˷׻ݤ, ˷׻ݤͤͿз׻ǽ.
+!  基準緯度 phi0 から空間距離 y [m] 離れた位置における緯度 [rad].
+!  y は北に計算する際は正値, 南に計算する際は負値を与えれば計算可能.
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: y     !  phi0 ζֵΥ [m] (̸)
-  real, intent(in) :: phi0  !  [rad]
+  real, intent(in) :: y     ! 基準緯度 phi0 からの空間距離 [m] (北向きが正)
+  real, intent(in) :: phi0  ! 基準緯度 [rad]
 
   dis2lat_f=y/radius+phi0
 
@@ -415,31 +415,31 @@ end function
 !---------------------------------
 
 double precision function dis2lat_d( y, phi0 )
-!   phi0 ֵΥ y [m] Υ줿֤ˤ [rad].
-!  y ̤˷׻ݤ, ˷׻ݤͤͿз׻ǽ.
+!  基準緯度 phi0 から空間距離 y [m] 離れた位置における緯度 [rad].
+!  y は北に計算する際は正値, 南に計算する際は負値を与えれば計算可能.
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: y     !  phi0 ζֵΥ [m] (̸)
-  double precision, intent(in) :: phi0  !  [rad]
+  double precision, intent(in) :: y     ! 基準緯度 phi0 からの空間距離 [m] (北向きが正)
+  double precision, intent(in) :: phi0  ! 基準緯度 [rad]
 
   dis2lat_d=y/radius_dp+phi0
 
   return
 end function
 
-! ʹ, ٷٺɸϿƺɸˤѴؿ
+! 以降, 緯度経度座標と地図投影座標における変換関数
 !---------------------------------
-! 1. ʹߤϥ륫ȥɸ
+! 1. 以降はメルカトル座標
 !---------------------------------
 
 real function x2merlon_f(x,lam0)
-!   lam0 Ͽ޵Υ x [m] Υ줿֤ˤ [rad].
-!  , x , Ϳз׻ǽ.
+!  基準経度 lam0 から地図距離 x [m] 離れた位置における経度 [rad].
+!  ただし, x は東方向に正, 西方向に負を与えれば計算可能.
   use Phys_Const
   implicit none
-  real, intent(in) :: x     !  lam0 ζֵΥ [m] ()
-  real, intent(in) :: lam0  !  [rad]
+  real, intent(in) :: x     ! 基準経度 lam0 からの空間距離 [m] (東向きが正)
+  real, intent(in) :: lam0  ! 基準経度 [rad]
 
   x2merlon_f=x/radius+lam0
 
@@ -449,12 +449,12 @@ end function
 !---------------------------------
 
 double precision function x2merlon_d(x,lam0)
-!   lam0 Ͽ޵Υ x [m] Υ줿֤ˤ [rad].
-!  , x , Ϳз׻ǽ.
+!  基準経度 lam0 から地図距離 x [m] 離れた位置における経度 [rad].
+!  ただし, x は東方向に正, 西方向に負を与えれば計算可能.
   use Phys_Const
   implicit none
-  double precision, intent(in) :: x     !  lam0 ζֵΥ [m] ()
-  double precision, intent(in) :: lam0  !  [rad]
+  double precision, intent(in) :: x     ! 基準経度 lam0 からの空間距離 [m] (東向きが正)
+  double precision, intent(in) :: lam0  ! 基準経度 [rad]
 
   x2merlon_d=x/radius_dp+lam0
 
@@ -464,12 +464,12 @@ end function
 !---------------------------------
 
 real function y2merlat_f(y,phi0)
-!   phi0 ֵΥ y [m] Υ줿֤ˤ [rad].
+!  基準緯度 phi0 から空間距離 y [m] 離れた位置における緯度 [rad].
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: y     !  phi0 ζֵΥ [rad] (̸).
-  real, intent(in) :: phi0  !  [rad]
+  real, intent(in) :: y     ! 基準緯度 phi0 からの空間距離 [rad] (北向き正).
+  real, intent(in) :: phi0  ! 基準緯度 [rad]
 
   y2merlat_f=2.0*atan(exp(y/radius)*abs(tan(0.25*pi+0.5*phi0)))-0.5*pi
 
@@ -479,12 +479,12 @@ end function
 !---------------------------------
 
 double precision function y2merlat_d(y,phi0)
-!   phi0 ֵΥ y [m] Υ줿֤ˤ [rad].
+!  基準緯度 phi0 から空間距離 y [m] 離れた位置における緯度 [rad].
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: y     !  phi0 ζֵΥ [rad] (̸).
-  double precision, intent(in) :: phi0  !  [rad]
+  double precision, intent(in) :: y     ! 基準緯度 phi0 からの空間距離 [rad] (北向き正).
+  double precision, intent(in) :: phi0  ! 基準緯度 [rad]
 
   y2merlat_d=2.0d0*datan(dexp(y/radius_dp)*dabs(dtan(0.25d0*pi_dp+0.5d0*phi0)))-0.5d0*pi_dp
 
@@ -495,12 +495,12 @@ end function
 !---------------------------------
 
 real function lon2merx_f(lam,lam0)
-!   lam0  lam ޤǤϿ޵Υ x [m].
-!  , x , Ϳз׻ǽ.
+!  基準経度 lam0 から経度 lam までの地図距離 x [m].
+!  ただし, x は東方向に正, 西方向に負を与えれば計算可能.
   use Phys_Const
   implicit none
-  real, intent(in) :: lam   ! ׻ [rad]
-  real, intent(in) :: lam0  !  [rad]
+  real, intent(in) :: lam   ! 計算したい経度 [rad]
+  real, intent(in) :: lam0  ! 基準経度 [rad]
 
   lon2merx_f=radius*(lam-lam0)
 
@@ -511,12 +511,12 @@ end function
 !---------------------------------
 
 double precision function lon2merx_d(lam,lam0)
-!   lam0  lam ޤǤϿ޵Υ x [m].
-!  , x , Ϳз׻ǽ.
+!  基準経度 lam0 から経度 lam までの地図距離 x [m].
+!  ただし, x は東方向に正, 西方向に負を与えれば計算可能.
   use Phys_Const
   implicit none
-  double precision, intent(in) :: lam   ! ׻ [rad]
-  double precision, intent(in) :: lam0  !  [rad]
+  double precision, intent(in) :: lam   ! 計算したい経度 [rad]
+  double precision, intent(in) :: lam0  ! 基準経度 [rad]
 
   lon2merx_d=radius_dp*(lam-lam0)
 
@@ -527,12 +527,12 @@ end function
 !---------------------------------
 
 real function lat2mery_f(phi,phi0)
-!   phi0  phi ޤǤϿ޵Υ y [m].
+!  基準緯度 phi0 から緯度 phi までの地図距離 y [m].
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: phi   ! ׻ [rad]
-  real, intent(in) :: phi0  !  [rad]
+  real, intent(in) :: phi   ! 計算したい緯度 [rad]
+  real, intent(in) :: phi0  ! 基準緯度 [rad]
 
   lat2mery_f=radius*log(abs(tan(0.25*pi+0.5*phi)/tan(0.25*pi+0.5*phi0)))
 
@@ -543,12 +543,12 @@ end function
 !---------------------------------
 
 double precision function lat2mery_d(phi,phi0)
-!   phi0  phi ޤǤϿ޵Υ y [m].
+!  基準緯度 phi0 から緯度 phi までの地図距離 y [m].
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: phi   ! ׻ [rad]
-  double precision, intent(in) :: phi0  !  [rad]
+  double precision, intent(in) :: phi   ! 計算したい緯度 [rad]
+  double precision, intent(in) :: phi0  ! 基準緯度 [rad]
 
   lat2mery_d=radius_dp*dlog(dabs(dtan(0.25d0*pi_dp+0.5d0*phi)/dtan(0.25d0*pi_dp+0.5d0*phi0)))
 
@@ -559,16 +559,16 @@ end function
 !---------------------------------
 
 real function ll2merdis_f(lambda1,phi1,lambda2,phi2,lambda0,phi0)
-!  lambda1, phi1  lambda2, phi2 ޤǤεΥ [m].
+!  lambda1, phi1 から lambda2, phi2 までの距離 [m].
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: lambda1  ! Ǥ 1 Ǥη [rad]
-  real, intent(in) :: phi1     ! Ǥ 1 Ǥΰ [rad]
-  real, intent(in) :: lambda2  ! Ǥ 2 Ǥη [rad]
-  real, intent(in) :: phi2     ! Ǥ 2 Ǥΰ [rad]
-  real, intent(in) :: lambda0  ! ̺ɸθб [rad]
-  real, intent(in) :: phi0     ! ̺ɸθб [rad]
+  real, intent(in) :: lambda1  ! 任意点 1 での経度 [rad]
+  real, intent(in) :: phi1     ! 任意点 1 での緯度 [rad]
+  real, intent(in) :: lambda2  ! 任意点 2 での経度 [rad]
+  real, intent(in) :: phi2     ! 任意点 2 での緯度 [rad]
+  real, intent(in) :: lambda0  ! 投影面座標の原点に対応する経度 [rad]
+  real, intent(in) :: phi0     ! 投影面座標の原点に対応する緯度 [rad]
 
   real :: x1, x2, y1, y2
 
@@ -586,16 +586,16 @@ end function
 !---------------------------------
 
 double precision function ll2merdis_d(lambda1,phi1,lambda2,phi2,lambda0,phi0)
-!  lambda1, phi1  lambda2, phi2 ޤǤεΥ [m].
+!  lambda1, phi1 から lambda2, phi2 までの距離 [m].
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: lambda1  ! Ǥ 1 Ǥη [rad]
-  double precision, intent(in) :: phi1     ! Ǥ 1 Ǥΰ [rad]
-  double precision, intent(in) :: lambda2  ! Ǥ 2 Ǥη [rad]
-  double precision, intent(in) :: phi2     ! Ǥ 2 Ǥΰ [rad]
-  double precision, intent(in) :: lambda0  ! ̺ɸθб [rad]
-  double precision, intent(in) :: phi0     ! ̺ɸθб [rad]
+  double precision, intent(in) :: lambda1  ! 任意点 1 での経度 [rad]
+  double precision, intent(in) :: phi1     ! 任意点 1 での緯度 [rad]
+  double precision, intent(in) :: lambda2  ! 任意点 2 での経度 [rad]
+  double precision, intent(in) :: phi2     ! 任意点 2 での緯度 [rad]
+  double precision, intent(in) :: lambda0  ! 投影面座標の原点に対応する経度 [rad]
+  double precision, intent(in) :: phi0     ! 投影面座標の原点に対応する緯度 [rad]
 
   double precision :: x1, x2, y1, y2
 
@@ -610,25 +610,25 @@ double precision function ll2merdis_d(lambda1,phi1,lambda2,phi2,lambda0,phi0)
 end function
 
 !---------------------------------
-! 2. ʹߤϥ٥Ⱥɸ
+! 2. 以降はランベルト座標
 !---------------------------------
 
 subroutine xy2lamll_f( x, y, lambda, phi, lambda0, phi0, phi1, phi2,  &
   &                    nopt, uopt, ropt )
-!   lambda0,  phi1, phi2 ̤ˤ,
-!   lambda0,  phi0 Ͽ޺ɸθȤȤ,
-!  Ͽ޺ɸ (x, y) [m] Ǥΰٷ [rad].
+!  基準経度 lambda0, 基準緯度 phi1, phi2 の投影面において,
+!  経度 lambda0, 緯度 phi0 を地図座標の原点としたとき,
+!  地図座標 (x, y) [m] での緯度経度 [rad].
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: x          ! Ͽ޺ɸʬ [m]
-  real, intent(in) :: y          ! Ͽ޺ɸʬ [m]
-  real, intent(inout) :: lambda  ! (x,y) б [rad]
-  real, intent(inout) :: phi     ! (x,y) б [rad]
-  real, intent(in) :: lambda0    !  [rad]
-  real, intent(in) :: phi0       !  [rad]
-  real, intent(in) :: phi1       ! ٥ƴ [rad]
-  real, intent(in) :: phi2       ! ٥ƴ [rad]
+  real, intent(in) :: x          ! 地図座標第一成分 [m]
+  real, intent(in) :: y          ! 地図座標第二成分 [m]
+  real, intent(inout) :: lambda  ! (x,y) に対応する経度 [rad]
+  real, intent(inout) :: phi     ! (x,y) に対応する緯度 [rad]
+  real, intent(in) :: lambda0    ! 基準経度 [rad]
+  real, intent(in) :: phi0       ! 基準緯度 [rad]
+  real, intent(in) :: phi1       ! ランベルト投影基準緯度 [rad]
+  real, intent(in) :: phi2       ! ランベルト投影基準緯度 [rad]
   real, intent(in), optional :: nopt       ! ncoe in Lambert_coe_f
   real, intent(in), optional :: uopt(0:2)  ! uphi(0:2) in Lambert_coe_f
   real, intent(in), optional :: ropt       ! rhophi0 in Lambert_coe_f
@@ -662,20 +662,20 @@ end subroutine
 
 subroutine xy2lamll_d( x, y, lambda, phi, lambda0, phi0, phi1, phi2,  &
   &                    nopt, uopt, ropt )
-!   lambda0,  phi1, phi2 ̤ˤ,
-!   lambda0,  phi0 Ͽ޺ɸθȤȤ,
-!  Ͽ޺ɸ (x, y) [m] Ǥΰٷ [rad].
+!  基準経度 lambda0, 基準緯度 phi1, phi2 の投影面において,
+!  経度 lambda0, 緯度 phi0 を地図座標の原点としたとき,
+!  地図座標 (x, y) [m] での緯度経度 [rad].
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: x          ! Ͽ޺ɸʬ [m]
-  double precision, intent(in) :: y          ! Ͽ޺ɸʬ [m]
-  double precision, intent(inout) :: lambda  ! (x,y) б [rad]
-  double precision, intent(inout) :: phi     ! (x,y) б [rad]
-  double precision, intent(in) :: lambda0    !  [rad]
-  double precision, intent(in) :: phi0       !  [rad]
-  double precision, intent(in) :: phi1       ! ٥ƴ [rad]
-  double precision, intent(in) :: phi2       ! ٥ƴ [rad]
+  double precision, intent(in) :: x          ! 地図座標第一成分 [m]
+  double precision, intent(in) :: y          ! 地図座標第二成分 [m]
+  double precision, intent(inout) :: lambda  ! (x,y) に対応する経度 [rad]
+  double precision, intent(inout) :: phi     ! (x,y) に対応する緯度 [rad]
+  double precision, intent(in) :: lambda0    ! 基準経度 [rad]
+  double precision, intent(in) :: phi0       ! 基準緯度 [rad]
+  double precision, intent(in) :: phi1       ! ランベルト投影基準緯度 [rad]
+  double precision, intent(in) :: phi2       ! ランベルト投影基準緯度 [rad]
   double precision, intent(in), optional :: nopt       ! ncoe in Lambert_coe_f
   double precision, intent(in), optional :: uopt(0:2)  ! uphi(0:2) in Lambert_coe_f
   double precision, intent(in), optional :: ropt       ! rhophi0 in Lambert_coe_f
@@ -709,20 +709,20 @@ end subroutine
 
 subroutine ll2lamxy_f( lambda, phi, x, y, lambda0, phi0, phi1, phi2,  &
   &                    nopt, uopt, ropt )
-!   lambda0,  phi1, phi2 ̤ˤ,
-!   lambda0,  phi0 Ͽ޺ɸθȤȤ,
-!  ̾Ǥΰٷ (phi,lambda) бϿ޺ɸ (x, y) [m].
+!  基準経度 lambda0, 基準緯度 phi1, phi2 の投影面において,
+!  経度 lambda0, 緯度 phi0 を地図座標の原点としたとき,
+!  球面上での緯度経度 (phi,lambda) が対応する地図座標 (x, y) [m].
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: lambda   ! (x,y) б [rad]
-  real, intent(in) :: phi      ! (x,y) б [rad]
-  real, intent(inout) :: x     ! Ͽ޺ɸʬ [m]
-  real, intent(inout) :: y     ! Ͽ޺ɸʬ [m]
-  real, intent(in) :: lambda0  !  [rad]
-  real, intent(in) :: phi0       !  [rad]
-  real, intent(in) :: phi1       ! ٥ƴ [rad]
-  real, intent(in) :: phi2       ! ٥ƴ [rad]
+  real, intent(in) :: lambda   ! (x,y) に対応する経度 [rad]
+  real, intent(in) :: phi      ! (x,y) に対応する緯度 [rad]
+  real, intent(inout) :: x     ! 地図座標第一成分 [m]
+  real, intent(inout) :: y     ! 地図座標第二成分 [m]
+  real, intent(in) :: lambda0  ! 基準経度 [rad]
+  real, intent(in) :: phi0       ! 基準緯度 [rad]
+  real, intent(in) :: phi1       ! ランベルト投影基準緯度 [rad]
+  real, intent(in) :: phi2       ! ランベルト投影基準緯度 [rad]
   real, intent(in), optional :: nopt       ! ncoe in Lambert_coe_f
   real, intent(in), optional :: uopt(0:2)  ! uphi(0:2) in Lambert_coe_f
   real, intent(in), optional :: ropt       ! rhophi0 in Lambert_coe_f
@@ -759,20 +759,20 @@ end subroutine
 
 subroutine ll2lamxy_d( lambda, phi, x, y, lambda0, phi0, phi1, phi2,  &
   &                    nopt, uopt, ropt )
-!   lambda0,  phi1, phi2 ̤ˤ,
-!   lambda0,  phi0 Ͽ޺ɸθȤȤ,
-!  ̾Ǥΰٷ (phi,lambda) бϿ޺ɸ (x, y) [m].
+!  基準経度 lambda0, 基準緯度 phi1, phi2 の投影面において,
+!  経度 lambda0, 緯度 phi0 を地図座標の原点としたとき,
+!  球面上での緯度経度 (phi,lambda) が対応する地図座標 (x, y) [m].
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: lambda   ! (x,y) б [rad]
-  double precision, intent(in) :: phi      ! (x,y) б [rad]
-  double precision, intent(inout) :: x     ! Ͽ޺ɸʬ [m]
-  double precision, intent(inout) :: y     ! Ͽ޺ɸʬ [m]
-  double precision, intent(in) :: lambda0  !  [rad]
-  double precision, intent(in) :: phi0       !  [rad]
-  double precision, intent(in) :: phi1       ! ٥ƴ [rad]
-  double precision, intent(in) :: phi2       ! ٥ƴ [rad]
+  double precision, intent(in) :: lambda   ! (x,y) に対応する経度 [rad]
+  double precision, intent(in) :: phi      ! (x,y) に対応する緯度 [rad]
+  double precision, intent(inout) :: x     ! 地図座標第一成分 [m]
+  double precision, intent(inout) :: y     ! 地図座標第二成分 [m]
+  double precision, intent(in) :: lambda0  ! 基準経度 [rad]
+  double precision, intent(in) :: phi0       ! 基準緯度 [rad]
+  double precision, intent(in) :: phi1       ! ランベルト投影基準緯度 [rad]
+  double precision, intent(in) :: phi2       ! ランベルト投影基準緯度 [rad]
   double precision, intent(in), optional :: nopt       ! ncoe in Lambert_coe_f
   double precision, intent(in), optional :: uopt(0:2)  ! uphi(0:2) in Lambert_coe_f
   double precision, intent(in), optional :: ropt       ! rhophi0 in Lambert_coe_f
@@ -811,20 +811,20 @@ end subroutine
 real function ll2lamdis_f( lambda1, phi1, lambda2, phi2,  &
   &                        lambda0, phit1, phit2, phi0,  &
   &                        nopt, uopt, ropt )
-!   phit1, phit2,  lambda0 Ͽ޺ɸθ
-!  phi0,  lambda 0 ȤȤ, ٷٺɸ 2 
-!  (lambda1,phi1), (lambda2,phi2) ֤Ͽ޾ǤεΥ [m].
+!  基準緯度 phit1, phit2, 基準経度 lambda0 から地図座標の原点が
+!  緯度phi0, 経度 lambda 0 としたとき, 緯度経度座標で定義される 2 点
+!  (lambda1,phi1), (lambda2,phi2) 間の地図上での距離 [m].
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: lambda1 ! ᤿ 1 η [rad].
-  real, intent(in) :: phi1    ! ᤿ 1 ΰ [rad].
-  real, intent(in) :: lambda2 ! ᤿ 2 η [rad].
-  real, intent(in) :: phi2    ! ᤿ 2 ΰ [rad].
-  real, intent(in) :: lambda0 ! ٤Ͽ޺ɸ [rad]
-  real, intent(in) :: phit1   !  1 [rad]
-  real, intent(in) :: phit2   !  2 [rad]
-  real, intent(in) :: phi0    ! Ͽ޺ɸ 0 [rad].
+  real, intent(in) :: lambda1 ! 求めたい点 1 の経度 [rad].
+  real, intent(in) :: phi1    ! 求めたい点 1 の緯度 [rad].
+  real, intent(in) :: lambda2 ! 求めたい点 2 の経度 [rad].
+  real, intent(in) :: phi2    ! 求めたい点 2 の緯度 [rad].
+  real, intent(in) :: lambda0 ! 基準経度かつ地図座標基準経度 [rad]
+  real, intent(in) :: phit1   ! 基準緯度 1 [rad]
+  real, intent(in) :: phit2   ! 基準緯度 2 [rad]
+  real, intent(in) :: phi0    ! 地図座標基準緯度 0 [rad].
   real, intent(in), optional :: nopt       ! ncoe in Lambert_coe_f
   real, intent(in), optional :: uopt(0:2)  ! uphi(0:2) in Lambert_coe_f
   real, intent(in), optional :: ropt       ! rhophi0 in Lambert_coe_f
@@ -864,20 +864,20 @@ end function
 double precision function ll2lamdis_d( lambda1, phi1, lambda2, phi2,  &
   &                                    lambda0, phit1, phit2, phi0,  &
   &                                    nopt, uopt, ropt )
-!   phit1, phit2,  lambda0 Ͽ޺ɸθ
-!  phi0,  lambda 0 ȤȤ, ٷٺɸ 2 
-!  (lambda1,phi1), (lambda2,phi2) ֤Ͽ޾ǤεΥ [m].
+!  基準緯度 phit1, phit2, 基準経度 lambda0 から地図座標の原点が
+!  緯度phi0, 経度 lambda 0 としたとき, 緯度経度座標で定義される 2 点
+!  (lambda1,phi1), (lambda2,phi2) 間の地図上での距離 [m].
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: lambda1 ! ᤿ 1 η [rad].
-  double precision, intent(in) :: phi1    ! ᤿ 1 ΰ [rad].
-  double precision, intent(in) :: lambda2 ! ᤿ 2 η [rad].
-  double precision, intent(in) :: phi2    ! ᤿ 2 ΰ [rad].
-  double precision, intent(in) :: lambda0 ! ٤Ͽ޺ɸ [rad]
-  double precision, intent(in) :: phit1   !  1 [rad]
-  double precision, intent(in) :: phit2   !  2 [rad]
-  double precision, intent(in) :: phi0    ! Ͽ޺ɸ 0 [rad].
+  double precision, intent(in) :: lambda1 ! 求めたい点 1 の経度 [rad].
+  double precision, intent(in) :: phi1    ! 求めたい点 1 の緯度 [rad].
+  double precision, intent(in) :: lambda2 ! 求めたい点 2 の経度 [rad].
+  double precision, intent(in) :: phi2    ! 求めたい点 2 の緯度 [rad].
+  double precision, intent(in) :: lambda0 ! 基準経度かつ地図座標基準経度 [rad]
+  double precision, intent(in) :: phit1   ! 基準緯度 1 [rad]
+  double precision, intent(in) :: phit2   ! 基準緯度 2 [rad]
+  double precision, intent(in) :: phi0    ! 地図座標基準緯度 0 [rad].
   double precision, intent(in), optional :: nopt       ! ncoe in Lambert_coe_f
   double precision, intent(in), optional :: uopt(0:2)  ! uphi(0:2) in Lambert_coe_f
   double precision, intent(in), optional :: ropt       ! rhophi0 in Lambert_coe_f
@@ -911,33 +911,98 @@ double precision function ll2lamdis_d( lambda1, phi1, lambda2, phi2,  &
 
 end function
 
+!---------------------------------
+!---------------------------------
+
+logical function check_close( xposi, yposi, ival )
+! xposi, yposi で囲まれた閉曲線領域内に ival 点があるかどうかをチェックする.
+! これらはすべて格子点上で処理される.
+
+  implicit none
+
+  integer, intent(in) :: xposi(:)  ! 閉曲線の x 方向格子点番号
+  integer, intent(in) :: yposi(size(xposi))  ! 閉曲線の y 方向格子点番号
+  integer, intent(in) :: ival(2)  ! チェックする点の x, y 格子点番号
+  integer :: ii, kx
+  double precision :: total, dtheta, x1, y1, x2, y2, r1, r2
+  double precision :: r1r2, r1dr2
+
+  kx=size(xposi)
+
+  if(xposi(1)/=xposi(kx).or.yposi(1)/=yposi(kx))then
+     write(*,*) "*** ERROR (check_close) ***: xposi(1) is not xposi(nx). "
+     stop
+  end if
+
+  total=0.0d0
+
+  do ii=2,kx
+     x1=dble(xposi(ii-1)-ival(1))
+     y1=dble(yposi(ii-1)-ival(2))
+     x2=dble(xposi(ii)-ival(1))
+     y2=dble(yposi(ii)-ival(2))
+     r1=dsqrt(x1**2+y1**2)
+     r2=dsqrt(x2**2+y2**2)
+     r1r2=r1*r2
+     r1dr2=x1*x2+y1*y2
+
+     if(r1==0.0.or.r2==0.0)then
+        check_close=.true.
+        return
+     end if
+
+     if(r1dr2>r1r2)then
+        dtheta=dacos(1.0d0)
+     else
+        dtheta=dacos(r1dr2/r1r2)
+     end if
+
+     if(x1*y2-y1*x2>0.0d0)then
+        total=total+dtheta
+     else
+        total=total-dtheta
+     end if
+
+  end do
+
+  if(dabs(total)>0.1d0)then
+     check_close=.true.
+  else
+     check_close=.false.
+  end if
+
+  return
+
+end function check_close
+
+
 !---------------------------------
 !---------------------------------
 
 subroutine vec2lam_f( lambda0, phi1, phi2, lambda, phi,  &
   &                   ui, vi, uo, vo, conv_flag, undef )
-! ʿ٥ȥʬٷٺɸϿ޺ɸѴ (٥Ⱥɸ).
+! 水平ベクトル成分を緯度経度座標から地図座標に変換する (ランベルト座標).
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: lambda0     ! ٥ƴ [rad]
-  real, intent(in) :: phi1        ! ٥ƴ 1 [rad]
-  real, intent(in) :: phi2        ! ٥ƴ 2 [rad]
-  real, intent(in) :: lambda(:,:) ! ®٤Ƥ [rad]
-  real, intent(in) :: phi(:,:)    ! ®٤Ƥ [rad]
+  real, intent(in) :: lambda0     ! ランベルト投影基準経度 [rad]
+  real, intent(in) :: phi1        ! ランベルト投影基準緯度 1 [rad]
+  real, intent(in) :: phi2        ! ランベルト投影基準緯度 2 [rad]
+  real, intent(in) :: lambda(:,:) ! 速度が定義されている経度 [rad]
+  real, intent(in) :: phi(:,:)    ! 速度が定義されている緯度 [rad]
   real, intent(in) :: ui(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ x ®ʬ [m/s] (Ѵ)
+                      ! 経度方向 or 地図座標 x 方向の速度成分 [m/s] (変換前)
   real, intent(in) :: vi(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ y ®ʬ [m/s] (Ѵ)
+                      ! 緯度方向 or 地図座標 y 方向の速度成分 [m/s] (変換前)
   real, intent(inout) :: uo(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ x ®ʬ [m/s] (Ѵ)
+                      ! 経度方向 or 地図座標 x 方向の速度成分 [m/s] (変換後)
   real, intent(inout) :: vo(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ y ®ʬ [m/s] (Ѵ)
-  character(5), intent(in) :: conv_flag  ! Ѵ
-                              ! 'll2xy' = ٷٺɸ٥ƺɸ
-                              ! 'xy2ll' = ٥ƺɸٷٺɸ
+                      ! 緯度方向 or 地図座標 y 方向の速度成分 [m/s] (変換後)
+  character(5), intent(in) :: conv_flag  ! 変換の方向
+                              ! 'll2xy' = 緯度経度座標からランベルト投影座標へ
+                              ! 'xy2ll' = ランベルト投影座標から緯度経度座標へ
 
-  real, intent(in), optional :: undef   ! ̤
+  real, intent(in), optional :: undef   ! 未定義値
 
   integer :: ix, jy, i, j
   real :: rundef, cos1, cos2, tan1, tan2, ncoe, cosp, sinp
@@ -1023,28 +1088,28 @@ end subroutine
 
 subroutine vec2lam_d( lambda0, phi1, phi2, lambda, phi,  &
   &                   ui, vi, uo, vo, conv_flag, undef )
-! ʿ٥ȥʬٷٺɸϿ޺ɸѴ (٥Ⱥɸ).
+! 水平ベクトル成分を緯度経度座標から地図座標に変換する (ランベルト座標).
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: lambda0     ! ٥ƴ [rad]
-  double precision, intent(in) :: phi1        ! ٥ƴ 1 [rad]
-  double precision, intent(in) :: phi2        ! ٥ƴ 2 [rad]
-  double precision, intent(in) :: phi(:,:)    ! ®٤Ƥ [rad]
-  double precision, intent(in) :: lambda(:,:) ! ®٤Ƥ [rad]
+  double precision, intent(in) :: lambda0     ! ランベルト投影基準経度 [rad]
+  double precision, intent(in) :: phi1        ! ランベルト投影基準緯度 1 [rad]
+  double precision, intent(in) :: phi2        ! ランベルト投影基準緯度 2 [rad]
+  double precision, intent(in) :: phi(:,:)    ! 速度が定義されている緯度 [rad]
+  double precision, intent(in) :: lambda(:,:) ! 速度が定義されている経度 [rad]
   double precision, intent(in) :: ui(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ x ®ʬ [m/s] (Ѵ)
+                      ! 経度方向 or 地図座標 x 方向の速度成分 [m/s] (変換前)
   double precision, intent(in) :: vi(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ y ®ʬ [m/s] (Ѵ)
+                      ! 緯度方向 or 地図座標 y 方向の速度成分 [m/s] (変換前)
   double precision, intent(inout) :: uo(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ x ®ʬ [m/s] (Ѵ)
+                      ! 経度方向 or 地図座標 x 方向の速度成分 [m/s] (変換後)
   double precision, intent(inout) :: vo(size(phi,1),size(phi,2))
-                      !  or Ͽ޺ɸ y ®ʬ [m/s] (Ѵ)
-  character(5), intent(in) :: conv_flag  ! Ѵ
-                              ! 'll2xy' = ٷٺɸ٥ƺɸ
-                              ! 'xy2ll' = ٥ƺɸٷٺɸ
+                      ! 緯度方向 or 地図座標 y 方向の速度成分 [m/s] (変換後)
+  character(5), intent(in) :: conv_flag  ! 変換の方向
+                              ! 'll2xy' = 緯度経度座標からランベルト投影座標へ
+                              ! 'xy2ll' = ランベルト投影座標から緯度経度座標へ
 
-  double precision, intent(in), optional :: undef   ! ̤
+  double precision, intent(in), optional :: undef   ! 未定義値
 
   integer :: ix, jy, i, j
   double precision :: rundef, cos1, cos2, tan1, tan2, ncoe, cosp, sinp
@@ -1129,19 +1194,19 @@ end subroutine
 !---------------------------------
 
 subroutine lambert_coe_f( lambda0, phi0, phi1, phi2, ncoe, uphi, rhophi0 )
-!   phi1, phi2,  lambda0, ƺɸθ phi0
-!  ξˤ, Ƽ Lambert ѿ׻ݤɬץѥ᡼
-!  n, U, rho .
+!  基準緯度 phi1, phi2, 基準経度 lambda0, 投影座標の原点基準緯度 phi0
+!  の場合における, 各種 Lambert 系変数を計算する際の必要パラメータ
+!  n, U, rho を求める.
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: lambda0        ! ٤Ͽ޺ɸ [rad]
-  real, intent(in) :: phi1           !  1 [rad]
-  real, intent(in) :: phi2           !  2 [rad]
-  real, intent(in) :: phi0           ! Ͽ޺ɸ 0 [rad].
-  real, intent(inout) :: ncoe        ! ̼ܰ N
-  real, intent(inout) :: uphi(0:2)   ! ܷ U(phi0,phi1,phi2)
-  real, intent(inout) :: rhophi0     ! Ⱦ r(phi0)
+  real, intent(in) :: lambda0        ! 基準経度かつ地図座標基準経度 [rad]
+  real, intent(in) :: phi1           ! 基準緯度 1 [rad]
+  real, intent(in) :: phi2           ! 基準緯度 2 [rad]
+  real, intent(in) :: phi0           ! 地図座標基準緯度 0 [rad].
+  real, intent(inout) :: ncoe        ! 縮尺因子 N
+  real, intent(inout) :: uphi(0:2)   ! 正接係数 U(phi0,phi1,phi2)
+  real, intent(inout) :: rhophi0     ! 扇半径 r(phi0)
 
   real :: cos1, cos2
 
@@ -1160,19 +1225,19 @@ end subroutine
 !---------------------------------
 
 subroutine lambert_coe_d( lambda0, phi0, phi1, phi2, ncoe, uphi, rhophi0 )
-!   phi1, phi2,  lambda0, ƺɸθ phi0
-!  ξˤ, Ƽ Lambert ѿ׻ݤɬץѥ᡼
-!  n, U, rho .
+!  基準緯度 phi1, phi2, 基準経度 lambda0, 投影座標の原点基準緯度 phi0
+!  の場合における, 各種 Lambert 系変数を計算する際の必要パラメータ
+!  n, U, rho を求める.
   use Phys_Const
   use Math_Const
   implicit none
-  double precision, intent(in) :: lambda0        ! ٤Ͽ޺ɸ [rad]
-  double precision, intent(in) :: phi1           !  1 [rad]
-  double precision, intent(in) :: phi2           !  2 [rad]
-  double precision, intent(in) :: phi0           ! Ͽ޺ɸ 0 [rad].
-  double precision, intent(inout) :: ncoe        ! ̼ܰ N
-  double precision, intent(inout) :: uphi(0:1)   ! ܷ U(phi0,phi1)
-  double precision, intent(inout) :: rhophi0     ! Ⱦ r(phi0)
+  double precision, intent(in) :: lambda0        ! 基準経度かつ地図座標基準経度 [rad]
+  double precision, intent(in) :: phi1           ! 基準緯度 1 [rad]
+  double precision, intent(in) :: phi2           ! 基準緯度 2 [rad]
+  double precision, intent(in) :: phi0           ! 地図座標基準緯度 0 [rad].
+  double precision, intent(inout) :: ncoe        ! 縮尺因子 N
+  double precision, intent(inout) :: uphi(0:1)   ! 正接係数 U(phi0,phi1)
+  double precision, intent(inout) :: rhophi0     ! 扇半径 r(phi0)
 
   double precision :: cos1, cos2, tanx
 
