@@ -3,17 +3,17 @@
 !---------------------------------------------------------------
 
 module Math_Function
-! ѴԤؿ
+! 数値変換等を行う関数集
 
 contains
 
 subroutine digit_conv( numb, digit, numa )
-! Ǥդ numb  digit ʿʸ numa Ѵ롼
-!  URL:http://www2.cc.niigata-u.ac.jp/~takeuchi/
+! 任意の整数 numb を digit 進数の文字列 numa に変換するルーチン
+! 参考 URL:http://www2.cc.niigata-u.ac.jp/~takeuchi/
   implicit none
-  integer, intent(in) :: numb  ! Ѵ 10 ʿ
-  integer, intent(in) :: digit  ! Ѵʿ
-  character(*), intent(inout) :: numa  ! Ѵʸ
+  integer, intent(in) :: numb  ! 変換する 10 進数
+  integer, intent(in) :: digit  ! 変換する進数数
+  character(*), intent(inout) :: numa  ! 変換後の文字列
   character(1) :: tmpc
   integer :: tmpi, tmpci
 
@@ -35,11 +35,11 @@ subroutine digit_conv( numb, digit, numa )
 end subroutine
 
 character(1) function digit_char_conv( num )
-! ʿѴκ, бʸ֤ؿ.
-! Ȥ, 10 ʿ 16 ʿؤѴκ, num = 16 ʤ, f ֤.
-! ե٥åȾʸΤߤбƤ, ¾, 36 ʿѴޤб.
+! 進数変換の際, それに対応する文字列を返す関数.
+! たとえば, 10 進数から 16 進数への変換の際, num = 16 なら, f を返す.
+! アルファベット小文字のみに対応しており, 事実上, 36 進数変換まで対応可.
   implicit none
-  integer, intent(in) :: num  ! Ѵ [10 ʾǤʤ, Ʊ֤.]
+  integer, intent(in) :: num  ! 変換する数値 [10 以上でない場合は, 同じ数字を返す.]
   select case (num)
   case (1:9)
      write(digit_char_conv,'(i1)') num
