@@ -3,9 +3,9 @@
 !---------------------------------------------------------------
 
 module Matrix_Calc
-!  ׻˹Ԥ롼.
-!  ͭͷ׻չ׻, ϢΩεʤɤԤ.
-!  ˥٥ȥ.
+!  行列計算を主に行うルーチン集.
+!  固有値計算や逆行列計算, 連立方程式の求解などを行う.
+!  一部にベクトル処理も入る.
 
   public :: Gau_Sei
   public :: LU_devs
@@ -13,6 +13,7 @@ module Matrix_Calc
   public :: SOR_Gau_Sei
   public :: SOR_Jacobi_algebra
   public :: gausss
+  public :: tri_gauss
   public :: schumit_norm
   public :: mat_dot
   public :: Householder
@@ -22,6 +23,17 @@ module Matrix_Calc
   private :: vec_dot
   private :: sum_sq
 
+interface gausss
+
+  module procedure gausssf, gausssd
+
+end interface gausss
+
+interface tri_gauss
+
+  module procedure tri_gaussf, tri_gaussd
+
+end interface tri_gauss
 
 interface trans_mat
 !  module Matrix_Calc
@@ -42,9 +54,9 @@ end interface determ_2d
 contains
 
 subroutine trans_mat_i( a )
-!  ʬž֤֤
+!  行列成分の転置を返す
   implicit none
-  integer, intent(inout), dimension(:,:) :: a  ! Ϲ
+  integer, intent(inout), dimension(:,:) :: a  ! 入力行列
   integer :: i, j, tmp, nx
 
   nx=size(a,1)
@@ -64,9 +76,9 @@ end subroutine
 !-----------------------------------------------------------------
 
 subroutine trans_mat_f( a )
-!  ʬž֤֤(¿)
+!  行列成分の転置を返す(実数版)
   implicit none
-  real, intent(inout), dimension(:,:) :: a  ! Ϲ
+  real, intent(inout), dimension(:,:) :: a  ! 入力行列
   integer :: i, j, nx
   real :: tmp
 
@@ -88,9 +100,9 @@ end subroutine
 !-----------------------------------------------------------------
 
 recursive function determ_2d_i( a ) result(res)
-! 2x2 ι󼰤׻ؿ()
+! 2x2 の正方行列の行列式を計算する関数(整数版)
   implicit none
-  integer, dimension(2,2), intent(in) :: a  ! 2x2 
+  integer, dimension(2,2), intent(in) :: a  ! 2x2 の正方行列
   integer :: res
 
   res=a(1,1)*a(2,2)-a(1,2)*a(2,1)
@@ -102,9 +114,9 @@ end function
 !-----------------------------------------------------------------
 
 recursive function determ_2d_f( a ) result(res)
-! 2x2 ι󼰤׻ؿ(¿)
+! 2x2 の正方行列の行列式を計算する関数(実数版)
   implicit none
-  real, dimension(2,2), intent(in) :: a  ! 2x2 
+  real, dimension(2,2), intent(in) :: a  ! 2x2 の正方行列
   real :: res
 
   res=a(1,1)*a(2,2)-a(1,2)*a(2,1)
@@ -116,7 +128,7 @@ end function
 !-----------------------------------------------------------------
 
 subroutine mat_dot( a, b, c )
-! ƱΤѤ׻ (a * b = c).
+! 行列同士の積を計算する (a * b = c).
   implicit none
   real, dimension(:,:), intent(in) :: a, b
   real, dimension(:,:), intent(inout) :: c
@@ -146,15 +158,15 @@ end subroutine mat_dot
 !-----------------------------------------------------------------
 
 subroutine invert_mat( ax, xx )
-! ξõˡĥ, չ׻.
-! Ūˤ, դ b ñ̥٥ȥ 1 Ĥ,õ̤Υ٥ȥ¤٤
-! չˤ.
+! ガウスの消去法を拡張して, 逆行列を計算する.
+! 具体的には, 右辺の b に単位ベクトルを 1 つずつ代入し,消去した結果のベクトルを並べて
+! 逆行列にする.
   implicit none
-  real, intent(in) :: ax(:,:)  ! չ
-  real, intent(inout) :: xx(size(ax,1),size(ax,2))  ! ᤿չ
+  real, intent(in) :: ax(:,:)  ! 逆行列を求める行列
+  real, intent(inout) :: xx(size(ax,1),size(ax,2))  ! 求めた逆行列
   integer :: i, j, k
-  real :: c(size(ax,1),size(ax,2))  ! ñ̹
-  real :: d(size(ax,1),size(ax,2))  ! a(i,j) 򥬥롼Ϥ, ̤ѲΤǤ˰
+  real :: c(size(ax,1),size(ax,2))  ! 単位行列
+  real :: d(size(ax,1),size(ax,2))  ! a(i,j) をガウスルーチンに渡すと, 結果が変化するのでこれに一時退避
   integer :: nx
 
   nx=size(ax,1)
@@ -169,27 +181,27 @@ subroutine invert_mat( ax, xx )
 
      do j=1,nx
         do k=1,nx
-           d(k,j)=ax(k,j)  ! ߡѿ
+           d(k,j)=ax(k,j)  ! ダミー変数へ代入
         end do
      end do
 
-     call gausss( d, c(:,i), xx(:,i) )  !  2 ʬɽΤ, ν֤ OK.
+     call gausss( d, c(:,i), xx(:,i) )  ! 配列第 2 成分が列を表すので, この順番で OK.
   end do
 
 end subroutine invert_mat
 
 !-----------------------------------------------------------------
-!  ʲ, ϢΩ 1 ε롼
+!  以下, 連立 1 次方程式の求解ルーチン
 !-----------------------------------------------------------------
 
-subroutine gausss( c, d, x )
-! ʬԥܥåդξõˡ
+subroutine gausssf( c, d, x )
+! 部分ピボット付きガウスの消去法
   implicit none
   real, intent(in) :: d(:)
-  real, intent(in) :: c(size(d),size(d))  !  ( 1 ǤԤɽ)
+  real, intent(in) :: c(size(d),size(d))  ! 係数行列 (第 1 要素が「行」を表す)
   real, intent(inout) :: x(size(d))
   real :: b(size(d))
-  real :: a(size(d),size(d))  !  ( 1 ǤԤɽ)
+  real :: a(size(d),size(d))  ! 係数行列 (第 1 要素が「列」を表す)
   real :: s, pivotb
   real :: pivot(size(d)+1)
   integer :: piv, i, j, k, nmax
@@ -198,24 +210,24 @@ subroutine gausss( c, d, x )
 
   do k=1,nmax
      do j=1,nmax
-        a(j,k)=c(j,k)
+        a(k,j)=c(j,k)   ! ここで行列入れ替え (計算自体はこれで行う)
      end do
      b(k)=d(k)
   end do
 
-!-- ʾõ ---
-!-- A(I,J) ʾõ ---
+!-- 前進消去 ---
+!-- A(I,J) の前進消去 ---
   do k=1,nmax-1
-!-- PIVOT  ---
-!-- ޤ, I ʬκͤꤹ ---
+!-- PIVOT の選択 ---
+!-- まず, I 成分の最大値を決定する ---
      piv=k
      do i=k+1,nmax
          if(abs(a(i,k)).gt.abs(a(piv,k)))then
             piv=i
          end if
      end do
-!-- ޤǤ, ͤꤵ ---
-!-- ʲ, ͤȤʬιԤؤ ---
+!-- ここまでで, 最大値が決定される ---
+!-- 以下で, 最大値をとる成分の行を入れ替える ---
      do j=k,nmax
         pivot(j)=a(k,j)
         a(k,j)=a(piv,j)
@@ -224,7 +236,7 @@ subroutine gausss( c, d, x )
      pivotb=b(k)
      b(k)=b(piv)
      b(piv)=pivotb
-!-- PIVOT ޤ ---
+!-- PIVOT 処理ここまで ---
      do i=k+1,nmax
         a(k,i)=a(k,i)/a(k,k)
      end do
@@ -243,7 +255,7 @@ subroutine gausss( c, d, x )
   b(nmax)=b(nmax)/a(nmax,nmax)
   a(nmax,nmax)=1.0
 
-!-- X(I) θ
+!-- X(I) の後進代入
   x(nmax)=b(nmax)
   do i=nmax-1,1,-1
      s=b(i)
@@ -253,17 +265,182 @@ subroutine gausss( c, d, x )
      x(i)=s
   end do
 
-end subroutine gausss
+end subroutine gausssf
+
+!------------------------------------------
+
+subroutine gausssd( c, d, x )
+! 部分ピボット付きガウスの消去法
+  implicit none
+  double precision, intent(in) :: d(:)
+  double precision, intent(in) :: c(size(d),size(d))  ! 係数行列 (第 1 要素が「行」を表す)
+  double precision, intent(inout) :: x(size(d))
+  double precision :: b(size(d))
+  double precision :: a(size(d),size(d))  ! 係数行列 (第 1 要素が「列」を表す)
+  double precision :: s, pivotb
+  double precision :: pivot(size(d)+1)
+  integer :: piv, i, j, k, nmax
+
+  nmax=size(b)
+
+  do k=1,nmax
+     do j=1,nmax
+        a(k,j)=c(j,k)   ! ここで行列入れ替え (計算自体はこれで行う)
+     end do
+     b(k)=d(k)
+  end do
+
+!-- 前進消去 ---
+!-- A(I,J) の前進消去 ---
+  do k=1,nmax-1
+!-- PIVOT の選択 ---
+!-- まず, I 成分の最大値を決定する ---
+     piv=k
+     do i=k+1,nmax
+         if(abs(a(i,k)).gt.abs(a(piv,k)))then
+            piv=i
+         end if
+     end do
+!-- ここまでで, 最大値が決定される ---
+!-- 以下で, 最大値をとる成分の行を入れ替える ---
+     do j=k,nmax
+        pivot(j)=a(k,j)
+        a(k,j)=a(piv,j)
+        a(piv,j)=pivot(j)
+     end do
+     pivotb=b(k)
+     b(k)=b(piv)
+     b(piv)=pivotb
+!-- PIVOT 処理ここまで ---
+     do i=k+1,nmax
+        a(k,i)=a(k,i)/a(k,k)
+     end do
+     b(k)=b(k)/a(k,k)
+     a(k,k)=1.0d0
+
+     do j=k+1,nmax
+        do i=k+1,nmax
+            a(j,i)=a(j,i)-a(k,i)*a(j,k)
+        end do
+        b(j)=b(j)-b(k)*a(j,k)
+        a(j,k)=0.0d0
+     end do
+  end do
+
+  b(nmax)=b(nmax)/a(nmax,nmax)
+  a(nmax,nmax)=1.0d0
+
+!-- X(I) の後進代入
+  x(nmax)=b(nmax)
+  do i=nmax-1,1,-1
+     s=b(i)
+     do j=i+1,nmax
+        s=s-a(i,j)*x(j)
+     end do
+     x(i)=s
+  end do
+
+end subroutine gausssd
+
+!------------------------------------------
+
+subroutine tri_gaussf( c, d, x )
+! 三重対角行列版ガウスの消去法
+  implicit none
+  real, intent(in) :: d(:)
+  real, intent(in) :: c(size(d),size(d))  ! 係数行列 (第 1 要素が「行」を表す)
+  real, intent(inout) :: x(size(d))
+  real :: b(size(d))
+  real :: a(size(d),size(d))  ! 係数行列 (第 1 要素が「列」を表す)
+  real :: s
+  integer :: i, j, k, nmax
+
+  nmax=size(b)
+
+  do k=1,nmax
+     do j=1,nmax
+        a(k,j)=c(j,k)   ! ここで行列入れ替え (計算自体はこれで行う)
+     end do
+     b(k)=d(k)
+  end do
+
+!-- 前進消去 ---
+!-- A(I,J) の前進消去 ---
+  do k=1,nmax-1
+     a(k,k+1)=a(k,k+1)/a(k,k)
+     b(k)=b(k)/a(k,k)
+     a(k,k)=1.0
+
+     a(k+1,k+1)=a(k+1,k+1)-a(k,k+1)*a(k+1,k)
+     b(k+1)=b(k+1)-b(k)*a(k+1,k)
+     a(k+1,k)=0.0
+  end do
+
+  b(nmax)=b(nmax)/a(nmax,nmax)
+  a(nmax,nmax)=1.0
+
+!-- X(I) の後進代入
+  x(nmax)=b(nmax)
+  do i=nmax-1,1,-1
+     x(i)=b(i)-a(i,i+1)*x(i+1)
+  end do
+
+end subroutine tri_gaussf
+
+!------------------------------------------
+
+subroutine tri_gaussd( c, d, x )
+! 三重対角行列版ガウスの消去法
+  implicit none
+  double precision, intent(in) :: d(:)
+  double precision, intent(in) :: c(size(d),size(d))  ! 係数行列 (第 1 要素が「行」を表す)
+  double precision, intent(inout) :: x(size(d))
+  double precision :: b(size(d))
+  double precision :: a(size(d),size(d))  ! 係数行列 (第 1 要素が「列」を表す)
+  double precision :: s
+  integer :: i, j, k, nmax
+
+  nmax=size(b)
+
+  do k=1,nmax
+     do j=1,nmax
+        a(k,j)=c(j,k)   ! ここで行列入れ替え (計算自体はこれで行う)
+     end do
+     b(k)=d(k)
+  end do
+
+!-- 前進消去 ---
+!-- A(I,J) の前進消去 ---
+  do k=1,nmax-1
+     a(k,k+1)=a(k,k+1)/a(k,k)
+     b(k)=b(k)/a(k,k)
+     a(k,k)=1.0d0
+
+     a(k+1,k+1)=a(k+1,k+1)-a(k,k+1)*a(k+1,k)
+     b(k+1)=b(k+1)-b(k)*a(k+1,k)
+     a(k+1,k)=0.0d0
+  end do
+
+  b(nmax)=b(nmax)/a(nmax,nmax)
+  a(nmax,nmax)=1.0d0
+
+!-- X(I) の後進代入
+  x(nmax)=b(nmax)
+  do i=nmax-1,1,-1
+     x(i)=b(i)-a(i,i+1)*x(i+1)
+  end do
+
+end subroutine tri_gaussd
 
 !------------------------------------------
 
 subroutine LU_devs( a, b, x, itermax )
-!-- LU ʬ׻륵֥롼 ---
+!-- LU 分解を計算するサブルーチン ---
   implicit none
-  real, intent(inout) :: b(:)  ! դΥ٥ȥ
-  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤԤɽ)
-  real, intent(inout) :: x(size(b))  ! 
-  integer, intent(in) :: itermax  ! ȿβ
+  real, intent(inout) :: b(:)  ! 右辺のベクトル
+  real, intent(inout) :: a(size(b),size(b))  ! 係数行列 (第 1 要素が「行」を表現)
+  real, intent(inout) :: x(size(b))  ! 解
+  integer, intent(in) :: itermax  ! 反復の回数
   real :: d(size(b),size(b)), r(size(b)), y(size(b))
   integer :: ip(size(b))
   real :: scale(size(b)), dx(size(b))
@@ -274,22 +451,22 @@ subroutine LU_devs( a, b, x, itermax )
 
   nmax=size(b)
 
-!-- ȿɤǤ٤ ---
+!-- 反復改良での精度の設定 ---
   t4=6.0
 
-!--  x(i) ν ---
+!-- 配列 x(i) の初期化 ---
   do i=1,nmax
      x(i)=0.0
   end do
 
   do i=1,nmax
      do j=1,nmax
-        d(i,j)=a(i,j)
+        d(i,j)=a(j,i)   ! ここで行列入れ替え (計算自体はこれで行う)
      end do
 
      ip(i)=i
 
-!-- ͤ׻롼 ---
+!-- 最大値を計算するループ ---
      s=d(i,1)
      do j=2,nmax
         if(d(i,j).gt.s)then
@@ -310,7 +487,7 @@ subroutine LU_devs( a, b, x, itermax )
         end if
      end do
 
-!-- ip(p)  ip(k) ؤ ---
+!-- ip(p) と ip(k) の入れ替え ---
      if(p.ne.k)then
         itemp=ip(p)
         ip(p)=ip(k)
@@ -329,7 +506,7 @@ subroutine LU_devs( a, b, x, itermax )
      end if
   end do
 
-!-- ʾõ ---
+!-- 前進消去 ---
   y(1)=b(ip(1))
   do i=2,nmax
      s1=0.0
@@ -339,7 +516,7 @@ subroutine LU_devs( a, b, x, itermax )
      y(i)=b(ip(i))-s1
   end do
 
-!--  ---
+!-- 後退代入 ---
   x(nmax)=y(nmax)/d(ip(nmax),nmax)
   do i=nmax-1,1,-1
      s2=0.0
@@ -359,23 +536,23 @@ subroutine LU_devs( a, b, x, itermax )
      end if
   end do
 
-!-- ȿ ---
-  eps=10**(-t4)                      ! ɸ٤ 10 ʿ t4 Ȥ
+!-- 反復改良 ---
+  eps=10**(-t4)                      ! 標準精度を 10 進数の t4 桁とする
 
   do iter=1,itermax
      if(xnorm==0.0)then
         exit
      end if
-!-- ĺη׻ ---
+!-- 残差の計算 ---
      do i=1,nmax
         s3=0.0
         do j=1,nmax
-           s3=s3+a(i,j)*x(j)
+           s3=s3+a(j,i)*x(j)  ! a は 1 要素目が行
         end do
         r(i)=b(i)-s3
      end do
 
-!-- ʾõ ---
+!-- 前進消去 ---
      y(1)=r(ip(1))
      do i=2,nmax
         s4=0.0
@@ -385,7 +562,7 @@ subroutine LU_devs( a, b, x, itermax )
         y(i)=r(ip(i))-s4
      end do
 
-!--  ---
+!-- 後退代入 ---
      dx(nmax)=y(nmax)/d(ip(nmax),nmax)
      do i=nmax-1,1,-1
         s5=0.0
@@ -418,31 +595,31 @@ end subroutine LU_devs
 !------------------------------------------
 
 subroutine Gau_Sei(a, b, eps, x)
-  ! ǥˡˤϢΩ 1 
+  ! ガウスザイデル法による連立 1 次方程式ソルバ
   implicit none
-  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
-  real, intent(inout) :: a(size(b),size(b))  !  ( 1 Ǥιʬɽ)
-  real, intent(in) :: eps  ! «
-  real, intent(inout) :: x(size(b))  ! 򤯲
-  integer :: i, j  ! ƥ졼ź
-  real :: xn  !  x(i) Υƥΰ
-  real :: err, err_max  ! 
+  real, intent(inout) :: b(:)  ! ax=b のベクトル
+  real, intent(inout) :: a(size(b),size(b))  ! 係数行列 (第 1 要素が行列の行成分を表す)
+  real, intent(in) :: eps  ! 収束条件
+  real, intent(inout) :: x(size(b))  ! 解く解
+  integer :: i, j  ! イテレーション用添字
+  real :: xn  ! 更新した x(i) のテンプ領域
+  real :: err, err_max  ! 誤差
   integer :: nx
-!-- ͤ 0.0 饹Ȥ ---
+!-- 初期値は 0.0 からスタートする ---
   x=0.0
   nx=size(b)
 
-!-- ԥܥåƥ
+!-- ピボッティング
   call Pivot_part( a, b )
 
-!-- ʲ, while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ ---
+!-- 以下, while を使用するため, 1 回目のイテレートは単独で行う ---
   err_max=0.0
   do i=1,nx
      xn=0.0
 
      do j=1,nx
         if(j/=i)then
-           xn=xn+a(i,j)*x(j)
+           xn=xn+a(j,i)*x(j)
         end if
      end do
 
@@ -458,7 +635,7 @@ subroutine Gau_Sei(a, b, eps, x)
 
   end do
 
-!-- ʲ, «ޤǥ롼פ ---
+!-- 以下より, 収束条件を満たすまでループする ---
   do while(err_max>=eps)
      err_max=0.0
      do i=1,nx
@@ -466,7 +643,7 @@ subroutine Gau_Sei(a, b, eps, x)
 
         do j=1,nx
            if(j/=i)then
-              xn=xn+a(i,j)*x(j)
+              xn=xn+a(j,i)*x(j)
            end if
         end do
 
@@ -487,34 +664,34 @@ end subroutine Gau_Sei
 !------------------------------------------
 
 subroutine Jacobi_algebra(a, b, eps, x)
-  ! 䥳ˡˤϢΩ 1 
+  ! ヤコビ法による連立 1 次方程式ソルバ
   implicit none
-  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
-  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤιԤɽ)
-  real, intent(in) :: eps  ! «
-  real, intent(inout) :: x(size(b))  ! 򤯲
-  real :: y(size(b))  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
-  integer :: i, j  ! ƥ졼ź
-  real :: err, err_max  ! 
+  real, intent(inout) :: b(:)  ! ax=b のベクトル
+  real, intent(inout) :: a(size(b),size(b))  ! 係数行列 (第 1 要素が行列の行を表す)
+  real, intent(in) :: eps  ! 収束条件
+  real, intent(inout) :: x(size(b))  ! 解く解
+  real :: y(size(b))  ! ヤコビ法で使用する一時格納用配列, この配列で一斉更新する.(xn の代わり)
+  integer :: i, j  ! イテレーション用添字
+  real :: err, err_max  ! 誤差
   integer :: nx
 
   nx=size(b)
 
-!-- ͤ 0,0 饹Ȥ ---
+!-- 初期値は 0,0 からスタートする ---
   x=0.0
   y=0.0
 
-!-- ԥܥåƥ
+!-- ピボッティング
   call Pivot_part( a, b )
 
-!-- ʲ, ºݤΥ(while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ) ---
+!-- 以下, 実際のソルバ(while を使用するため, 1 回目のイテレートは単独で行う) ---
   err_max=0.0
   do i=1,nx
      y(i)=0.0
 
      do j=1,nx
         if(j/=i)then
-           y(i)=y(i)+a(i,j)*x(j)
+           y(i)=y(i)+a(j,i)*x(j)
         end if
      end do
 
@@ -527,11 +704,11 @@ subroutine Jacobi_algebra(a, b, eps, x)
      end if
   end do
 
-  do i=1,nx  ! ǡΰƹ
+  do i=1,nx  ! データの一斉更新
      x(i)=y(i)
   end do
 
-!-- ʲ, «ޤǥ롼פ ---
+!-- 以下より, 収束条件を満たすまでループする ---
   do while(err_max>=eps)
      err_max=0.0
      do i=1,nx
@@ -539,7 +716,7 @@ subroutine Jacobi_algebra(a, b, eps, x)
 
         do j=1,nx
            if(j/=i)then
-              y(i)=y(i)+a(i,j)*x(j)
+              y(i)=y(i)+a(j,i)*x(j)
            end if
         end do
 
@@ -551,7 +728,7 @@ subroutine Jacobi_algebra(a, b, eps, x)
         end if
      end do
 
-     do i=1,nx  ! ǡΰƹ
+     do i=1,nx  ! データの一斉更新
         x(i)=y(i)
      end do
   end do
@@ -561,42 +738,42 @@ end subroutine Jacobi_algebra
 !------------------------------------------
 
 subroutine SOR_Gau_Sei(a, b, eps, accel, x)
-  ! ǥˡ, SOR ǲ®ˤϢΩ 1 
+  ! ガウスザイデル法かつ, SOR で加速による連立 1 次方程式ソルバ
   implicit none
-  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
-  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤιԤɽ)
-  real, intent(in) :: eps  ! «
-  real, intent(in) :: accel  ! ®. , Ū accel >= 2 ǤȯΤ,
-                             ! Ͱʾ夬ꤵȥ顼ǻߤ.
-  real, intent(inout) :: x(size(b))  ! 򤯲
-  integer :: i, j  ! ƥ졼ź
-  real :: xn  !  x(i) Υƥΰ
-  real :: err, err_max  ! 
+  real, intent(inout) :: b(:)  ! ax=b のベクトル
+  real, intent(inout) :: a(size(b),size(b))  ! 係数行列 (第 1 要素が行列の行を表す)
+  real, intent(in) :: eps  ! 収束条件
+  real, intent(in) :: accel  ! 加速係数. ただし, 数学的に accel >= 2 では発散するので,
+                             ! この値以上が設定されるとエラーで止める.
+  real, intent(inout) :: x(size(b))  ! 解く解
+  integer :: i, j  ! イテレーション用添字
+  real :: xn  ! 更新した x(i) のテンプ領域
+  real :: err, err_max  ! 誤差
   integer :: nx
 
   nx=size(b)
 
-!-- ®ѥ᡼γǧ
+!-- 加速パラメータの確認
   if(accel>=2.0)then
      write(*,*) "***** ERROR *****"
      write(*,*) "accel parameter must be less than 2.0. STOP."
      stop
   end if
 
-!-- ͤ 0.0 饹Ȥ ---
+!-- 初期値は 0.0 からスタートする ---
   x=0.0
 
-!-- ԥܥåƥ
+!-- ピボッティング
   call Pivot_part( a, b )
 
-!-- ʲ, while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ ---
+!-- 以下, while を使用するため, 1 回目のイテレートは単独で行う ---
   err_max=0.0
   do i=1,nx
      xn=0.0
 
      do j=1,nx
         if(j/=i)then
-           xn=xn+a(i,j)*x(j)
+           xn=xn+a(j,i)*x(j)
         end if
      end do
 
@@ -613,7 +790,7 @@ subroutine SOR_Gau_Sei(a, b, eps, accel, x)
 
   end do
 
-!-- ʲ, «ޤǥ롼פ ---
+!-- 以下より, 収束条件を満たすまでループする ---
   do while(err_max>=eps)
      err_max=0.0
      do i=1,nx
@@ -621,7 +798,7 @@ subroutine SOR_Gau_Sei(a, b, eps, accel, x)
 
         do j=1,nx
            if(j/=i)then
-              xn=xn+a(i,j)*x(j)
+              xn=xn+a(j,i)*x(j)
            end if
         end do
 
@@ -643,43 +820,43 @@ end subroutine SOR_Gau_Sei
 !------------------------------------------
 
 subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
-  ! 䥳ˡ SOR ®ˤϢΩ 1 
+  ! ヤコビ法かつ SOR 加速による連立 1 次方程式ソルバ
   implicit none
-  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
-  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤιԤɽ)
-  real, intent(in) :: eps  ! «
-  real, intent(in) :: accel  ! ®. , Ū accel >= 2 ǤȯΤ,
-                             ! Ͱʾ夬ꤵȥ顼ǻߤ.
-  real, intent(inout) :: x(size(b))  ! 򤯲
-  real :: y(size(b))  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
-  integer :: i, j  ! ƥ졼ź
-  real :: err, err_max  ! 
+  real, intent(inout) :: b(:)  ! ax=b のベクトル
+  real, intent(inout) :: a(size(b),size(b))  ! 係数行列 (第 1 要素が行列の行を表す)
+  real, intent(in) :: eps  ! 収束条件
+  real, intent(in) :: accel  ! 加速係数. ただし, 数学的に accel >= 2 では発散するので,
+                             ! この値以上が設定されるとエラーで止める.
+  real, intent(inout) :: x(size(b))  ! 解く解
+  real :: y(size(b))  ! ヤコビ法で使用する一時格納用配列, この配列で一斉更新する.(xn の代わり)
+  integer :: i, j  ! イテレーション用添字
+  real :: err, err_max  ! 誤差
   integer :: nx
 
   nx=size(b)
 
-!-- ®ѥ᡼γǧ
+!-- 加速パラメータの確認
   if(accel>=2.0)then
      write(*,*) "***** ERROR *****"
      write(*,*) "accel parameter must be less than 2.0. STOP."
      stop
   end if
 
-!-- ͤ 0,0 饹Ȥ ---
+!-- 初期値は 0,0 からスタートする ---
   x=0.0
   y=0.0
 
-!-- ԥܥåƥ
+!-- ピボッティング
   call Pivot_part( a, b )
 
-!-- ʲ, ºݤΥ(while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ) ---
+!-- 以下, 実際のソルバ(while を使用するため, 1 回目のイテレートは単独で行う) ---
   err_max=0.0
   do i=1,nx
      y(i)=0.0
 
      do j=1,nx
         if(j/=i)then
-           y(i)=y(i)+a(i,j)*x(j)
+           y(i)=y(i)+a(j,i)*x(j)
         end if
      end do
 
@@ -692,11 +869,11 @@ subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
      end if
   end do
 
-  do i=1,nx  ! ǡΰƹ
+  do i=1,nx  ! データの一斉更新
      x(i)=x(i)+accel*(y(i)-x(i))
   end do
 
-!-- ʲ, «ޤǥ롼פ ---
+!-- 以下より, 収束条件を満たすまでループする ---
   do while(err_max>=eps)
      err_max=0.0
      do i=1,nx
@@ -704,7 +881,7 @@ subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
 
         do j=1,nx
            if(j/=i)then
-              y(i)=y(i)+a(i,j)*x(j)
+              y(i)=y(i)+a(j,i)*x(j)
            end if
         end do
 
@@ -717,7 +894,7 @@ subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
         end if
      end do
 
-     do i=1,nx  ! ǡΰƹ
+     do i=1,nx  ! データの一斉更新
         x(i)=y(i)
      end do
   end do
@@ -725,16 +902,16 @@ subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
 end subroutine SOR_Jacobi_algebra
 
 !-----------------------------------------
-! ʲ, ͭΤΥ롼
+! 以下, 固有値問題求解のためのルーチン
 !-----------------------------------------
 
 subroutine eigenvalue_power( a, eps, eigenval, eigenvec )
-! ٤ˡѤƹκͭͤȤθͭͤбͭ٥ȥ.
+! べき乗法を用いて行列の最大固有値とその固有値に対応する固有ベクトルを求める.
   implicit none
-  real, intent(inout) :: eigenvec(:)  ! ͭ٥ȥ
-  real, intent(in) :: a(size(eigenvec),size(eigenvec))  ! ͭͤ ( 1 ǤԤɽ)
-  real, intent(in) :: eps  ! «Ƚ
-  real, intent(inout) :: eigenval  !  a κͭ
+  real, intent(inout) :: eigenvec(:)  ! 固有ベクトル
+  real, intent(in) :: a(size(eigenvec),size(eigenvec))  ! 固有値を求める行列 (第 1 要素が行を表す)
+  real, intent(in) :: eps  ! 収束判定条件
+  real, intent(inout) :: eigenval  ! 行列 a の最大固有値
   integer :: i, j
   real, dimension(size(eigenvec)) :: x, y
   real :: tmp1, tmp2, err_max
@@ -743,45 +920,45 @@ subroutine eigenvalue_power( a, eps, eigenval, eigenvec )
   nx=size(eigenvec)
 
   do i=1,nx
-     x(i)=1.0  ! ȿˡνͤȤ󥼥Υ٥ȥ
+     x(i)=1.0  ! 反復法の初期値として非ゼロのベクトルを定義
   end do
 
-  tmp1=sqrt(vec_dot( x, x ))  ! ٥ȥΥΥ׻
+  tmp1=sqrt(vec_dot( x, x ))  ! 初期ベクトルのノルムを計算
 
   do i=1,nx
-     x(i)=x(i)/tmp1  ! ٥ȥ򵬳ʲ
+     x(i)=x(i)/tmp1  ! 初期ベクトルを規格化
   end do
 
-  err_max=eps  ! while ʸ뤿ν
+  err_max=eps  ! while 文に入れるための処理
 
-!-- ȿˡ
+!-- 反復法開始
 
   do while(err_max>=eps)
      err_max=0.0
      do i=1,nx
-        y(i)=0.0  ! ν
+        y(i)=0.0  ! 配列の初期化
         do j=1,nx
-           y(i)=y(i)+a(i,j)*x(j)
+           y(i)=y(i)+a(j,i)*x(j)
         end do
      end do
 
-     tmp1=sqrt(vec_dot( y, y ))  ! ٥ȥΥΥ׻
+     tmp1=sqrt(vec_dot( y, y ))  ! ベクトルのノルムを計算
 
      do i=1,nx
-        x(i)=y(i)/tmp1  ! x(i) ι
+        x(i)=y(i)/tmp1  ! x(i) の更新
      end do
 
-!-- ͭͷ׻
-     tmp2=vec_dot( x, y )  ! Ƿ׻ Ay  y^t (Ĥޤ, ͭ٥ȥž) 򤫤.
-     err_max=errata( eigenval, tmp2, 1 )  !  x(i) ȹ y(i) θ
+!-- 固有値計算
+     tmp2=vec_dot( x, y )  ! 上で計算した Ay に y^t (つまり, 固有ベクトルの転置) をかける.
+     err_max=errata( eigenval, tmp2, 1 )  ! 過去の x(i) と更新した y(i) の誤差比較
      eigenval=tmp2
 
   end do
 
-!-- ȿˡλ
+!-- 反復法終了
 
   do i=1,nx
-     eigenvec(i)=x(i)  ! ͭ٥ȥѿ
+     eigenvec(i)=x(i)  ! 固有ベクトルの変数へ代入
   end do
 
 end subroutine eigenvalue_power
@@ -790,14 +967,14 @@ end subroutine eigenvalue_power
 !------------------------------------------
 
 subroutine Jacobi_eigen( a, lambda, eps )
-! Jacobi ˡѤƸͭͤ׻롼.
-! ܥ롼Ǥ, ׻оݤȤʤ n μоιǤʤФʤʤ.
+! Jacobi 法を用いて固有値を計算するルーチン.
+! 本ルーチンでは, 計算対象となる行列は n 次の実対称行列でなければならない.
   implicit none
-  real, intent(in) :: a(:,:)  ! ͭͤ׻оι.
-                              !  1 Ǥ,  2 Ǥʬ򤽤줾ɽ.
-  real, intent(inout) :: lambda(size(a,1))  ! Ƹͭ
-  real, intent(in), optional :: eps  ! ȿ׻μ« [и]
-                                     ! ǥեȤǤ, 1.0e-6
+  real, intent(in) :: a(:,:)  ! 固有値を計算する実対称行列.
+                              ! 第 1 要素が行, 第 2 要素が列成分をそれぞれ表す.
+  real, intent(inout) :: lambda(size(a,1))  ! 各固有値
+  real, intent(in), optional :: eps  ! 反復計算の収束条件 [絶対誤差]
+                                     ! デフォルトでは, 1.0e-6
   integer :: i, j, k, n, m, l
   real :: tmp_a(size(a,1),size(a,2)), new_a(size(a,1),size(a,2))
   real :: error, err_max, tan2, cos2, sin2
@@ -810,26 +987,26 @@ subroutine Jacobi_eigen( a, lambda, eps )
      error=1.0e-6
   end if
 
-!-- intent(in) °ʤΤ, tmp 
+!-- intent(in) 属性なので, tmp へ入れ込む
 
   do j=1,n
      do i=1,n
-        tmp_a(i,j)=a(i,j)
-        new_a(i,j)=a(i,j)
+        tmp_a(i,j)=a(j,i)  ! 行列入れ替え
+        new_a(i,j)=a(j,i)  ! 行列入れ替え
      end do
   end do
 
-!-- ºݤ˷׻.
+!-- 実際に計算させる.
 
   err_max=eps
 
   do while (err_max>=eps)
      err_max=0.0
-     do j=1,n-1  ! ƹԤˤĤƽ
-        do i=j+1,n  ! 廰ѤΤ߹Ԥ, гʬϰդ˵.
+     do j=1,n-1  ! 各行について順に操作
+        do i=j+1,n  ! 上三角のみ行えば, 対角成分は一意に求められる.
            if(tmp_a(i,j)/=0.0)then
-              ! ʲ, 幹Ѥη׻
-              if(tmp_a(i,i)/=tmp_a(j,j))then  ! гʬνŲ
+              ! 以下で, 井桁更新用の係数を計算
+              if(tmp_a(i,i)/=tmp_a(j,j))then  ! 対角成分の重解を処理
                  tan2=2.0*tmp_a(i,j)/(tmp_a(i,i)-tmp_a(j,j))
                  cos2=sqrt(0.5*(1.0+1.0/sqrt(1.0+tan2*tan2)))
                  if(tan2>=0.0)then
@@ -837,17 +1014,17 @@ subroutine Jacobi_eigen( a, lambda, eps )
                  else
                     sin2=-sqrt(0.5*(1.0-1.0/sqrt(1.0+tan2*tan2)))
                  end if
-              else  ! ξ, tan2=\infty ʤΤ,
+              else  ! この場合, tan2=\infty なので,
                  cos2=sqrt(0.5)
-                 if(tmp_a(i,j)>=0.0)then  ! ʤ, \pi / 4
+                 if(tmp_a(i,j)>=0.0)then  ! 係数が正なら, \pi / 4
                     sin2=sqrt(0.5)
                  else
                     sin2=-sqrt(0.5)
                  end if
               end if
-              ! ʹߤǼºݤ˰򹹿
-              new_a(i,j)=0.0  !  2 Ĥ˷׻Ƥ. 
-              new_a(j,i)=0.0  ! (ȤƱ׻ 2 ԤΤ򤹤뤿)
+              ! 以降で実際に井桁を更新
+              new_a(i,j)=0.0  ! これら 2 つは先に計算しておく. 
+              new_a(j,i)=0.0  ! (あとで同じ計算を 2 回行うのを回避するため)
               do k=1,n
                  if(k/=i.and.k/=j)then
                     new_a(i,k)=tmp_a(i,k)*cos2+tmp_a(j,k)*sin2
@@ -864,12 +1041,12 @@ subroutine Jacobi_eigen( a, lambda, eps )
                     end if
                  end if
               end do
-              ! ʲ, new_a -> tmp_a ᤷ, Ʊ˺.
+              ! 以下で, new_a -> tmp_a に戻し, 同時に最大誤差を求める.
               do m=1,n
                  do l=1,n
                     error=abs(new_a(l,m)-tmp_a(l,m))
                     tmp_a(l,m)=new_a(l,m)
-                    if(error>err_max)then  ! κͤ.
+                    if(error>err_max)then  ! 誤差の最大値を求める.
                        err_max=error
                     end if
                  end do
@@ -889,23 +1066,23 @@ end subroutine Jacobi_eigen
 !-----------------------------------------
 
 subroutine QR_method( a, lambda, p, eps, sym_opt )
-! QR ʬˡѤƹ a ͭͤ׻롼.
-! ʸ (2007) 4.8.
-! ʲ줿ͭ٥ȥ褦ˤƤ뤬, ͤΤɤ̤ǧ.
-! ͭͤ˴ؤƤ꤫ǧѤ.
-! ׻ȤƤ,
-! 1. Householder Ѵ
-! 2. ľη׻
-! 3. QR ʬ
-! 4. QR 
+! QR 分解法を用いて行列 a の全固有値を計算するルーチン.
+! 参考文献は川上 (2007) 4.8.
+! 規格化された固有ベクトルも求めるようにしているが, 値が正確かどうかは未確認.
+! 固有値に関しては例題から確認済み.
+! 計算順序としては,
+! 1. Householder 変換
+! 2. 直交行列の計算
+! 3. QR 分解
+! 4. QR 逆積
   implicit none
-  real, intent(in) :: a(:,:)  ! ͭͤ [ 1 Ǥ]
-  real, intent(inout) :: lambda(size(a,1))  ! a θͭ
-  real, intent(inout), optional :: p(size(a,1),size(a,2))  ! ͭ٥ȥ.
-                       ! ֤ˤ, Householder Ѵν֤٤ʤ.
-  real, intent(in), optional :: eps  ! ȿˡμ« default = 1.0e-5
-  logical, intent(in), optional :: sym_opt  ! a оι.
-                              ! .true. = оι, default = .false.
+  real, intent(in) :: a(:,:)  ! 固有値を求める行列 [第 1 要素が行]
+  real, intent(inout) :: lambda(size(a,1))  ! a の固有値
+  real, intent(inout), optional :: p(size(a,1),size(a,2))  ! 固有ベクトル.
+                       ! これを返すには, Householder 変換時の処理時間が遅くなる.
+  real, intent(in), optional :: eps  ! 反復法の収束条件 default = 1.0e-5
+  logical, intent(in), optional :: sym_opt  ! a が対称行列か.
+                              ! .true. = 対称行列, default = .false.
   integer :: i, j, k, n, counter
   real :: dia, s, t, err, err_max, tmp1, tmp2, mu
   real, dimension(size(a,1),size(a,2)) :: a0, q, r, b, tmp_p, tmp_pp
@@ -932,7 +1109,7 @@ subroutine QR_method( a, lambda, p, eps, sym_opt )
      err_max=1.0e-5
   end if
 
-!-- 1. Householder Ѵ.
+!-- 1. Householder 変換.
   if(pconv_flag.eqv..true.)then
      call Householder( a, a0, p=tmp_p, sym_opt=sym_link )
   else
@@ -944,10 +1121,10 @@ subroutine QR_method( a, lambda, p, eps, sym_opt )
   do while(counter>1)
      err=err_max
      do while(err_max<=err)
-        q=0.0   ! QR ʬ Q_k 
+        q=0.0   ! QR 分解の Q_k に相当
 
         do k=1,n
-           q(k,k)=1.0    ! ǽñ̹Ȥƽ
+           q(k,k)=1.0    ! 最初に単位行列として初期化
         end do
 
         mu=a0(counter,counter)
@@ -956,7 +1133,7 @@ subroutine QR_method( a, lambda, p, eps, sym_opt )
            a0(k,k)=a0(k,k)-mu    ! moving original point
         end do
 
-!-- QR ʬԤ.
+!-- QR 分解を行う.
         do k=1,counter-1
            dia=sqrt(abs(a0(k,k))**2+abs(a0(k+1,k))**2)
            s=a0(k+1,k)/dia
@@ -982,13 +1159,13 @@ subroutine QR_method( a, lambda, p, eps, sym_opt )
 
         do j=1,counter
            do i=1,counter
-              r(i,j)=a0(i,j)     ! QR ʬ줿廰ѹ R
+              r(i,j)=a0(i,j)     ! QR 分解で得られた上三角行列 R
            end do
         end do
 
-!-- QR εѤ׻. A=RQ , R Ͼ廰, Q ϥإå٥륰ʤΤ,
+!-- QR の逆積を計算する. A=RQ で, R は上三角, Q はヘッセンベルグなので,
 !-- a_{i,j} = R_{i,k} * Q_{k,j} + R_{i,k+1} * Q_{k+1,j}, (k=i)
-!-- , Q ž֤Ƿ׻Τ, Q=qT Ȥ, Q_{k,j} = q_{j,k}.
+!-- ただし, Q は転置で計算されるので, Q=qT とすると, Q_{k,j} = q_{j,k}.
 !-- a_{i,j} = R_{i,k} * q_{j,k} + R_{i,k+1} * q_{j,k+1}, (k=i)
 
         call mat_dot( r, q, a0 )
@@ -998,7 +1175,7 @@ subroutine QR_method( a, lambda, p, eps, sym_opt )
            a0(i,i)=a0(i,i)+mu
         end do
 
-!-- «Ƚ
+!-- 収束判定条件
         if(abs(err_max)>abs(a0(counter,counter-1)))then
            err=abs(a0(counter,counter-1))
         end if
@@ -1027,21 +1204,21 @@ end subroutine QR_method
 !-----------------------------------------
 
 subroutine Householder( a, b, p, sym_opt )
-! ϥۥѴѤ, Ǥռоιإå٥륰Ѵ.
-! , Υ롼ǤϷ׻®٤θ, гѤξ廰ʬϷ׻ʤ.
-! оιξ, 廰ʬϲʬƱˤʤΤ,
-! 廰ʬͤ, b βʬФ褤.
-! ͤ (2007)  4.5.2.
+! ハウスホルダー変換を用いて, 任意実非対称行列をヘッセンベルグ行列に変換する.
+! ただし, このルーチンでは計算速度を考慮して, 非対角の上三角成分は計算しない.
+! 対称行列の場合, 上三角成分は下三角成分と同じになるので,
+! 上三角成分の値を得たい場合は, b の下三角成分を求めればよい.
+! 参考は川上 (2007) の 4.5.2.
   implicit none
-  real, intent(in) :: a(:,:)   ! Ǥդμоι
-  real, intent(inout) :: b(size(a,1),size(a,2))  ! إå٥륰
-  real, intent(inout), optional :: p(size(a,1),size(a,2))  ! ѴѤľ
-                                   ! ֤, Ѥ˷׻ԤΤ,
-                                   ! ׻֤٤ʤ뤳Ȥ.
-  logical, intent(in), optional :: sym_opt   ! a оι󤫤ɤ.
-                       ! default = .false. (оΤǤϤʤ)
-                       ! .true. ξ, b оʬ򤽤Τޤ֤.
-                       ! ׻®٤θ̾оʬ׻ʤ.
+  real, intent(in) :: a(:,:)   ! 任意の実非対称行列
+  real, intent(inout) :: b(size(a,1),size(a,2))  ! ヘッセンベルグ行列
+  real, intent(inout), optional :: p(size(a,1),size(a,2))  ! 変換に用いた直交行列
+                                   ! これを返す場合, 専用に計算処理を行うので,
+                                   ! 計算時間が遅くなることに注意.
+  logical, intent(in), optional :: sym_opt   ! a が対称行列かどうか.
+                       ! default = .false. (対称ではない)
+                       ! .true. の場合, b の対称成分をそのまま返す.
+                       ! 計算速度を考慮して通常は対称成分を計算しない.
   integer :: i, j, k, n
   real :: coe, s, t, tmp
   real, allocatable, dimension(:) :: w, pconv, qconv
@@ -1081,7 +1258,7 @@ subroutine Householder( a, b, p, sym_opt )
         qconv=0.0
         w=0.0
         tmp_p=0.0
-     !-- Ѵκ
+     !-- 変換行列の作成
         t=sum_sq( b(j+1:n,j) )
         if(b(j+1,j)>0.0)then
            s=sqrt(t)
@@ -1091,7 +1268,7 @@ subroutine Householder( a, b, p, sym_opt )
 
         w(1:j)=0.0
         w(j+1)=b(j+1,j)+s
-        coe=1.0/(t+b(j+1,j)*s)   ! η (2007)  c ǤϤʤ, 2c Ǥ.
+        coe=1.0/(t+b(j+1,j)*s)   ! この係数は川上 (2007) の c ではなく, 2c である.
         w(j+2:n)=b(j+2:n,j)
 
         do k=j+1,n
@@ -1108,7 +1285,7 @@ subroutine Householder( a, b, p, sym_opt )
            qconv(k)=pconv(k)-0.5*coe*qconv(k)*w(k)
         end do
 
-     !-- ѴˤѴ
+     !-- 変換行列による変換
 
         b(j+1,j)=-s
         b(j+2:n,j)=0.0
@@ -1120,7 +1297,7 @@ subroutine Householder( a, b, p, sym_opt )
         end do
 
         if(pconv_flag.eqv..true.)then
-           do k=j+1,n   ! w  j+1 ʾʬΤ󥼥.
+           do k=j+1,n   ! w は j+1 以上の成分のみ非ゼロ.
               do i=j+1,n
                  tmp_p(i,k)=-coe*w(i)*w(k)
               end do
@@ -1146,14 +1323,14 @@ subroutine Householder( a, b, p, sym_opt )
         end do
      end do
 
-  else   ! оιξ (ޤбƤʤ.)
+  else   ! 非対称行列の場合 (まだ対応していない.)
 
      do j=1,n-2
         pconv=0.0
         qconv=0.0
         w=0.0
         tmp_p=0.0
-     !-- Ѵκ
+     !-- 変換行列の作成
         t=sum_sq( b(j+1:n,j) )
         if(b(j+1,j)>0.0)then
            s=sqrt(t)
@@ -1163,7 +1340,7 @@ subroutine Householder( a, b, p, sym_opt )
 
         w(1:j)=0.0
         w(j+1)=b(j+1,j)+s
-        coe=1.0/(t+b(j+1,j)*s)   ! η (2007)  c ǤϤʤ, 2c Ǥ.
+        coe=1.0/(t+b(j+1,j)*s)   ! この係数は川上 (2007) の c ではなく, 2c である.
         w(j+2:n)=b(j+2:n,j)
 
         do k=j+1,n
@@ -1180,7 +1357,7 @@ subroutine Householder( a, b, p, sym_opt )
            qconv(k)=pconv(k)-0.5*coe*qconv(k)*w(k)
         end do
 
-     !-- ѴˤѴ
+     !-- 変換行列による変換
 
         b(j+1,j)=-s
         b(j+2:n,j)=0.0
@@ -1192,7 +1369,7 @@ subroutine Householder( a, b, p, sym_opt )
         end do
 
         if(pconv_flag.eqv..true.)then
-           do k=j+1,n   ! w  j+1 ʾʬΤ󥼥.
+           do k=j+1,n   ! w は j+1 以上の成分のみ非ゼロ.
               do i=j+1,n
                  tmp_p(i,k)=-coe*w(i)*w(k)
               end do
@@ -1220,24 +1397,24 @@ end subroutine Householder
 !-----------------------------------------
 
 subroutine schumit_norm( u, v )
-! ߥåȤľˡѤ, nx ٥ȥľ򲽤.
-!  1 Ǥ٥ȥγʬ,  2 ʬ٥ȥ뷲 1 ٥ȥɽ.
-! Ĥޤ, u(i,j)  j ܥ٥ȥ i ʬȤȤɽ.
-! ɽʤ, ĥ٥ȥ򲣤¤٤.
-! ܥ롼ϥߥåȤľ򲽤ܤ˷׻ƤΤ,
-! ׻®٤Ū٤餷.
+! シュミットの直交化法を用いて, nx 次元ベクトルを正規直交化する.
+! 引数の配列は第 1 要素がベクトルの各成分, 第 2 成分がベクトル群の 1 ベクトルを表す.
+! つまり, u(i,j) は j 番目ベクトルの第 i 成分ということを表す.
+! 行列で表現するなら, 縦ベクトルを横に並べた形と等しい.
+! 本ルーチンはシュミットの直交化を真面目に計算しているので,
+! 計算速度は比較的遅いらしい.
   implicit none
-  real, intent(in) :: u(:,:)  ! ľ򲽤Υ٥ȥ
-  real, intent(inout) :: v(size(u,1),size(u,2))  ! ľ򲽸Υ٥ȥ
+  real, intent(in) :: u(:,:)  ! 直交化する前のベクトル
+  real, intent(inout) :: v(size(u,1),size(u,2))  ! 直交化後のベクトル
   integer :: i, j, k, nx, ny
-  real :: tmpn(size(u,2))  ! ԤȤ, ΥͤǼ.
-  real :: tmps(size(u,1))  ! ±黻κݤΰǼ˻.
+  real :: tmpn(size(u,2))  ! 正規化を行うときの, ノルムの値を格納する.
+  real :: tmps(size(u,1))  ! 総和演算の際の一時格納に使用.
 
   nx=size(u,1)
   ny=size(u,2)
 
   tmpn(1)=sqrt(vec_dot( u(:,1), u(:,1) ))
-  do i=1,nx  ! 1 ܤΥ٥ȥδȤ.
+  do i=1,nx  ! 1 本目のベクトルを基底の基準とする.
      v(i,1)=u(i,1)/tmpn(1)
   end do
 
@@ -1254,7 +1431,7 @@ subroutine schumit_norm( u, v )
      do i=1,nx
         v(i,j)=u(i,j)-tmps(i)
      end do
-! ʲԤ
+! 以下で正規化を行う
      tmpn(j)=sqrt(vec_dot( v(:,j), v(:,j) ))
      do i=1,nx
         v(i,j)=v(i,j)/tmpn(j)
@@ -1266,15 +1443,15 @@ end subroutine schumit_norm
 !-----------------------------------------
 !-----------------------------------------
 
-!-- ʲ, ȯ !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!-- 以下, 開発中 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 subroutine eigen_power_all( a, lambda, eigen_vec, eps )
-!  ٤ˡѤ, a ˤĤƤƤθͭͤȤȼͭ٥ȥ
-!  ׻롼.
+!  べき乗法を用いて, a についての全ての固有値とそれに伴う固有ベクトルを
+!  計算するルーチン.
   implicit none
-  real, intent(in) :: a(:,:)  ! ͭͤ [ 1 Ǥ]
-  real, intent(inout) :: lambda(size(a,1))  ! a θͭ
-  real, intent(inout) :: eigen_vec(size(a,1),size(a,2))  ! lambda(i) бͭ٥ȥ, Ǥͭ lambda(i) бƤ.
-  real, intent(in), optional :: eps  ! ȿˡμ«
+  real, intent(in) :: a(:,:)  ! 固有値を求める行列 [第 1 要素が行]
+  real, intent(inout) :: lambda(size(a,1))  ! a の固有値
+  real, intent(inout) :: eigen_vec(size(a,1),size(a,2))  ! lambda(i) に対応する固有ベクトル, 第一要素が固有値 lambda(i) に対応している.
+  real, intent(in), optional :: eps  ! 反復法の収束条件
   integer :: n
 
   n=size(a,1)
@@ -1285,33 +1462,40 @@ subroutine eigen_power_all( a, lambda, eigen_vec, eps )
 end subroutine
 
 !-----------------------------------------
-! ʲ, private °դ롼
+! 以下, private 属性を付けたルーチン
 !-----------------------------------------
 
 subroutine Pivot_part( a, b )
-! гʬ¸ߤ를ԥܥåƥ󥰤ˤä󥼥֤ͤ.
+! 対角成分に存在するゼロをピボッティングによって非ゼロ値に置き換える.
   implicit none
-  real, intent(inout) :: b(:)  ! ԥܥåƥ󥰤ȤȤ֤뱦ե٥ȥ
-  real, intent(inout) :: a(size(b),size(b))  ! ԥܥåƥ󥰤Ԥ ( 1 ǤԤб)
-  real :: tmp(size(b))  ! ؤΰ
-  real :: tmpv  ! ؤȼ b(i) 򤵤ѿ
+  real, intent(inout) :: b(:)  ! ピボッティングとともに置き換えられる右辺ベクトル
+  real, intent(inout) :: a(size(b),size(b))  ! ピボッティングを行う行列 (第 1 要素が行に対応)
+  real :: tmp(size(b))  ! 入れ替え時の一時退避配列
+  real :: tmpa(size(b),size(b))  ! 1 要素が「列」に対応)
+  real :: tmpv  ! 入れ替えに伴う b(i) を退避させる変数
   integer :: i, j, k
   integer :: nx
 
   nx=size(b)
 
+  do j=1,nx
+     do i=1,nx
+        tmpa(j,i)=a(i,j)  ! ここで行と列を入れ替え
+     end do
+  end do
+
   do i=1,nx
-     if(a(i,i)==0.0)then
-        do j=1,nx  !  do  j=1 ֤Ԥõ
-! ʲȽ̼ϼ̤
-! a(i,i)==0 ʤΤ, j ܤ i 󤬥ǤʤԤõ a(j,i)/=0.
-!  j ܤؤ뤬, ؤȤ,  i ܤˤä j ؤȤ
-! j ܤгʬ a(j,j) ˤʤʤ褦 a(i,j)/=0  j ꤹ.
-           if(a(i,j)/=0.0.and.a(j,i)/=0.0.and.i/=j)then
-              do k=1,nx  ! ºݤؤ
-                 tmp(k)=a(i,k)
-                 a(i,k)=a(j,k)
-                 a(j,k)=tmp(k)
+     if(tmpa(i,i)==0.0)then
+        do j=1,nx  ! この do で j=1 から置き換える行を探索
+! 以下の判別式は次の通り
+! a(i,i)==0 なので, j 行目の i 列がゼロでない行を探す a(j,i)/=0.
+! その j 行目と入れ替えるが, 入れ替えたとき, 元は i 行目にあった j 列が入れ替えたとき
+! j 行目の対角成分 a(j,j) がゼロにならないような a(i,j)/=0 行 j を特定する作業.
+           if(tmpa(i,j)/=0.0.and.tmpa(j,i)/=0.0.and.i/=j)then
+              do k=1,nx  ! 実際に配列の入れ替え
+                 tmp(k)=tmpa(i,k)
+                 tmpa(i,k)=tmpa(j,k)
+                 tmpa(j,k)=tmp(k)
               end do
               tmpv=b(i)
               b(i)=b(j)
@@ -1322,15 +1506,21 @@ subroutine Pivot_part( a, b )
      end if
   end do
 
+  do j=1,nx
+     do i=1,nx
+        a(j,i)=tmpa(i,j)  ! ここで行と列を入れ替え
+     end do
+  end do
+
 end subroutine Pivot_part
 
 !-----------------------------------------
 
 real function errata(x1, x2, n)
   implicit none
-  real, intent(in) :: x1  ! 
-  real, intent(in) :: x2  ! 
-  integer, intent(in) :: n  ! μ (n=1 : и, n=2 : и)
+  real, intent(in) :: x1  ! 誤差比較
+  real, intent(in) :: x2  ! 誤差比較
+  integer, intent(in) :: n  ! 誤差の種類 (n=1 : 相対誤差, n=2 : 絶対誤差)
 
   if(n==1)then
      if(abs(x1)==0.0)then
@@ -1348,7 +1538,7 @@ end function errata
 !-----------------------------------------
 
 real function vec_dot( u, v )
-! ǤդμΥ٥ȥѤ׻
+! 任意の次元のベクトル内積を計算する
   implicit none
   real, intent(in) :: u(:)
   real, intent(in) :: v(size(u))
@@ -1370,7 +1560,7 @@ end function
 !-----------------------------------------
 
 real function sum_sq( a )
-! Ǥդ 1 Ǥγʬ 2 ¤׻.
+! 任意の 1 次元要素の各成分の 2 乗和を計算する.
   implicit none
   real, intent(in) :: a(:)
   integer :: i, n
