@@ -2,7 +2,7 @@
 ! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 
-module Poly_Function  ! ľ¿༰׻륵֥롼
+module Poly_Function  ! 直交多項式を計算するサブルーチン集
 
   use special_function
 
@@ -58,18 +58,18 @@ end interface SONINE
 contains
 subroutine CHEBYSHEV_f(n, x, che)
 !****************************************
-!*** ӥΥ֥롼 ***
+!*** チェビシェフ漸化式のサブルーチン ***
 !****************************************
   implicit none
-  integer, intent(in) :: n  ! ׻ӥդκǹ⼡
-  real, intent(in) :: x(:)  ! ӥ¿༰ΰ
-  real, intent(inout) :: che(0:n,size(x))  ! ׻ӥ¿༰
+  integer, intent(in) :: n  ! 計算するチェビシェフの最高次数
+  real, intent(in) :: x(:)  ! チェビシェフ多項式の引数
+  real, intent(inout) :: che(0:n,size(x))  ! 計算するチェビシェフ多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      che(0,i)=1.0
   end do
@@ -81,7 +81,7 @@ subroutine CHEBYSHEV_f(n, x, che)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               che(j+1,i)=2.0*che(1,i)*che(j,i)-che(j-1,i)
@@ -94,18 +94,18 @@ end  subroutine
 
 subroutine CHEBYSHEV_d(n, x, che)
 !****************************************
-!*** ӥΥ֥롼 ***
+!*** チェビシェフ漸化式のサブルーチン ***
 !****************************************
   implicit none
-  integer, intent(in) :: n  ! ׻ӥդκǹ⼡
-  double precision, intent(in) :: x(:)  ! ӥ¿༰ΰ
+  integer, intent(in) :: n  ! 計算するチェビシェフの最高次数
+  double precision, intent(in) :: x(:)  ! チェビシェフ多項式の引数
   double precision, intent(inout) :: che(0:n,size(x))
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      che(0,i)=1.0d0
   end do
@@ -117,7 +117,7 @@ subroutine CHEBYSHEV_d(n, x, che)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               che(j+1,i)=2.0d0*che(1,i)*che(j,i)-che(j-1,i)
@@ -131,22 +131,22 @@ end subroutine
 
 subroutine GEGENBAUER_f(n, x, p, lambda)
 !************************************
-!*  Х ¿༰׻֥롼  *
+!*  ゲーゲンバウアー 多項式計算サブルーチン  *
 !************************************
-!* Ȥ
-!* n=(0ǽ)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! ׻륲Х¿༰κǹ⼡
-  real, intent(in) :: x(:)  ! 
-  real, intent(in) :: lambda  ! Х
-  real, intent(inout) :: p(0:n,size(x))  ! ׻륲Х¿༰
+  integer, intent(in) :: n  ! 計算するゲーゲンバウアー多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(in) :: lambda  ! ゲーゲンバウアー係数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算するゲーゲンバウアー多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -158,7 +158,7 @@ subroutine GEGENBAUER_f(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0/real(j+1))*(2.0*(lambda+real(j))*x(i)*p(j,i)  &
@@ -172,22 +172,22 @@ end subroutine
 
 subroutine GEGENBAUER_d(n, x, p, lambda)
 !************************************
-!*  Х ¿༰׻֥롼  *
+!*  ゲーゲンバウアー 多項式計算サブルーチン  *
 !************************************
-!* Ȥ
-!* n=(0ǽ)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! ׻륲Х¿༰κǹ⼡
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(in) :: lambda  ! Х
-  double precision, intent(inout) :: p(0:n,size(x))  ! ׻륲Х¿༰
+  integer, intent(in) :: n  ! 計算するゲーゲンバウアー多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(in) :: lambda  ! ゲーゲンバウアー係数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算するゲーゲンバウアー多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -199,7 +199,7 @@ subroutine GEGENBAUER_d(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0d0/dble(j+1))*(2.0d0*(lambda+dble(j))*x(i)*p(j,i)  &
@@ -214,21 +214,21 @@ end subroutine
 
 subroutine HERMITE_f(n, x, p)
 !************************************
-!*  Hermite ¿༰׻֥롼  *
+!*  Hermite 多項式計算サブルーチン  *
 !************************************
-!* Ȥ
-!* n=(0ǽ)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! ׻ Hermite ¿༰κǹ⼡
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! ׻ Hermite ¿༰
+  integer, intent(in) :: n  ! 計算する Hermite 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Hermite 多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -240,7 +240,7 @@ subroutine HERMITE_f(n, x, p)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=2.0*(x(i)*p(j,i)-real(j)*p(j-1,i))
@@ -254,21 +254,21 @@ end subroutine
 
 subroutine HERMITE_d(n, x, p)
 !************************************
-!*  Hermite ¿༰׻֥롼  *
+!*  Hermite 多項式計算サブルーチン  *
 !************************************
-!* Ȥ
-!* n=(0ǽ)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! ׻ Hermit ¿༰κǹ⼡
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! ׻ Hermit ¿༰
+  integer, intent(in) :: n  ! 計算する Hermit 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Hermit 多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -280,7 +280,7 @@ subroutine HERMITE_d(n, x, p)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=2.0d0*(x(i)*p(j,i)-dble(j)*p(j-1,i))
@@ -294,30 +294,30 @@ end subroutine
 
 subroutine JACOBI_POLY_f(n, x, p, alpha, beta)
 !***********************************
-!  Jacobi ¿༰׻֥롼   *
+!  Jacobi 多項式計算サブルーチン   *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
-  real, intent(in) :: alpha  ! 
-  real, intent(in) :: beta  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  real, intent(in) :: alpha  ! 第一引数
+  real, intent(in) :: beta  ! 第二引数
   real :: gamma, omega
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 係数の設定 ---
   gamma=alpha+beta
   omega=alpha-beta
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -329,7 +329,7 @@ subroutine JACOBI_POLY_f(n, x, p, alpha, beta)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(0.5/(real(j+1)*real(j+1+gamma)*real(2.0*j+gamma)))  &
@@ -348,30 +348,30 @@ end subroutine
 
 subroutine JACOBI_POLY_d(n, x, p, alpha, beta)
 !***********************************
-!  Jacobi ¿༰׻֥롼   *
+!  Jacobi 多項式計算サブルーチン   *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
-  double precision, intent(in) :: alpha  ! 
-  double precision, intent(in) :: beta  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  double precision, intent(in) :: alpha  ! 第一引数
+  double precision, intent(in) :: beta  ! 第二引数
   double precision :: gamma, omega
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 係数の設定 ---
   gamma=alpha+beta
   omega=alpha-beta
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -383,7 +383,7 @@ subroutine JACOBI_POLY_d(n, x, p, alpha, beta)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(0.5d0/(dble(j+1)*dble(j+1+gamma)*dble(2.0*j+gamma)))  &
@@ -402,23 +402,23 @@ end subroutine
 
 subroutine LAGUERRE_f(n, x, p)
 !***********************************
-!  Laguerre ¿༰׻֥롼 *
+!  Laguerre 多項式計算サブルーチン *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -430,7 +430,7 @@ subroutine LAGUERRE_f(n, x, p)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(2.0*real(j)+1.0-x(i))*p(j,i)  &
@@ -445,23 +445,23 @@ end subroutine
 
 subroutine LAGUERRE_d(n, x, p)
 !***********************************
-!  Laguerre ¿༰׻֥롼 *
+!  Laguerre 多項式計算サブルーチン *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -473,7 +473,7 @@ subroutine LAGUERRE_d(n, x, p)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(2.0d0*dble(j)+1.0d0-x(i))*p(j,i)  &
@@ -488,23 +488,23 @@ end subroutine
 
 subroutine LEGENDRE_f(n, x, p)
 !***********************************
-!  Legendre ¿༰׻֥롼 *
+!  Legendre 多項式計算サブルーチン *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -516,7 +516,7 @@ subroutine LEGENDRE_f(n, x, p)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0/real(j+1))*(p(j,i)*(2.0*real(j)+1.0)  &
@@ -531,23 +531,23 @@ end subroutine
 
 subroutine LEGENDRE_d(n, x, p)
 !***********************************
-!  Legendre ¿༰׻֥롼 *
+!  Legendre 多項式計算サブルーチン *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -559,7 +559,7 @@ subroutine LEGENDRE_d(n, x, p)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0d0/dble(j+1))*(p(j,i)*(2.0d0*dble(j)+1.0d0)  &
@@ -573,21 +573,21 @@ end subroutine
 
 subroutine AS_LEGENDRE_f(n, m, x, p)
 !***********************************
-!  Legendre ؿ׻֥롼 *
+!  Legendre 陪関数計算サブルーチン *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! m=ȼ(n>=m)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! m=随伴次数(n>=m)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ legendre ؿκǹ⼡
-  integer, intent(in) :: m  ! ׻ legendre ؿοȼ
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(abs(m):n,size(x))  ! ׻ legendre ؿ
+  integer, intent(in) :: n  ! 計算する legendre 陪関数の最高次数
+  integer, intent(in) :: m  ! 計算する legendre 陪関数の随伴次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(abs(m):n,size(x))  ! 計算する legendre 陪関数
   integer :: i, j, abm
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
   real :: coe
 
   nmax=size(x)
@@ -599,7 +599,7 @@ subroutine AS_LEGENDRE_f(n, m, x, p)
      stop
   end if
 
-!-- m ˤĤƤ 2 󳬾׻
+!-- m についての 2 回階乗を計算
 
   coe=1.0
 
@@ -609,28 +609,28 @@ subroutine AS_LEGENDRE_f(n, m, x, p)
      end do
   end if
 
-!-- m=0 ξϥ른ɥ¿༰ƱʤΤ, ή.
+!-- m=0 の場合はルジャンドル多項式と同じなので, それを流用.
 
   if(m==0)then
      call Legendre_f( n, x, p(:,:) )
   else
 
-  !-- ʲ, m/=0ξη׻.
-  !--  ---
+  !-- 以下, m/=0の場合の計算.
+  !-- 初項の設定 ---
 
      do i=1,nmax
         p(abm,i)=sqrt(coe*(1.0-x(i)**2)**abm)
      end do
 
-     if(abm<n)then  ! |m|<n ξη׻.
+     if(abm<n)then  ! |m|<n の場合の計算.
 
         do i=1,nmax
            p(abm+1,i)=p(abm,i)*(2.0*real(abm)+1.0)*x(i)
         end do
 
-        if(abm+1<n)then  ! |m+1|<n ξη׻.
+        if(abm+1<n)then  ! |m+1|<n の場合の計算.
 
-        !-- η׻ ---
+        !-- 漸化式の計算 ---
            do j=abm+1,n-1
               do i=1,nmax
                  p(j+1,i)=(1.0/real(j-abm+1))*(p(j,i)*(2.0*real(j)+1.0)  &
@@ -641,7 +641,7 @@ subroutine AS_LEGENDRE_f(n, m, x, p)
         end if
      end if
 
-     if(m<0)then  ! 鼡ξɲ÷׻
+     if(m<0)then  ! 負次の場合の追加計算
         coe=real(kaijo_i(n-m))/real(kaijo_i(n+m))
 
         if(mod(m,2)==0)then
@@ -667,20 +667,20 @@ end subroutine
 
 subroutine AS_LEGENDRE_d(n, m, x, p)
 !***********************************
-!  Legendre ¿༰׻֥롼 *
+!  Legendre 多項式計算サブルーチン *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ legendre ؿκǹ⼡
-  integer, intent(in) :: m  ! ׻ legendre ؿοȼ
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(abs(m):n,size(x))  ! ׻ legendre ؿ
+  integer, intent(in) :: n  ! 計算する legendre 陪関数の最高次数
+  integer, intent(in) :: m  ! 計算する legendre 陪関数の随伴次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(abs(m):n,size(x))  ! 計算する legendre 陪関数
   integer :: i, j, abm
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
   double precision :: coe
 
   nmax=size(x)
@@ -692,7 +692,7 @@ subroutine AS_LEGENDRE_d(n, m, x, p)
      stop
   end if
 
-!-- m ˤĤƤ 2 󳬾׻
+!-- m についての 2 回階乗を計算
 
   coe=1.0d0
 
@@ -702,28 +702,28 @@ subroutine AS_LEGENDRE_d(n, m, x, p)
      end do
   end if
 
-!-- m=0 ξϥ른ɥ¿༰ƱʤΤ, ή.
+!-- m=0 の場合はルジャンドル多項式と同じなので, それを流用.
 
   if(m==0)then
      call Legendre_d( n, x, p(:,:) )
   else
 
-  !-- ʲ, m/=0ξη׻.
-  !--  ---
+  !-- 以下, m/=0の場合の計算.
+  !-- 初項の設定 ---
 
      do i=1,nmax
         p(abm,i)=dsqrt(coe*(1.0d0-x(i)**2)**abm)
      end do
 
-     if(abm<n)then  ! |m|<n ξη׻.
+     if(abm<n)then  ! |m|<n の場合の計算.
 
         do i=1,nmax
            p(abm+1,i)=p(abm,i)*(2.0d0*dble(abm)+1.0d0)*x(i)
         end do
 
-        if(abm+1<n)then  ! |m+1|<n ξη׻.
+        if(abm+1<n)then  ! |m+1|<n の場合の計算.
 
-        !-- η׻ ---
+        !-- 漸化式の計算 ---
            do j=abm+1,n-1
               do i=1,nmax
                  p(j+1,i)=(1.0d0/dble(j-abm+1))*(p(j,i)*(2.0d0*dble(j)+1.0d0)  &
@@ -734,7 +734,7 @@ subroutine AS_LEGENDRE_d(n, m, x, p)
         end if
      end if
 
-     if(m<0)then  ! 鼡ξɲ÷׻
+     if(m<0)then  ! 負次の場合の追加計算
         coe=dble(kaijo_i(n-m))/dble(kaijo_i(n+m))
 
         if(mod(m,2)==0)then
@@ -760,24 +760,24 @@ end subroutine
 
 subroutine SONINE_f(n, x, p, lambda)
 !***********************************
-!  Sonine ¿༰׻֥롼  *
+!  Sonine 多項式計算サブルーチン  *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
-  real, intent(in) :: lambda  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  real, intent(in) :: lambda  ! 第一引数
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -789,7 +789,7 @@ subroutine SONINE_f(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0/real(j+1))  &
@@ -805,24 +805,24 @@ end subroutine
 
 subroutine SONINE_d(n, x, p, lambda)
 !***********************************
-!  Sonine ¿༰׻֥롼  *
+!  Sonine 多項式計算サブルーチン  *
 !***********************************
-! Ȥ
-! n=(0ǽ)
-! nmax=ֳʻ
-! p=p(0:n,nmax) 2
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! ׻ jacobi ¿༰κǹ⼡
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! ׻ Jacobi ¿༰
-  double precision, intent(in) :: lambda  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  double precision, intent(in) :: lambda  ! 第一引数
   integer :: i, j
-  integer :: nmax  !  x ǿ
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!--  ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -834,7 +834,7 @@ subroutine SONINE_d(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- η׻ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0d0/dble(j+1))  &
@@ -849,13 +849,13 @@ end subroutine
 
 
 subroutine ymn( n, m, x, y, p )
-! Ĵ´ؿ׻롼
+! 球面調和関数を計算するルーチン
   implicit none
-  integer, intent(in) :: n  ! ȿ
-  integer, intent(in) :: m  ! ȿ
-  real, intent(in) :: x(:)  ! ѿ [0<=x<=2*pi]
-  real, intent(in) :: y(:)  ! ѿ [-1<=y<=1]
-  complex, intent(inout) :: p(0:n,-m:m,size(x),size(y))  ! Ĵ´ؿ
+  integer, intent(in) :: n  ! 緯度方向の波数
+  integer, intent(in) :: m  ! 経度方向の波数
+  real, intent(in) :: x(:)  ! 経度変数 [0<=x<=2*pi]
+  real, intent(in) :: y(:)  ! 緯度変数 [-1<=y<=1]
+  complex, intent(inout) :: p(0:n,-m:m,size(x),size(y))  ! 球面調和関数
   integer :: nmax, mmax
   integer :: i, j, k, l
   complex, parameter :: img=(0.0,1.0)
@@ -864,7 +864,7 @@ subroutine ymn( n, m, x, y, p )
   nmax=size(x)
   mmax=size(y)
 
-!-- 른ɥؿ׻.
+!-- ルジャンドル陪関数を計算.
   do j=-m,m
      call AS_Legendre( n, j, y, pm(abs(j):n,j,:) )
   end do
@@ -883,13 +883,13 @@ end subroutine
 
 
 subroutine gauss_lat( n, lat, eps )
-! ٤׻롼
+! ガウス緯度を計算するルーチン
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! ٤ʬο
-  real, intent(inout) :: lat(n)  ! ٤γǤΰ [degree]
-  real, intent(in), optional :: eps  ! ˥塼ȥˡǤΥȽ
-                                ! ǥեȤ 1.0e-6.
+  integer, intent(in) :: n  ! ガウス緯度の分点の数
+  real, intent(inout) :: lat(n)  ! ガウス緯度の各点での緯度 [degree]
+  real, intent(in), optional :: eps  ! ニュートン法でのゼロ点判定値
+                                ! デフォルトは 1.0e-6.
   real :: tmp(0:n,1)
   real :: nu(1)
   integer :: k
@@ -901,7 +901,7 @@ subroutine gauss_lat( n, lat, eps )
      eps_max=1.0e-6
   end if
 
-  do k=1,n  ! k ܤʬ
+  do k=1,n  ! k 番目の分点
 
      nu(1)=cos((pi*(4.0*real(k)-1.0))/(4.0*real(n)+2.0))
      call legendre( n, nu(1:1), tmp(0:n,1:1) )
