@@ -2,7 +2,7 @@
 !     Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !-----------------------------------------------------------------------
 
-module radar_analysis  ! 졼ǡϥ⥸塼
+module radar_analysis  ! レーダデータ解析モジュール
 
   use Matrix_calc
 
@@ -11,26 +11,26 @@ module radar_analysis  ! 졼ǡϥ⥸塼
 contains
 
 subroutine VVP( r, t, p, x, y, z, vr, u, v, w, undef )
-! VVP ˡѤƥɥåץ顼졼ư®٥ǡ®ǡѤ.
-! ׻ν֤
-! 1. ɸѴԤ.
-! 2. ׻õ.
-! 3. ɸѿ (G) ׻.
-! 4. չ (G-1) ׻.
-! 5. ׻Ԥ.
-!    ʳǵ᤿ʪ̤ 3 ®پʤΤ,  5  3 ʬ׻Τ߹Ԥ.
+! VVP 法を用いてドップラーレーダの動径速度データから風速場データを求積する.
+! 計算の順番は
+! 1. 座標変換を行う.
+! 2. 計算候補点を探索する.
+! 3. 座標変数行列 (G) を計算する.
+! 4. 逆行列 (G-1) を計算する.
+! 5. 行列計算を行う.
+!    現段階で求めたい物理量が 3 次元速度場なので, 過程 5 は 3 成分計算のみ行う.
   implicit none
-  integer, intent(in) :: r(:)  ! ưʻҺɸ [m]
-  integer, intent(in) :: t(:)  ! Ʊ̳ʻҺɸ [rad]
-  integer, intent(in) :: p(:)  ! ĳʻҺɸ [rad]
-  integer, intent(in) :: x(:)  ! ʻҺɸ [m]
-  integer, intent(in) :: y(:)  ! ʻҺɸ [m]
-  integer, intent(in) :: z(:)  ! ľʻҺɸ [m]
-  integer, intent(in) :: vr(size(r),size(t),size(p))  ! ɥåץ顼졼®٥ǡ [m/s]
-  integer, intent(inout) :: u(size(x),size(y),size(z))  ! ®پǡ [m/s]
-  integer, intent(inout) :: v(size(x),size(y),size(z))  ! ®پǡ [m/s]
-  integer, intent(inout) :: w(size(x),size(y),size(z))  ! ®پǡ [m/s]
-  real, intent(in), optional :: undef  ! ̤ǡ
+  integer, intent(in) :: r(:)  ! 動径方向格子座標 [m]
+  integer, intent(in) :: t(:)  ! 同位角方向格子座標 [rad]
+  integer, intent(in) :: p(:)  ! 仰角方向格子座標 [rad]
+  integer, intent(in) :: x(:)  ! 東西方向格子座標 [m]
+  integer, intent(in) :: y(:)  ! 南北方向格子座標 [m]
+  integer, intent(in) :: z(:)  ! 鉛直方向格子座標 [m]
+  integer, intent(in) :: vr(size(r),size(t),size(p))  ! ドップラーレーダ速度データ [m/s]
+  integer, intent(inout) :: u(size(x),size(y),size(z))  ! 東西速度場データ [m/s]
+  integer, intent(inout) :: v(size(x),size(y),size(z))  ! 東西速度場データ [m/s]
+  integer, intent(inout) :: w(size(x),size(y),size(z))  ! 東西速度場データ [m/s]
+  real, intent(in), optional :: undef  ! 未定義データ
   real, allocatable, dimension(:) :: Vo, Vv
   real, allocatable, dimension(:,:) :: a, b, c
 
@@ -52,13 +52,13 @@ subroutine VVP( r, t, p, x, y, z, vr, u, v, w, undef )
   do k=1,nz
      do j=1,ny
         do i=1,nx
-        !-- 1,2. ɸѴȷ׻õ.
+        !-- 1,2. 座標変換と計算候補点を探索する.
            call search_calc_point( r, t, p, x(i), y(j), z(k), ix, iy, iz, nl )
            allocate(b(nm,nl))
-        !-- 3. ɸѿη׻
-        !-- 4. չη׻
+        !-- 3. 座標変数行列の計算
+        !-- 4. 逆行列の計算
            call invert_mat( c, a )
-        !-- 5. ׻
+        !-- 5. 行列計算
            u(i,j,k)=calc_G( 1, a, b, Vo )
            v(i,j,k)=calc_G( 2, a, b, Vo )
            w(i,j,k)=calc_G( 8, a, b, Vo )
