@@ -2,7 +2,7 @@
 ! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 
-module Special_Function  !-- üؿ׻⥸塼 ---
+module Special_Function  !-- 特殊関数を計算するモジュール ---
 
 interface kaijo
 
@@ -90,11 +90,11 @@ private :: df_bessy_term2_d
 contains
 
 real function digamma(k)
-  !-- ޴ؿ׻륵֥롼 ---
-  !-- Ȥ ---
-  !-- ؿ̾ "digamma(n)" , ɬǤʤФʤʤ
+  !-- ダイガンマ関数を計算するサブルーチン ---
+  !-- 使い方 ---
+  !-- 関数名は "digamma(n)" で, 引数は必ず整数でなければならない
   implicit none
-  integer, intent(in) :: k  ! (k+1) ܤޤǤη׻
+  integer, intent(in) :: k  ! (k+1) 項目までの計算
   integer :: j
 
   if (k.gt.1) then
@@ -113,14 +113,14 @@ real function digamma(k)
 end function
 
 real function epsilon(i,j,k)
-!-- ǥȥΥץ׻륵֥롼 ---
-!-- F77 ǤǤѤǤʤä CASE ʸǿʬԤ ---
-!-- i,j,k  1..3  3 ष¸ߤʤȤΤȤδؿǤΤ,
-!-- ǤΥƥ󥽥ˤŬѤǤʤ. ---
+!-- エディントンのイプシロンを計算するサブルーチン ---
+!-- F77 版では利用できなかった CASE 文で振り分けを行う ---
+!-- i,j,k は 1..3 の 3 種類しか存在しないという仮定のもとの関数であるので,
+!-- 相対性理論でのテンソルには適用できない. ---
   implicit none
-  integer, intent(in) :: i  !  1 ʬ
-  integer, intent(in) :: j  !  1 ʬ
-  integer, intent(in) :: k  !  1 ʬ
+  integer, intent(in) :: i  ! 第 1 成分
+  integer, intent(in) :: j  ! 第 1 成分
+  integer, intent(in) :: k  ! 第 1 成分
 
   select case (i)
 
@@ -244,9 +244,9 @@ real function epsilon(i,j,k)
 end function
 
 
-real function Full_Ellip1_Func_f(k)  !  1 ﴰʱߴؿ׻
+real function Full_Ellip1_Func_f(k)  ! 第 1 種完全楕円関数計算
   implicit none
-  real, intent(in) :: k  ! ؿΰ
+  real, intent(in) :: k  ! 関数の引数
   real :: pi, m, dt, t, tmin, tmax
   integer :: i
   integer, parameter :: nmax=1000
@@ -275,9 +275,9 @@ real function Full_Ellip1_Func_f(k)  !  1 ﴰʱߴؿ׻
 end function
 
 
-double precision function Full_Ellip1_Func_d(k)  !  1 ﴰʱߴؿ׻
+double precision function Full_Ellip1_Func_d(k)  ! 第 1 種完全楕円関数計算
   implicit none
-  double precision, intent(in) :: k  ! ؿΰ
+  double precision, intent(in) :: k  ! 関数の引数
   double precision :: pi, m, dt, t, tmin, tmax
   integer :: i
   integer, parameter :: nmax=1000
@@ -306,9 +306,9 @@ double precision function Full_Ellip1_Func_d(k)  !  1 ﴰʱߴؿ׻
 end function
 
 
-real function Full_Ellip2_Func_f(k)  ! ﴰʱߴؿ
+real function Full_Ellip2_Func_f(k)  ! 第二種完全楕円関数
   implicit none
-  real, intent(in) :: k  ! ؿΰ
+  real, intent(in) :: k  ! 関数の引数
   real :: pi, m, dt, t, tmin, tmax
   integer :: i
   integer, parameter :: nmax=1000
@@ -338,9 +338,9 @@ end function
 
 
 
-double precision function Full_Ellip2_Func_d(k)  ! ﴰʱߴؿ
+double precision function Full_Ellip2_Func_d(k)  ! 第二種完全楕円関数
   implicit none
-  double precision, intent(in) :: k  ! ؿΰ
+  double precision, intent(in) :: k  ! 関数の引数
   double precision :: pi, m, dt, t, tmin, tmax
   integer :: i
   integer, parameter :: nmax=1000
@@ -372,9 +372,9 @@ end function
 !----------------------------------------------------
 
 integer function kaijo_i(k)
-  !-- ؿ׻륵֥롼 ---
-  !-- Ȥ ---
-  !-- ؿ̾ "kaijo(k)" ,  "k" ˤΤ뤳
+  !-- 階乗関数を計算するサブルーチン ---
+  !-- 使い方 ---
+  !-- 関数名は "kaijo(k)" で, 引数 "k" には整数のみ入れること
   implicit none
   integer, intent(in) :: k
   integer :: j
@@ -395,9 +395,9 @@ end function
 !----------------------------------------------------
 
 real function kaijo_f(k)
-  !-- ؿ׻륵֥롼 ---
-  !-- Ȥ ---
-  !-- ؿ̾ "kaijo(k)" ,  "k" ˤΤ뤳
+  !-- 階乗関数を計算するサブルーチン ---
+  !-- 使い方 ---
+  !-- 関数名は "kaijo(k)" で, 引数 "k" には整数のみ入れること
   implicit none
   real, intent(in) :: k
   integer :: j
@@ -417,13 +417,13 @@ end function
 !----------------------------------------------------
 !----------------------------------------------------
 
-real function bessj_f(m,t)  !  I ٥åؿ׻
+real function bessj_f(m,t)  ! 第 I 種ベッセル関数を計算する
   implicit none
-  integer, intent(in) :: m  ! ׻뼡
-  real, intent(in) :: t  ! 
+  integer, intent(in) :: m  ! 計算する次数
+  real, intent(in) :: t  ! 引数
   integer :: istep, n
   real :: x, coe1
-  integer, parameter :: mmax = 100 ! ʬѤ
+  integer, parameter :: mmax = 100 ! 数値積分用の配列
   real, parameter :: pis=3.14159265
   real, parameter :: xmin = 0.0d0, xmax = 2.0d0*pis
   real, parameter :: dx = (xmax-xmin)/(mmax-1)
@@ -435,14 +435,14 @@ real function bessj_f(m,t)  !  I ٥åؿ׻
      stop
   end if
 
-!-- μǤäʬ ---
+!-- 負の次数であった場合を分ける ---
   if(m < 0)then
      n=-m
   else
      n=m
   end if
 
-!-- ٥åؿʬ׻ ---
+!-- ベッセル関数の積分計算 ---
   bessj_f=0.0
 
   do istep=2,mmax-1
@@ -454,9 +454,9 @@ real function bessj_f(m,t)  !  I ٥åؿ׻
  &            +cos(t*sin(xmax)-real(n)*xmax))
   bessj_f=bessj_f/(2.0*pis)
 
-!-- μǤäʬ ---
+!-- 負の次数であった場合を分ける ---
   if(m.lt.0)then
-     if(mod(n,2)==0)then  ! (-1)^m η׻󤹤
+     if(mod(n,2)==0)then  ! (-1)^m の計算を節約する
         coe1=1.0
      else
         coe1=-1.0
@@ -470,13 +470,13 @@ end function
 !----------------------------------------------------
 !----------------------------------------------------
 
-double precision function bessj_d(m,t)  !  I ٥åؿ׻
+double precision function bessj_d(m,t)  ! 第 I 種ベッセル関数を計算する
   implicit none
-  integer, intent(in) :: m  ! ׻뼡
-  double precision, intent(in) :: t  ! 
+  integer, intent(in) :: m  ! 計算する次数
+  double precision, intent(in) :: t  ! 引数
   integer :: istep, n
   double precision :: x, coe1
-  integer, parameter :: mmax = 100 ! ʬѤ
+  integer, parameter :: mmax = 100 ! 数値積分用の配列
   double precision, parameter :: pis=3.14159265
   double precision, parameter :: xmin = 0.0d0, xmax = 2.0d0*pis
   double precision, parameter :: dx = (xmax-xmin)/(mmax-1)
@@ -488,14 +488,14 @@ double precision function bessj_d(m,t)  !  I ٥åؿ׻
      stop
   end if
 
-!-- μǤäʬ ---
+!-- 負の次数であった場合を分ける ---
   if(m < 0)then
      n=-m
   else
      n=m
   end if
 
-!-- ٥åؿʬ׻ ---
+!-- ベッセル関数の積分計算 ---
   bessj_d=0.0d0
 
   do istep=2,mmax-1
@@ -507,9 +507,9 @@ double precision function bessj_d(m,t)  !  I ٥åؿ׻
  &            +dcos(t*dsin(xmax)-dble(n)*xmax))
   bessj_d=bessj_d/(2.0d0*pis)
 
-!-- μǤäʬ ---
+!-- 負の次数であった場合を分ける ---
   if(m.lt.0)then
-     if(mod(n,2)==0)then  ! (-1)^m η׻󤹤
+     if(mod(n,2)==0)then  ! (-1)^m の計算を節約する
         coe1=1.0d0
      else
         coe1=-1.0d0
@@ -524,25 +524,25 @@ end function
 !----------------------------------------------------
 
 real function bessj_fnoni(nu,t)
-! ˤ٥åؿ׻.
-! Ǥϥ졼եʬΩʤΤ, Lommel ʬ
-! ׻뤳Ȥˤäɾ. ޤ,
+! 次数が非整数におけるベッセル関数を計算する.
+! 非整数次ではシュレーフリ積分が成り立たないので, Lommel 積分を台形公式で
+! 計算することによって評価する. また,
 ! $J_{-n}(x)=(-1)^nJ_n(x)$
-! μΩʤΤ, μξľܷ׻Ԥ褦ѹ.
-! Lommel ʬϰʲμ
+! の式が成り立たないので, 負の次数の場合も直接計算を行うように変更.
+! Lommel の積分は以下の式：
 ! $J_{\nu} (x)=\left(\frac{x}{2} \right) ^{\nu} \frac{1}{\sqrt[]{\pi} \Gamma (\nu +1/2)} \int^{\pi}_{0}{\cos{(z\cos{\theta} )} } $
-! , μɾǤΤ, $\nu > -\frac{1}{2} $ޤǤʤΤ, 꾮Υ٥åؿϷ׻Ǥʤ.
-! , ʲμ٥åؿ
+! ただし, この式で評価できるのは, $\nu > -\frac{1}{2} $までなので, これより小さい非整数次のベッセル関数は計算できない.
+! そこで, これ以下の次数の非整数ベッセル関数は漸化式：
 ! $J_{\nu -1}(x)+J_{\nu +1}(x)=\frac{2\nu}{x} J_{\nu} (x)$
-! ѤƷ׻. , ξ, $x>0$ ˸¤.
+! を用いて計算する. ただし, この場合, $x>0$ に限る.
 
   use Math_Const
   implicit none
-  real, intent(in) :: nu  ! ׻뼡
-  real, intent(in) :: t  ! 
+  real, intent(in) :: nu  ! 計算する次数
+  real, intent(in) :: t  ! 引数
   integer :: istep
   real :: x
-  integer, parameter :: mmax = 100 ! ʬѤ
+  integer, parameter :: mmax = 100 ! 数値積分用の配列
   real :: xmin, xmax, dx, tmp1, tmp2, bess0, bess1, bess2, tmp
   intrinsic :: aint
 
@@ -557,13 +557,13 @@ real function bessj_fnoni(nu,t)
      stop
   end if
 
-  if(nu<=-0.5)then  ! nu <= -1/2 ξν.
+  if(nu<=-0.5)then  ! nu <= -1/2 の場合の処理.
      tmp1=nu+1.0+aint(abs(nu))
-     tmp2=nu+2.0+aint(abs(nu))  !  3 ʤΤ, ͤ 2 .
+     tmp2=nu+2.0+aint(abs(nu))  ! 漸化式が 3 項漸化式なので, 初期値が 2 つ.
   end if
 
 
-!-- ٥åؿʬ׻ ---
+!-- ベッセル関数の積分計算 ---
   bessj_fnoni=0.0
 
   if(nu>-0.5)then
@@ -576,7 +576,7 @@ real function bessj_fnoni(nu,t)
  &               +cos(t*cos(xmax))*((sin(xmax))**(2.0*nu)))
      bessj_fnoni=bessj_fnoni*((0.5*x)**nu)/(sqrt(pi)*gamma_func_f(nu+0.5))
 
-  else  ! nu <= -0.5 ΤȤ.
+  else  ! nu <= -0.5 のとき.
      bess1=0.0
      bess2=0.0
      do istep=2,mmax-1
@@ -594,12 +594,12 @@ real function bessj_fnoni(nu,t)
 
      tmp=tmp1
 
-     do while(tmp/=nu)  ! tmp=nu ˤʤä, ˤʤäȽǤ.
+     do while(tmp/=nu)  ! tmp=nu になったら, 求める項になったと判断する.
         bess0=2.0*tmp1*bess1/t-bess2
         tmp=tmp-1.0
         tmp1=tmp1-1.0
         bess2=bess1
-        bess1=bess0  ! η겼
+        bess1=bess0  ! 項の繰り下げ
      end do
 
      bessj_fnoni=bess1
@@ -614,25 +614,25 @@ end function
 !----------------------------------------------------
 
 double precision function bessj_dnoni(nu,t)
-! ˤ٥åؿ׻.
-! Ǥϥ졼եʬΩʤΤ, Lommel ʬ
-! ׻뤳Ȥˤäɾ. ޤ,
+! 次数が非整数におけるベッセル関数を計算する.
+! 非整数次ではシュレーフリ積分が成り立たないので, Lommel 積分を台形公式で
+! 計算することによって評価する. また,
 ! $J_{-n}(x)=(-1)^nJ_n(x)$
-! μΩʤΤ, μξľܷ׻Ԥ褦ѹ.
-! Lommel ʬϰʲμ
+! の式が成り立たないので, 負の次数の場合も直接計算を行うように変更.
+! Lommel の積分は以下の式：
 ! $J_{\nu} (x)=\left(\frac{x}{2} \right) ^{\nu} \frac{1}{\sqrt[]{\pi_dp} \Gamma (\nu +1/2)} \int^{\pi_dp}_{0}{\cos{(z\cos{\theta} )} } $
-! , μɾǤΤ, $\nu > -\frac{1}{2} $ޤǤʤΤ, 꾮Υ٥åؿϷ׻Ǥʤ.
-! , ʲμ٥åؿ
+! ただし, この式で評価できるのは, $\nu > -\frac{1}{2} $までなので, これより小さい非整数次のベッセル関数は計算できない.
+! そこで, これ以下の次数の非整数ベッセル関数は漸化式：
 ! $J_{\nu -1}(x)+J_{\nu +1}(x)=\frac{2\nu}{x} J_{\nu} (x)$
-! ѤƷ׻. , ξ, $x>0$ ˸¤.
+! を用いて計算する. ただし, この場合, $x>0$ に限る.
 
   use Math_Const
   implicit none
-  double precision, intent(in) :: nu  ! ׻뼡
-  double precision, intent(in) :: t  ! 
+  double precision, intent(in) :: nu  ! 計算する次数
+  double precision, intent(in) :: t  ! 引数
   integer :: istep
   double precision :: x
-  integer, parameter :: mmax = 100 ! ʬѤ
+  integer, parameter :: mmax = 100 ! 数値積分用の配列
   double precision :: xmin, xmax, dx, tmp1, tmp2, bess0, bess1, bess2, tmp
   intrinsic :: aint
 
@@ -647,13 +647,13 @@ double precision function bessj_dnoni(nu,t)
      stop
   end if
 
-  if(nu<=-0.5d0)then  ! nu <= -1/2 ξν.
+  if(nu<=-0.5d0)then  ! nu <= -1/2 の場合の処理.
      tmp1=nu+1.0d0+aint(abs(nu))
-     tmp2=nu+2.0d0+aint(abs(nu))  !  3 ʤΤ, ͤ 2 .
+     tmp2=nu+2.0d0+aint(abs(nu))  ! 漸化式が 3 項漸化式なので, 初期値が 2 つ.
   end if
 
 
-!-- ٥åؿʬ׻ ---
+!-- ベッセル関数の積分計算 ---
   bessj_dnoni=0.0d0
 
   if(nu>-0.5d0)then
@@ -666,7 +666,7 @@ double precision function bessj_dnoni(nu,t)
  &               +cos(t*cos(xmax))*((sin(xmax))**(2.0d0*nu)))
      bessj_dnoni=bessj_dnoni*((0.5d0*x)**nu)/(sqrt(pi_dp)*gamma_func_d(nu+0.5d0))
 
-  else  ! nu <= -0.5 ΤȤ.
+  else  ! nu <= -0.5 のとき.
      bess1=0.0d0
      bess2=0.0d0
      do istep=2,mmax-1
@@ -684,12 +684,12 @@ double precision function bessj_dnoni(nu,t)
 
      tmp=tmp1
 
-     do while(tmp/=nu)  ! tmp=nu ˤʤä, ˤʤäȽǤ.
+     do while(tmp/=nu)  ! tmp=nu になったら, 求める項になったと判断する.
         bess0=2.0d0*tmp1*bess1/t-bess2
         tmp=tmp-1.0d0
         tmp1=tmp1-1.0d0
         bess2=bess1
-        bess1=bess0  ! η겼
+        bess1=bess0  ! 項の繰り下げ
      end do
 
      bessj_dnoni=bess1
@@ -709,21 +709,21 @@ end function
 !----------------------------------------------------
 
 real function bessy_f( n, z )
-! ΥΥޥؿ׻.
-! ׻ˤ, 졼եʬɽѤ, Ⱦ̵ΰʬˤĤƤ,
-! ʬؿ 10^{-6} ãޤǤǤ.
-! ޤ, Ⱦ̵ʬʬؿ 2 Ĥ뤬, 줾ˤĤƹͤ
-! ɾ, ΤͤۤǤιʬ褦ˤ.
-! , ˡŬڤɤݾڤǤʤ.
+! 整数次のノイマン関数を計算する.
+! 計算には, シュレーフリの積分表示を用い, 半無限領域の積分については,
+! 非積分関数が 10^{-6} に達する点までで打ちきる.
+! また, 半無限積分の非積分関数は 2 つあるが, それぞれについて項の値を
+! 毎回評価し, 上のしきい値を越えた時点でその項は積分をやめるようにする.
+! ただし, この方法が適切かどうかは保証できない.
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  real, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  real, intent(in) :: z  ! 変数
   real :: dt, term1, term2, tmp1, tmp2, t
-  real,parameter :: tmin=0.0, tmax=pi  ! ʬʬΰ
+  real,parameter :: tmin=0.0, tmax=pi  ! 定積分項の積分領域
   real, parameter :: thres=1.0e-6
   integer :: i
-  integer, parameter :: nt=100  ! ʬʬʬ
+  integer, parameter :: nt=100  ! 定積分項の積分分割数
 
   if(z<0.0)then
      write(*,*) "*** ERROR ***"
@@ -736,12 +736,12 @@ real function bessy_f( n, z )
   term2=0.0
   dt=1.0e-2
 
-!-- Ⱦ̵ʬη׻
-!--  1
+!-- 半無限積分項の計算
+!-- 項 1
 
   t=0.0
 
-  tmp1=0.5  ! ʬؿ z=0 Ǥ x 0.5
+  tmp1=0.5  ! 非積分関数の z=0 での値 x 0.5
   term1=tmp1
 
   do while (tmp1>thres)
@@ -754,29 +754,29 @@ real function bessy_f( n, z )
   term1=term1+0.5*exp(n*t-z*sinh(t))
   term1=dt*term1/pi
 
-!--  2
+!-- 項 2
 
   t=0.0
 
-  tmp2=0.5  ! ʬؿ z=0 Ǥ x 0.5
+  tmp2=0.5  ! 非積分関数の z=0 での値 x 0.5
   term2=tmp2
 
   do while (tmp2>thres)
      t=t+dt
      tmp2=exp(-(n*t+z*sinh(t)))
-     term2=term2+tmp2*cos(n*pi)  ! cos μǤͤŪ˲ʤ
-                               ! 褦, Τߤɾ. cos ϤȤǤ
+     term2=term2+tmp2*cos(n*pi)  ! cos の周期性でしきい値を一時的に下回らない
+                               ! ように, 振幅のみで評価する. cos はあとでかける
   end do
 
   t=t+dt
   term2=term2+0.5*exp(-(n*t+z*sinh(t)))*cos(n*pi)
   term2=dt*term2/pi
 
-!-- ʬ׻
+!-- 定積分計算
   dt=(tmax-tmin)/nt
   t=0.0
 
-  bessy_f=0.0  ! tmin Ǥʬؿ
+  bessy_f=0.0  ! tmin での非積分関数の値
 
   do i=1,nt-1
      t=t+dt
@@ -793,21 +793,21 @@ end function
 !----------------------------------------------------
 
 double precision function bessy_d( n, z )
-! ΥΥޥؿ׻.
-! ׻ˤ, 졼եʬɽѤ, Ⱦ̵ΰʬˤĤƤ,
-! ʬؿ 10^{-6} ãޤǤǤ.
-! ޤ, Ⱦ̵ʬʬؿ 2 Ĥ뤬, 줾ˤĤƹͤ
-! ɾ, ΤͤۤǤιʬ褦ˤ.
-! , ˡŬڤɤݾڤǤʤ.
+! 整数次のノイマン関数を計算する.
+! 計算には, シュレーフリの積分表示を用い, 半無限領域の積分については,
+! 非積分関数が 10^{-6} に達する点までで打ちきる.
+! また, 半無限積分の非積分関数は 2 つあるが, それぞれについて項の値を
+! 毎回評価し, 上のしきい値を越えた時点でその項は積分をやめるようにする.
+! ただし, この方法が適切かどうかは保証できない.
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  double precision, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  double precision, intent(in) :: z  ! 変数
   double precision :: dt, term1, term2, tmp1, tmp2, t
-  double precision :: tmin, tmax  ! ʬʬΰ
+  double precision :: tmin, tmax  ! 定積分項の積分領域
   double precision, parameter :: thres=1.0d-6
   integer :: i
-  integer, parameter :: nt=100  ! ʬʬʬ
+  integer, parameter :: nt=100  ! 定積分項の積分分割数
 
   if(z<0.0d0)then
      write(*,*) "*** ERROR ***"
@@ -822,12 +822,12 @@ double precision function bessy_d( n, z )
   term2=0.0d0
   dt=1.0d-2
 
-!-- Ⱦ̵ʬη׻
-!--  1
+!-- 半無限積分項の計算
+!-- 項 1
 
   t=0.0d0
 
-  tmp1=0.5d0  ! ʬؿ z=0 Ǥ x 0.5
+  tmp1=0.5d0  ! 非積分関数の z=0 での値 x 0.5
   term1=tmp1
 
   do while (tmp1>thres)
@@ -840,29 +840,29 @@ double precision function bessy_d( n, z )
   term1=term1+0.5d0*exp(n*t-z*sinh(t))
   term1=dt*term1/pi_dp
 
-!--  2
+!-- 項 2
 
   t=0.0d0
 
-  tmp2=0.5d0  ! ʬؿ z=0 Ǥ x 0.5
+  tmp2=0.5d0  ! 非積分関数の z=0 での値 x 0.5
   term2=tmp2
 
   do while (tmp2>thres)
      t=t+dt
      tmp2=exp(-(n*t+z*sinh(t)))
-     term2=term2+tmp2*cos(n*pi_dp)  ! cos μǤͤŪ˲ʤ
-                               ! 褦, Τߤɾ. cos ϤȤǤ
+     term2=term2+tmp2*cos(n*pi_dp)  ! cos の周期性でしきい値を一時的に下回らない
+                               ! ように, 振幅のみで評価する. cos はあとでかける
   end do
 
   t=t+dt
   term2=term2+0.5d0*exp(-(n*t+z*sinh(t)))*cos(n*pi_dp)
   term2=dt*term2/pi_dp
 
-!-- ʬ׻
+!-- 定積分計算
   dt=(tmax-tmin)/nt
   t=0.0d0
 
-  bessy_d=0.0d0  ! tmin Ǥʬؿ
+  bessy_d=0.0d0  ! tmin での非積分関数の値
 
   do i=1,nt-1
      t=t+dt
@@ -879,12 +879,12 @@ end function
 !----------------------------------------------------
 
 real function bessy_fnoni( nu, t )
-! ˤΥޥؿ׻.
+! 非整数次におけるノイマン関数を計算する.
 ! $Y_{\nu} =\frac{1}{\sin{\nu \pi}} [\cos{\nu \pi }J_{\nu} (x)-J_{-\nu} (x)]$
   use Math_Const
   implicit none
-  real, intent(in) :: nu  ! 
-  real, intent(in) :: t  ! ѿ
+  real, intent(in) :: nu  ! 次数
+  real, intent(in) :: t  ! 変数
   intrinsic :: aint
 
   if(t<=0.0)then
@@ -894,7 +894,7 @@ real function bessy_fnoni( nu, t )
      stop
   end if
 
-  if(nu/=aint(nu))then  ! nu ξ, bessy_f ˥쥯Ȥ.
+  if(nu/=aint(nu))then  ! nu が整数次の場合は, bessy_f にリダイレクトする.
      bessy_fnoni=(cos(nu*pi)*bessj_fnoni( nu, t )-bessj_fnoni( -nu, t ))  &
   &              /(sin(nu*pi))
   else
@@ -908,12 +908,12 @@ end function
 !----------------------------------------------------
 
 double precision function bessy_dnoni( nu, t )
-! ˤΥޥؿ׻.
+! 非整数次におけるノイマン関数を計算する.
 ! $Y_{\nu} =\frac{1}{\sin{\nu \pi}} [\cos{\nu \pi }J_{\nu} (x)-J_{-\nu} (x)]$
   use Math_Const
   implicit none
-  double precision, intent(in) :: nu  ! 
-  double precision, intent(in) :: t  ! ѿ
+  double precision, intent(in) :: nu  ! 次数
+  double precision, intent(in) :: t  ! 変数
   intrinsic :: aint
 
   if(t<=0.0)then
@@ -923,7 +923,7 @@ double precision function bessy_dnoni( nu, t )
      stop
   end if
 
-  if(nu/=aint(nu))then  ! nu ξ, bessy_f ˥쥯Ȥ.
+  if(nu/=aint(nu))then  ! nu が整数次の場合は, bessy_f にリダイレクトする.
      bessy_dnoni=(cos(nu*pi_dp)*bessj_dnoni( nu, t )-bessj_dnoni( -nu, t ))  &
   &              /(sin(nu*pi_dp))
   else
@@ -937,11 +937,11 @@ end function
 !----------------------------------------------------
 
 real function sp_bessj_f( m, t )
-! 1٥åؿη׻.
-! ٥åؿȵ٥åؿδط.
+! 第1種球ベッセル関数の計算.
+! ベッセル関数と球ベッセル関数の関係から.
   use Math_Const
   implicit none
-  integer, intent(in) :: m  ! 
+  integer, intent(in) :: m  ! 次数
   real, intent(in) :: t
 
   if(t<=0.0)then
@@ -960,11 +960,11 @@ end function
 !----------------------------------------------------
 
 double precision function sp_bessj_d( m, t )
-! 1٥åؿη׻.
-! ٥åؿȵ٥åؿδط.
+! 第1種球ベッセル関数の計算.
+! ベッセル関数と球ベッセル関数の関係から.
   use Math_Const
   implicit none
-  integer, intent(in) :: m  ! 
+  integer, intent(in) :: m  ! 次数
   double precision, intent(in) :: t
 
   if(t<=0.0d0)then
@@ -983,11 +983,11 @@ end function
 !----------------------------------------------------
 
 real function sp_bessy_f( m, t )
-! 2٥åؿη׻.
-! 1٥åؿȤδط.
+! 第2種球ベッセル関数の計算.
+! 第1種球ベッセル関数との関係から.
   use Math_Const
   implicit none
-  integer, intent(in) :: m  ! 
+  integer, intent(in) :: m  ! 次数
   real, intent(in) :: t
   real :: coe1
 
@@ -998,8 +998,8 @@ real function sp_bessy_f( m, t )
      stop
   end if
 
-  if(mod(abs(m+1),2)==0)then  ! (-1)^n η׻Ȥ򸺤餹, Ƚ.
-     coe1=1.0  ! $m+1 = \pm 2n$ ʤΤ, coe1=1
+  if(mod(abs(m+1),2)==0)then  ! (-1)^n の計算コストを減らすため, ここで正負判定.
+     coe1=1.0  ! $m+1 = \pm 2n$ なので, coe1=1
   else
      coe1=-1.0
   end if
@@ -1013,11 +1013,11 @@ end function
 !----------------------------------------------------
 
 double precision function sp_bessy_d( m, t )
-! 2٥åؿη׻.
-! 1٥åؿȤδط.
+! 第2種球ベッセル関数の計算.
+! 第1種球ベッセル関数との関係から.
   use Math_Const
   implicit none
-  integer, intent(in) :: m  ! 
+  integer, intent(in) :: m  ! 次数
   double precision, intent(in) :: t
   double precision :: coe1
 
@@ -1028,8 +1028,8 @@ double precision function sp_bessy_d( m, t )
      stop
   end if
 
-  if(mod(abs(m+1),2)==0)then  ! (-1)^n η׻Ȥ򸺤餹, Ƚ.
-     coe1=1.0d0  ! $m+1 = \pm 2n$ ʤΤ, coe1=1
+  if(mod(abs(m+1),2)==0)then  ! (-1)^n の計算コストを減らすため, ここで正負判定.
+     coe1=1.0d0  ! $m+1 = \pm 2n$ なので, coe1=1
   else
      coe1=-1.0d0
   end if
@@ -1043,11 +1043,11 @@ end function
 !----------------------------------------------------
 
 real function df_bessj_f( m, t )
-! ˤ 1 ѷ٥åؿη׻
-! df_bessj_fnoni إ쥯
+! 整数次における第 1 種変形ベッセル関数の計算
+! df_bessj_fnoni へリダイレクト
   implicit none
-  integer, intent(in) :: m  ! 
-  real, intent(in) :: t  ! ѿ
+  integer, intent(in) :: m  ! 次数
+  real, intent(in) :: t  ! 変数
 
   df_bessj_f=df_bessj_fnoni( real(m), t )
 
@@ -1057,11 +1057,11 @@ end function
 !----------------------------------------------------
 
 double precision function df_bessj_d( m, t )
-! ˤ 1 ѷ٥åؿη׻
-! df_bessj_fnoni إ쥯
+! 整数次における第 1 種変形ベッセル関数の計算
+! df_bessj_fnoni へリダイレクト
   implicit none
-  integer, intent(in) :: m  ! 
-  double precision, intent(in) :: t  ! ѿ
+  integer, intent(in) :: m  ! 次数
+  double precision, intent(in) :: t  ! 変数
 
   df_bessj_d=df_bessj_dnoni( dble(m), t )
 
@@ -1071,20 +1071,20 @@ end function
 !----------------------------------------------------
 
 real function df_bessj_fnoni( nu, t )
-! ˤ 1 ѷ٥åؿη׻
-! ʬ׻.
-! ʬϰʲμ
+! 非整数次における第 1 種変形ベッセル関数の計算
+! 積分形から計算.
+! 積分形は以下の式：
 ! $$I_{\nu} (x)=\frac{1}{\sqrt[]{\pi} \mathit{\Gamma} (\nu +1/2)} \left(\frac{x}{2} \right) ^{\nu} \int^{\infty}_{0}{\cosh{(x\cosh{t})} sin^{2\nu}{t} dt} $$
-! , $\nu >-1/2$ǤΤ, 꾮ˤĤƤ, 
+! ただし, $\nu >-1/2$であるので, これより小さい次数については, 漸化式：
 ! $$I_{\nu -1}-I_{\nu +1} =\frac{2\nu}{x} I_{\nu} $$
-! ѤƼ򲼤.
+! を用いて次数を下げる.
   use Math_Const
   implicit none
-  real, intent(in) :: nu  ! ׻뼡
-  real, intent(in) :: t  ! 
+  real, intent(in) :: nu  ! 計算する次数
+  real, intent(in) :: t  ! 引数
   integer :: istep
   real :: x
-  integer, parameter :: mmax = 100 ! ʬѤ
+  integer, parameter :: mmax = 100 ! 数値積分用の配列
   real :: xmin, xmax, dx, tmp1, tmp2, bess0, bess1, bess2, tmp
   intrinsic :: aint
 
@@ -1099,13 +1099,13 @@ real function df_bessj_fnoni( nu, t )
      stop
   end if
 
-  if(nu<=-0.5)then  ! nu <= -1/2 ξν.
+  if(nu<=-0.5)then  ! nu <= -1/2 の場合の処理.
      tmp1=nu+1.0+aint(abs(nu))
-     tmp2=nu+2.0+aint(abs(nu))  !  3 ʤΤ, ͤ 2 .
+     tmp2=nu+2.0+aint(abs(nu))  ! 漸化式が 3 項漸化式なので, 初期値が 2 つ.
   end if
 
 
-!-- ٥åؿʬ׻ ---
+!-- ベッセル関数の積分計算 ---
   df_bessj_fnoni=0.0
 
   if(nu>-0.5)then
@@ -1118,7 +1118,7 @@ real function df_bessj_fnoni( nu, t )
  &               +cosh(t*cos(xmax))*((sin(xmax))**(2.0*nu)))
      df_bessj_fnoni=df_bessj_fnoni*((0.5*x)**nu)/(sqrt(pi)*gamma_func_f(nu+0.5))
 
-  else  ! nu <= -0.5 ΤȤ.
+  else  ! nu <= -0.5 のとき.
      bess1=0.0
      bess2=0.0
      do istep=2,mmax-1
@@ -1136,12 +1136,12 @@ real function df_bessj_fnoni( nu, t )
 
      tmp=tmp1
 
-     do while(tmp/=nu)  ! tmp=nu ˤʤä, ˤʤäȽǤ.
+     do while(tmp/=nu)  ! tmp=nu になったら, 求める項になったと判断する.
         bess0=2.0*tmp1*bess1/t-bess2
         tmp=tmp-1.0
         tmp1=tmp1-1.0
         bess2=bess1
-        bess1=bess0  ! η겼
+        bess1=bess0  ! 項の繰り下げ
      end do
 
      df_bessj_fnoni=bess1
@@ -1155,20 +1155,20 @@ end function
 !----------------------------------------------------
 
 double precision function df_bessj_dnoni( nu, t )
-! ˤ 1 ѷ٥åؿη׻
-! ʬ׻.
-! ʬϰʲμ
+! 非整数次における第 1 種変形ベッセル関数の計算
+! 積分形から計算.
+! 積分形は以下の式：
 ! $$I_{\nu} (x)=\frac{1}{\sqrt[]{\pi} \mathit{\Gamma} (\nu +1/2)} \left(\frac{x}{2} \right) ^{\nu} \int^{\infty}_{0}{\cosh{(x\cosh{t})} sin^{2\nu}{t} dt} $$
-! , $\nu >-1/2$ǤΤ, 꾮ˤĤƤ, 
+! ただし, $\nu >-1/2$であるので, これより小さい次数については, 漸化式：
 ! $$I_{\nu -1}-I_{\nu +1} =\frac{2\nu}{x} I_{\nu} $$
-! ѤƼ򲼤.
+! を用いて次数を下げる.
   use Math_Const
   implicit none
-  double precision, intent(in) :: nu  ! ׻뼡
-  double precision, intent(in) :: t  ! 
+  double precision, intent(in) :: nu  ! 計算する次数
+  double precision, intent(in) :: t  ! 引数
   integer :: istep
   double precision :: x
-  integer, parameter :: mmax = 100 ! ʬѤ
+  integer, parameter :: mmax = 100 ! 数値積分用の配列
   double precision :: xmin, xmax, dx, tmp1, tmp2, bess0, bess1, bess2, tmp
   intrinsic :: aint
 
@@ -1183,13 +1183,13 @@ double precision function df_bessj_dnoni( nu, t )
      stop
   end if
 
-  if(nu<=-0.5d0)then  ! nu <= -1/2 ξν.
+  if(nu<=-0.5d0)then  ! nu <= -1/2 の場合の処理.
      tmp1=nu+1.0d0+aint(abs(nu))
-     tmp2=nu+2.0d0+aint(abs(nu))  !  3 ʤΤ, ͤ 2 .
+     tmp2=nu+2.0d0+aint(abs(nu))  ! 漸化式が 3 項漸化式なので, 初期値が 2 つ.
   end if
 
 
-!-- ٥åؿʬ׻ ---
+!-- ベッセル関数の積分計算 ---
   df_bessj_dnoni=0.0d0
 
   if(nu>-0.5d0)then
@@ -1202,7 +1202,7 @@ double precision function df_bessj_dnoni( nu, t )
  &               +cosh(t*cos(xmax))*((sin(xmax))**(2.0d0*nu)))
      df_bessj_dnoni=df_bessj_dnoni*((0.5d0*x)**nu)/(sqrt(pi_dp)*gamma_func_d(nu+0.5d0))
 
-  else  ! nu <= -0.5 ΤȤ.
+  else  ! nu <= -0.5 のとき.
      bess1=0.0d0
      bess2=0.0d0
      do istep=2,mmax-1
@@ -1220,12 +1220,12 @@ double precision function df_bessj_dnoni( nu, t )
 
      tmp=tmp1
 
-     do while(tmp/=nu)  ! tmp=nu ˤʤä, ˤʤäȽǤ.
+     do while(tmp/=nu)  ! tmp=nu になったら, 求める項になったと判断する.
         bess0=2.0d0*tmp1*bess1/t-bess2
         tmp=tmp-1.0d0
         tmp1=tmp1-1.0d0
         bess2=bess1
-        bess1=bess0  ! η겼
+        bess1=bess0  ! 項の繰り下げ
      end do
 
      df_bessj_dnoni=bess1
@@ -1239,19 +1239,19 @@ end function
 !----------------------------------------------------
 
 real function df_bessy_f( n, z )
-! ѷΥޥؿ׻.
-! ׻ˤ, 
+! 整数次の変形ノイマン関数を計算する.
+! 計算には, 式：
 ! $$K_n(x)=\int^{\infty}_{0}{e^{-z\cosh{t}} \cosh{nt} dt} $$
-! , $n>=0$. $n<0$ˤĤƤ, ѷΥޥؿ:
+! ただし, $n>=0$. $n<0$については, 変形ノイマン関数の漸化式:
 ! $$K_{\nu -1}-K_{\nu +1} =-\frac{2\nu}{x} K_{\nu} $$
-! Ѥ,
-! Ⱦ̵ΰʬˤĤƤ,
-! ʬؿ 10^{-6} ãޤǤǤ.
-! , ˡŬڤɤݾڤǤʤ.
+! を用いる,
+! 半無限領域の積分については,
+! 非積分関数が 10^{-6} に達する点までで打ちきる.
+! ただし, この方法が適切かどうかは保証できない.
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  real, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  real, intent(in) :: z  ! 変数
   integer :: coe1, coe2, coe
   real :: t, bess0, bess1, bess2
   real, parameter :: thres=1.0e-6
@@ -1264,25 +1264,25 @@ real function df_bessy_f( n, z )
      stop
   end if
 
-  if(n<0)then  ! nu <= -1/2 ξν.
+  if(n<0)then  ! nu <= -1/2 の場合の処理.
      coe1=n+1+aint(abs(real(n)))
-     coe2=n+2+aint(abs(real(n)))  !  3 ʤΤ, ͤ 2 .
+     coe2=n+2+aint(abs(real(n)))  ! 漸化式が 3 項漸化式なので, 初期値が 2 つ.
   end if
 
   if(n>=0)then
      df_bessy_f=df_bessy_term1_f( n, z )+df_bessy_term2_f( n, z )
-  else  ! n<0 ΤȤ
+  else  ! n<0 のとき
      bess1=df_bessy_term1_f( coe1, z )+df_bessy_term2_f( coe1, z )
      bess2=df_bessy_term1_f( coe2, z )+df_bessy_term2_f( coe2, z )
 
      coe=coe1
 
-     do while(coe/=n)  ! coe=n ˤʤä, ˤʤäȽǤ.
+     do while(coe/=n)  ! coe=n になったら, 求める項になったと判断する.
         bess0=2.0d0*coe1*bess1/t-bess2
         coe=coe-1.0d0
         coe1=coe1-1.0d0
         bess2=bess1
-        bess1=bess0  ! η겼
+        bess1=bess0  ! 項の繰り下げ
      end do
 
      df_bessy_f=bess1
@@ -1295,19 +1295,19 @@ end function
 !----------------------------------------------------
 
 double precision function df_bessy_d( n, z )
-! ѷΥޥؿ׻.
-! ׻ˤ, 
+! 整数次の変形ノイマン関数を計算する.
+! 計算には, 式：
 ! $$K_n(x)=\int^{\infty}_{0}{e^{-z\cosh{t}} \cosh{nt} dt} $$
-! , $n>=0$. $n<0$ˤĤƤ, ѷΥޥؿ:
+! ただし, $n>=0$. $n<0$については, 変形ノイマン関数の漸化式:
 ! $$K_{\nu -1}-K_{\nu +1} =-\frac{2\nu}{x} K_{\nu} $$
-! Ѥ,
-! Ⱦ̵ΰʬˤĤƤ,
-! ʬؿ 10^{-6} ãޤǤǤ.
-! , ˡŬڤɤݾڤǤʤ.
+! を用いる,
+! 半無限領域の積分については,
+! 非積分関数が 10^{-6} に達する点までで打ちきる.
+! ただし, この方法が適切かどうかは保証できない.
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  double precision, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  double precision, intent(in) :: z  ! 変数
   integer :: coe1, coe2, coe
   double precision :: t, bess0, bess1, bess2
   double precision, parameter :: thres=1.0d-6
@@ -1320,25 +1320,25 @@ double precision function df_bessy_d( n, z )
      stop
   end if
 
-  if(n<0)then  ! nu <= -1/2 ξν.
+  if(n<0)then  ! nu <= -1/2 の場合の処理.
      coe1=n+1+aint(abs(real(n)))
-     coe2=n+2+aint(abs(real(n)))  !  3 ʤΤ, ͤ 2 .
+     coe2=n+2+aint(abs(real(n)))  ! 漸化式が 3 項漸化式なので, 初期値が 2 つ.
   end if
 
   if(n>=0)then
      df_bessy_d=df_bessy_term1_d( n, z )+df_bessy_term2_d( n, z )
-  else  ! n<0 ΤȤ
+  else  ! n<0 のとき
      bess1=df_bessy_term1_d( coe1, z )+df_bessy_term2_d( coe1, z )
      bess2=df_bessy_term1_d( coe2, z )+df_bessy_term2_d( coe2, z )
 
      coe=coe1
 
-     do while(coe/=n)  ! coe=n ˤʤä, ˤʤäȽǤ.
+     do while(coe/=n)  ! coe=n になったら, 求める項になったと判断する.
         bess0=2.0d0*coe1*bess1/t-bess2
         coe=coe-1.0d0
         coe1=coe1-1.0d0
         bess2=bess1
-        bess1=bess0  ! η겼
+        bess1=bess0  ! 項の繰り下げ
      end do
 
      df_bessy_d=bess1
@@ -1353,8 +1353,8 @@ end function
 real function df_bessy_term1_f( n, z )
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  real, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  real, intent(in) :: z  ! 変数
   real :: term1, tmp1, t, term2, dt
   real, parameter :: thres=1.0e-6
 
@@ -1362,12 +1362,12 @@ real function df_bessy_term1_f( n, z )
   term2=0.0
   dt=1.0e-2
 
-!-- Ⱦ̵ʬη׻
-!--  1
+!-- 半無限積分項の計算
+!-- 項 1
 
   t=0.0
 
-  tmp1=0.5  ! ʬؿ z=0 Ǥ x 0.5
+  tmp1=0.5  ! 非積分関数の z=0 での値 x 0.5
   term1=tmp1
 
   do while (tmp1>thres)
@@ -1389,8 +1389,8 @@ end function
 real function df_bessy_term2_f( n, z )
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  real, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  real, intent(in) :: z  ! 変数
   real :: term1, tmp2, t, term2, dt
   real, parameter :: thres=1.0e-6
 
@@ -1398,12 +1398,12 @@ real function df_bessy_term2_f( n, z )
   term2=0.0
   dt=1.0e-2
 
-!-- Ⱦ̵ʬη׻
-!--  2
+!-- 半無限積分項の計算
+!-- 項 2
 
   t=0.0
 
-  tmp2=0.5  ! ʬؿ z=0 Ǥ x 0.5
+  tmp2=0.5  ! 非積分関数の z=0 での値 x 0.5
   term2=tmp2
 
   do while (tmp2>thres)
@@ -1424,8 +1424,8 @@ end function
 double precision function df_bessy_term1_d( n, z )
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  double precision, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  double precision, intent(in) :: z  ! 変数
   double precision :: term1, tmp1, term2, t, dt
   double precision, parameter :: thres=1.0d-6
 
@@ -1433,12 +1433,12 @@ double precision function df_bessy_term1_d( n, z )
   term2=0.0
   dt=1.0d-2
 
-!-- Ⱦ̵ʬη׻
-!--  1
+!-- 半無限積分項の計算
+!-- 項 1
 
   t=0.0d0
 
-  tmp1=0.5d0  ! ʬؿ z=0 Ǥ x 0.5
+  tmp1=0.5d0  ! 非積分関数の z=0 での値 x 0.5
   term1=tmp1
 
   do while (tmp1>thres)
@@ -1460,8 +1460,8 @@ end function
 double precision function df_bessy_term2_d( n, z )
   use Math_Const
   implicit none
-  integer, intent(in) :: n  ! 
-  double precision, intent(in) :: z  ! ѿ
+  integer, intent(in) :: n  ! 次数
+  double precision, intent(in) :: z  ! 変数
   double precision :: term1, tmp2, t, term2, dt
   double precision, parameter :: thres=1.0d-6
 
@@ -1469,12 +1469,12 @@ double precision function df_bessy_term2_d( n, z )
   term2=0.0d0
   dt=1.0d-2
 
-!-- Ⱦ̵ʬη׻
-!--  2
+!-- 半無限積分項の計算
+!-- 項 2
 
   t=0.0d0
 
-  tmp2=0.5d0  ! ʬؿ z=0 Ǥ x 0.5
+  tmp2=0.5d0  ! 非積分関数の z=0 での値 x 0.5
   term2=tmp2
 
   do while (tmp2>thres)
@@ -1493,12 +1493,12 @@ end function
 !----------------------------------------------------
 
 real function df_bessy_fnoni( nu, t )
-! ˤѷΥޥؿ׻.
+! 非整数次における変形ノイマン関数を計算する.
 ! $K_{\nu} =\frac{1}{\sin{\nu \pi}} [I_{-\nu} (x)-I_{\nu} (x)]$
   use Math_Const
   implicit none
-  real, intent(in) :: nu  ! 
-  real, intent(in) :: t  ! ѿ
+  real, intent(in) :: nu  ! 次数
+  real, intent(in) :: t  ! 変数
   intrinsic :: aint
 
   if(t<=0.0)then
@@ -1508,7 +1508,7 @@ real function df_bessy_fnoni( nu, t )
      stop
   end if
 
-  if(nu/=aint(nu))then  ! nu ξ, bessy_f ˥쥯Ȥ.
+  if(nu/=aint(nu))then  ! nu が整数次の場合は, bessy_f にリダイレクトする.
      df_bessy_fnoni=(df_bessj_fnoni( -nu, t )-df_bessj_fnoni( nu, t ))  &
   &              /(sin(nu*pi))
   else
@@ -1522,12 +1522,12 @@ end function
 !----------------------------------------------------
 
 double precision function df_bessy_dnoni( nu, t )
-! ˤѷΥޥؿ׻.
+! 非整数次における変形ノイマン関数を計算する.
 ! $K_{\nu} =\frac{1}{\sin{\nu \pi}} [I_{-\nu} (x)-I_{\nu} (x)]$
   use Math_Const
   implicit none
-  double precision, intent(in) :: nu  ! 
-  double precision, intent(in) :: t  ! ѿ
+  double precision, intent(in) :: nu  ! 次数
+  double precision, intent(in) :: t  ! 変数
   intrinsic :: aint
 
   if(t<=0.0d0)then
@@ -1537,7 +1537,7 @@ double precision function df_bessy_dnoni( nu, t )
      stop
   end if
 
-  if(nu/=aint(nu))then  ! nu ξ, bessy_f ˥쥯Ȥ.
+  if(nu/=aint(nu))then  ! nu が整数次の場合は, bessy_f にリダイレクトする.
      df_bessy_dnoni=(df_bessj_dnoni( -nu, t )-df_bessj_dnoni( nu, t ))  &
   &              /(sin(nu*pi_dp))
   else
@@ -1549,11 +1549,11 @@ end function
 
 !----------------------------------------------------
 !----------------------------------------------------
-!
+!途中
 !real function Airy_f( x )
-! ꡼ؿ׻
+! エアリー関数を計算する
 !  implicit none
-!  real, intent(in) :: x  ! 
+!  real, intent(in) :: x  ! 引数
 !  real :: t, z, dx
 !  real, parameter :: xmin=-1.0
 !  real, parameter :: xmax=1.0
@@ -1573,15 +1573,15 @@ end function
 !----------------------------------------------------
 
 real function gamma_func_f(x)
-! ޴ؿ׻.
-! ˤϡִȿظüؿp.5פζ¿༰.
-! ζ 0<=x<=1 ǤȤʤΤ, ޴ؿ
-! $z\Gamma (z)=\Gamma (z+1)$ ǶŬϰϤȤ.
-! z>1.0 ξ,
+! ガンマ関数を計算する.
+! 基本方針は「岩波数学公式（特殊関数）p.5」の近似多項式を使用.
+! この近似式は 0<=x<=1 でしか使えないので, ガンマ関数の等式
+! $z\Gamma (z)=\Gamma (z+1)$ で近似式の適用範囲に落とし込む.
+! z>1.0 の場合は,
 ! $\Gamma (z)=(z-1)\Gamma (z-1)=\cdots =(z-1)\cdots (x)\Gamma (x)$
-! z<0.0 ξ,
+! z<0.0 の場合は,
 ! $\Gamma (z)=\Gamma (z+1)/z=\cdots =\Gamma (x)/(z\cdots x)$
-! ޤ, ޴ؿ, ǤϷ׻ȥåפ褦.
+! また, ガンマ関数の性質から, 負整数では計算がストップするように設定.
 
   implicit none
   real, intent(in) :: x
@@ -1601,11 +1601,11 @@ real function gamma_func_f(x)
   &     -0.756704078, 0.482199394, -0.193527818, 0.035868343 /)
 
   if(abs(x)>1.0)then
-     intg=aint(abs(x))  ! ʲڤΤ
-     if(x>1.0)then  ! Ƚ
+     intg=aint(abs(x))  ! 小数点以下切り捨て
+     if(x>1.0)then  ! 正負の判別
         tmp=x-intg
      else
-        tmp=x+1.0+intg  ! 0 ޤΤ +1.
+        tmp=x+1.0+intg  ! 0 またぎのための +1.
      end if
   else
      tmp=x
@@ -1617,7 +1617,7 @@ real function gamma_func_f(x)
      gamma_func_f=gamma_func_f+coe(i)*(tmp**i)
   end do
 
-  if(abs(x)>1.0)then  ! ޴ؿˤ׻
+  if(abs(x)>1.0)then  ! ガンマ関数の等式による計算
      tmp=x
      do while(tmp>1.0.or.tmp<0.0)
         if(x>1.0)then
@@ -1637,15 +1637,15 @@ end function
 !----------------------------------------------------
 
 double precision function gamma_func_d(x)
-! ޴ؿ׻.
-! ˤϡִȿظüؿp.5פζ¿༰.
-! ζ 0<=x<=1 ǤȤʤΤ, ޴ؿ
-! $z\Gamma (z)=\Gamma (z+1)$ ǶŬϰϤȤ.
-! z>1.0 ξ,
+! ガンマ関数を計算する.
+! 基本方針は「岩波数学公式（特殊関数）p.5」の近似多項式を使用.
+! この近似式は 0<=x<=1 でしか使えないので, ガンマ関数の等式
+! $z\Gamma (z)=\Gamma (z+1)$ で近似式の適用範囲に落とし込む.
+! z>1.0 の場合は,
 ! $\Gamma (z)=(z-1)\Gamma (z-1)=\cdots =(z-1)\cdots (x)\Gamma (x)$
-! z<0.0 ξ,
+! z<0.0 の場合は,
 ! $\Gamma (z)=\Gamma (z+1)/z=\cdots =\Gamma (x)/(z\cdots x)$
-! ޤ, ޴ؿ, ǤϷ׻ȥåפ褦.
+! また, ガンマ関数の性質から, 負整数では計算がストップするように設定.
 
   implicit none
   double precision, intent(in) :: x
@@ -1665,11 +1665,11 @@ double precision function gamma_func_d(x)
   &     -0.756704078d0, 0.482199394d0, -0.193527818d0, 0.035868343d0 /)
 
   if(abs(x)>1.0d0)then
-     intg=aint(abs(x))  ! ʲڤΤ
-     if(x>1.0d0)then  ! Ƚ
+     intg=aint(abs(x))  ! 小数点以下切り捨て
+     if(x>1.0d0)then  ! 正負の判別
         tmp=x-intg
      else
-        tmp=x+1.0d0+intg  ! 0 ޤΤ +1.
+        tmp=x+1.0d0+intg  ! 0 またぎのための +1.
      end if
   else
      tmp=x
@@ -1681,7 +1681,7 @@ double precision function gamma_func_d(x)
      gamma_func_d=gamma_func_d+coe(i)*(tmp**i)
   end do
 
-  if(abs(x)>1.0d0)then  ! ޴ؿˤ׻
+  if(abs(x)>1.0d0)then  ! ガンマ関数の等式による計算
      tmp=x
      do while(tmp>1.0d0.or.tmp<0.0d0)
         if(x>1.0d0)then
@@ -1701,15 +1701,15 @@ end function
 !----------------------------------------------------
 
 real function beta_func_f( x, y )
-! ١ؿ׻롼.
-! ١ؿȥ޴ؿδ֤δط
+! ベータ関数を計算するルーチン.
+! ベータ関数とガンマ関数の間の関係式
 ! $B(x,y)=\frac{\Gamma (x)\Gamma (y)}{\Gamma (x+y)} $
-! Ѥ뤳Ȥˤä, ޴ؿη׻Ԥ.
-! gamma_func ˤ, ðξ, ٹФ򤷤ƤΤ,
-! ١ؿðˤƤٹ𤬽ФͤˤʤäƤ.
+! を用いることによって, ガンマ関数からの計算を行う.
+! gamma_func において, 引数が特異点の場合, 警告を出す処理をしてあるので,
+! ベータ関数の特異点においても警告が出て落ちる仕様になっている.
   implicit none
-  real, intent(in) :: x  ! 
-  real, intent(in) :: y  ! 
+  real, intent(in) :: x  ! 第一引数
+  real, intent(in) :: y  ! 第二引数
 
   beta_func_f=(gamma_func_f(x)*gamma_func_f(y))/(gamma_func_f(x+y))
 
@@ -1720,15 +1720,15 @@ end function
 !----------------------------------------------------
 
 double precision function beta_func_d( x, y )
-! ١ؿ׻롼.
-! ١ؿȥ޴ؿδ֤δط
+! ベータ関数を計算するルーチン.
+! ベータ関数とガンマ関数の間の関係式
 ! $B(x,y)=\frac{\Gamma (x)\Gamma (y)}{\Gamma (x+y)} $
-! Ѥ뤳Ȥˤä, ޴ؿη׻Ԥ.
-! gamma_func ˤ, ðξ, ٹФ򤷤ƤΤ,
-! ١ؿðˤƤٹ𤬽ФͤˤʤäƤ.
+! を用いることによって, ガンマ関数からの計算を行う.
+! gamma_func において, 引数が特異点の場合, 警告を出す処理をしてあるので,
+! ベータ関数の特異点においても警告が出て落ちる仕様になっている.
   implicit none
-  double precision, intent(in) :: x  ! 
-  double precision, intent(in) :: y  ! 
+  double precision, intent(in) :: x  ! 第一引数
+  double precision, intent(in) :: y  ! 第二引数
 
   beta_func_d=(gamma_func_d(x)*gamma_func_d(y))/(gamma_func_d(x+y))
 
@@ -1738,10 +1738,10 @@ end function
 !----------------------------------------------------
 !----------------------------------------------------
 
-real function delta(t,u)  ! ͥåΥǥ륿׻륵֥롼
+real function delta(t,u)  ! クロネッカーのデルタを計算するサブルーチン
   implicit none
-  integer, intent(in) :: t  ! ʬ
-  integer, intent(in) :: u  ! ʬ
+  integer, intent(in) :: t  ! 行成分
+  integer, intent(in) :: u  ! 列成分
 
   if(t==u)then
      delta=1.0
@@ -1755,32 +1755,32 @@ end function
 
 subroutine besfzero(nmax,mmax,k)
 !**********************************
-!  ٥åؿΥ׻ *
+!  ベッセル関数のゼロ点を計算する *
 !**********************************
   implicit none
-  integer, intent(in) :: nmax          ! ٥åؿΥκĿ
-  integer, intent(in) :: mmax          ! ٥åؿκ缡
-  real, intent(inout) :: k(0:nmax,mmax)  ! mmax ޤǤ nmax+1 ĤΥǼ
+  integer, intent(in) :: nmax          ! ベッセル関数のゼロ点の最大個数
+  integer, intent(in) :: mmax          ! ベッセル関数の最大次数
+  real, intent(inout) :: k(0:nmax,mmax)  ! mmax 次までの nmax+1 個のゼロ点を格納する
   real :: a, b, c, d, e, f, g, lim, dx
   integer :: i, j, n
 
-!-- ʬˡβȶ ---
-  lim=1.0e-6    ! «
+!-- 二分法の解と近似する条件 ---
+  lim=1.0e-6    ! 収束条件
 
-!-- ʬˡꤹ뤿,  ---
-!-- ٥åؿΥδֳ֤Ϥ褽 3 ȤǤΤ,
-!-- 0.5 Ĺ, ޤ
-!-- ա˼ºݻѤκݤ, bessj_f ؿȤƤ뤫ǧΤ.
-!-- Х
+!-- 二分法の二点を決定するための, 刻み幅 ---
+!-- ベッセル関数のゼロ点の間隔はおよそ 3 ごとであるので,
+!-- 0.5 ずつ刻めば, まあいいか
+!-- （注意）実際使用の際は, bessj_f 関数が参照されているかを確認のこと.
+!-- バグ検証中
   dx=0.5
-!-- ν ---
+!-- 配列の初期化 ---
   do i=0,nmax
      do j=1,mmax
         k(i,j)=0.0
      end do
   end do
 
-!-- 0 ׻ ---
+!-- 0 次計算 ---
   k(0,1)=0.0
   d=k(0,1)
 
@@ -1816,7 +1816,7 @@ subroutine besfzero(nmax,mmax,k)
   10 continue
 
   if(nmax > 0)then
-!-- 1 ʾ׻ ---
+!-- 1 次以上計算 ---
      do n=1,nmax
      do 21 i=1,mmax
         d=k(n-1,i)+dx
@@ -1849,30 +1849,30 @@ end subroutine
 
 subroutine besdzero(nmax,mmax,k)
 !**********************************
-!  ٥åؿΥ׻ *
+!  ベッセル関数のゼロ点を計算する *
 !**********************************
   implicit none
-  integer, intent(in) :: nmax          ! ٥åؿΥκĿ
-  integer, intent(in) :: mmax          ! ٥åؿκ缡
-  double precision, intent(inout) :: k(0:nmax,mmax)  ! mmax ޤǤ nmax+1 ĤΥǼ
+  integer, intent(in) :: nmax          ! ベッセル関数のゼロ点の最大個数
+  integer, intent(in) :: mmax          ! ベッセル関数の最大次数
+  double precision, intent(inout) :: k(0:nmax,mmax)  ! mmax 次までの nmax+1 個のゼロ点を格納する
   double precision :: a, b, c, d, e, f, g, lim, dx
   integer :: i, j, n
 
-!-- ʬˡβȶ ---
-  lim=1.0d-6    ! «
+!-- 二分法の解と近似する条件 ---
+  lim=1.0d-6    ! 収束条件
 
-!-- ʬˡꤹ뤿,  ---
-!-- ٥åؿΥδֳ֤Ϥ褽 3 ȤǤΤ,
-!-- 0.5 Ĺ, ޤ
+!-- 二分法の二点を決定するための, 刻み幅 ---
+!-- ベッセル関数のゼロ点の間隔はおよそ 3 ごとであるので,
+!-- 0.5 ずつ刻めば, まあいいか
   dx=0.5d0
-!-- ν ---
+!-- 配列の初期化 ---
   do i=0,nmax
      do j=1,mmax
         k(i,j)=0.0d0
      end do
   end do
 
-!-- 0 ׻ ---
+!-- 0 次計算 ---
   k(0,1)=0.0d0
   d=k(0,1)
 
@@ -1908,7 +1908,7 @@ subroutine besdzero(nmax,mmax,k)
   10 continue
 
   if(nmax > 0)then
-!-- 1 ʾ׻ ---
+!-- 1 次以上計算 ---
      do n=1,nmax
      do 21 i=1,mmax
         d=k(n-1,i)+dx
