@@ -3,7 +3,7 @@
 !-----------------------------------------------------------------------
 
 module Thermo_Advanced_Routine
-! å롼, ؿ use ʣǮϳشؿ׻⥸塼
+! 基礎ルーチン, 関数集を use して複雑な熱力学関数を計算するモジュール
   use Thermo_Function
   use Thermo_Routine
   use Thermo_Advanced_Function
@@ -15,15 +15,15 @@ module Thermo_Advanced_Routine
 contains
 
 subroutine Rich_horizon( za, pta, ptg, va, qva, qvs, Ri )
-! Х륯㡼ɥ׻롼
+! バルクリチャードソン数を計算するルーチン
   implicit none
-  real, intent(in) :: za  ! 㡼ɥ׻ [m]
-  real, intent(in), dimension(:,:) :: pta  ! za Ǥβ [K]
-  real, intent(in), dimension(size(pta,1),size(pta,2)) :: ptg  ! ɽ̤Ǥβ [K]
-  real, intent(in), dimension(size(pta,1),size(pta,2)) :: va  !  za Ǥοʿ® [m/s]
-  real, intent(in), dimension(size(pta,1),size(pta,2)) :: qva  ! za Ǥκ [kg/kg]
-  real, intent(in), dimension(size(pta,1),size(pta,2)) :: qvs  ! ɽ̤Ǥ˰º [kg/kg]
-  real, intent(inout), dimension(size(pta,1),size(pta,2)) :: Ri  ! 㡼ɥ
+  real, intent(in) :: za  ! リチャードソン数を計算する高度 [m]
+  real, intent(in), dimension(:,:) :: pta  ! za での仮温位 [K]
+  real, intent(in), dimension(size(pta,1),size(pta,2)) :: ptg  ! 地表面での温位 [K]
+  real, intent(in), dimension(size(pta,1),size(pta,2)) :: va  ! 高度 za での水平風速の絶対値 [m/s]
+  real, intent(in), dimension(size(pta,1),size(pta,2)) :: qva  ! za での混合比 [kg/kg]
+  real, intent(in), dimension(size(pta,1),size(pta,2)) :: qvs  ! 地表面での飽和混合比 [kg/kg]
+  real, intent(inout), dimension(size(pta,1),size(pta,2)) :: Ri  ! 求めるリチャードソン数
   integer :: i, j, nx, ny
 
   nx=size(pta,1)
@@ -44,12 +44,12 @@ end subroutine
 !--------------------------------------------------------
 
 subroutine Louis_horizon( z, z0m, richard, Lo )
-! Louis(1980) ƤƤ絤԰٤θХ륯׻ؿ
+! Louis(1980) で提案されている大気の不安定度を考慮したバルク係数の補正係数を計算する関数
   implicit none
-  real, intent(in) :: z  ! cm  [m]
-  real, intent(in), dimension(:,:) :: z0m  ! ǥǷ׻ٹ [m]
-  real, intent(in), dimension(size(z0m,1),size(z0m,2)) :: richard  ! Х륯㡼ɥ
-  real, intent(inout), dimension(size(z0m,1),size(z0m,2)) :: Lo  ! 
+  real, intent(in) :: z  ! cm を求める高度 [m]
+  real, intent(in), dimension(:,:) :: z0m  ! モデルで計算される粗度高度 [m]
+  real, intent(in), dimension(size(z0m,1),size(z0m,2)) :: richard  ! バルクリチャードソン数
+  real, intent(inout), dimension(size(z0m,1),size(z0m,2)) :: Lo  ! 補正係数
   real, parameter :: b=5.0, c=5.0
   integer :: i, j, nx, ny
 
@@ -71,12 +71,12 @@ end subroutine
 !--------------------------------------------------------
 
 subroutine cm_horizon( z, z0m, coem, richard )
-! ư̤˴ؤХ륯׻롼
+! 運動量に関するバルク係数を計算するルーチン
   implicit none
-  real, intent(in) :: z  ! cm  [m]
-  real, intent(in), dimension(:,:) :: z0m  ! ǥǷ׻ٹ [m]
-  real, intent(inout), dimension(size(z0m,1),size(z0m,2)) :: coem  ! Х륯
-  real, intent(in), dimension(size(z0m,1),size(z0m,2)), optional :: richard  ! Louis (1980) ΥǷ׻ΥХ륯㡼ɥ
+  real, intent(in) :: z  ! cm を求める高度 [m]
+  real, intent(in), dimension(:,:) :: z0m  ! モデルで計算される粗度高度 [m]
+  real, intent(inout), dimension(size(z0m,1),size(z0m,2)) :: coem  ! バルク係数
+  real, intent(in), dimension(size(z0m,1),size(z0m,2)), optional :: richard  ! Louis (1980) のスキームで計算する場合のバルクリチャードソン数
   integer :: i, j, nx, ny
 
   nx=size(z0m,1)
@@ -110,11 +110,11 @@ end subroutine
 !--------------------------------------------------------
 
 subroutine cmdva_2_ust_horizon( cmd, va, velst )
-! Х륯, ®٤໤® u_* ׻롼
+! バルク係数, 速度から摩擦速度 u_* を計算するルーチン
   implicit none
-  real, intent(in), dimension(:,:) :: cmd  !  za ǤΥХ륯
-  real, intent(in), dimension(size(cmd,1),size(cmd,2)) :: va  !  za Ǥοʿ [m/s]
-  real, intent(inout), dimension(size(cmd,1),size(cmd,2)) :: velst  ! ໤® [m/s]
+  real, intent(in), dimension(:,:) :: cmd  ! 高度 za でのバルク係数
+  real, intent(in), dimension(size(cmd,1),size(cmd,2)) :: va  ! 高度 za での水平風の絶対値 [m/s]
+  real, intent(inout), dimension(size(cmd,1),size(cmd,2)) :: velst  ! 摩擦速度 [m/s]
   integer :: i, j, nx, ny
 
   nx=size(cmd,1)
@@ -136,12 +136,12 @@ end subroutine
 !--------------------------------------------------------
 
 subroutine taurho_2_ust_horizon( taux, tauy, rho, velst )
-! ϤΥǥȿʿ 2 ʬȤι٤Ǥ̩٤໤® u_* ׻롼
+! 風応力のデカルト水平 2 成分とその高度での密度から摩擦速度 u_* を計算するルーチン
   implicit none
-  real, intent(in), dimension(:,:) :: taux  ! ٤ǤϤΥǥ x ʬ [N/m]
-  real, intent(in), dimension(size(taux,1),size(taux,2)) :: tauy  ! ٤ǤϤΥǥ y ʬ [N/m]
-  real, intent(in), dimension(size(taux,1),size(taux,2)) :: rho  ! ٤Ǥ̩ [kg/m^3]
-  real, intent(inout), dimension(size(taux,1),size(taux,2)) :: velst  ! ໤® [m/s]
+  real, intent(in), dimension(:,:) :: taux  ! 基準高度での風応力のデカルト x 成分 [N/m]
+  real, intent(in), dimension(size(taux,1),size(taux,2)) :: tauy  ! 基準高度での風応力のデカルト y 成分 [N/m]
+  real, intent(in), dimension(size(taux,1),size(taux,2)) :: rho  ! 基準高度での密度 [kg/m^3]
+  real, intent(inout), dimension(size(taux,1),size(taux,2)) :: velst  ! 摩擦速度 [m/s]
   integer :: i, j, nx, ny
 
   nx=size(taux,1)
@@ -165,29 +165,29 @@ end subroutine
 subroutine EDC_TKE( types, dt, x, y, z, pt, tke, nuth, nutv, nuhh, nuhv, undef )
   use Phys_Const
   implicit none
-! 1.5  TKE ѤǴ׻.
-  character(1), intent(in) :: types  ! ήμλ.
-  ! ήξ = 'i', ήξ = 'r'.
-  real, intent(in) :: dt    ! ֥ƥå [s]
-  real, intent(in) :: x(:)  ! x κɸѿ [m]
-  real, intent(in) :: y(:)  ! y κɸѿ [m]
-  real, intent(in) :: z(:)  ! z κɸѿ [m]
-  real, intent(in) :: pt(size(x),size(y),size(z))  ! ܾβ [K]
+! 1.5 次の TKE を用いた渦粘性係数を計算する.
+  character(1), intent(in) :: types  ! 乱流の種類の指定.
+  ! 等方性乱流の場合 = 'i', 非等方性乱流の場合 = 'r'.
+  real, intent(in) :: dt    ! 時間ステップ [s]
+  real, intent(in) :: x(:)  ! x 方向の座標変数 [m]
+  real, intent(in) :: y(:)  ! y 方向の座標変数 [m]
+  real, intent(in) :: z(:)  ! z 方向の座標変数 [m]
+  real, intent(in) :: pt(size(x),size(y),size(z))  ! 基本場の温位 [K]
   real, intent(in) :: tke(size(x),size(y),size(z))  ! tke [J/kg]
-  real, intent(inout) :: nuth(size(x),size(y),size(z))  ! ʿǴ [m^2/s]
-  real, intent(inout) :: nutv(size(x),size(y),size(z))  ! ľǴ [m^2/s]
-  real, intent(inout) :: nuhh(size(x),size(y),size(z))  ! ʿȻ [m^2/s]
-  real, intent(inout) :: nuhv(size(x),size(y),size(z))  ! ľȻ [m^2/s]
-  real, intent(in), optional :: undef   ! ̤
+  real, intent(inout) :: nuth(size(x),size(y),size(z))  ! 水平渦粘性係数 [m^2/s]
+  real, intent(inout) :: nutv(size(x),size(y),size(z))  ! 鉛直渦粘性係数 [m^2/s]
+  real, intent(inout) :: nuhh(size(x),size(y),size(z))  ! 水平渦拡散係数 [m^2/s]
+  real, intent(inout) :: nuhv(size(x),size(y),size(z))  ! 鉛直渦拡散係数 [m^2/s]
+  real, intent(in), optional :: undef   ! 未定義値
   real :: BV(size(x),size(y),size(z))
   real, parameter :: alpha=1.0e-6
   integer :: i, j, k
-  integer :: nx  !  1 ǿ
-  integer :: ny  !  2 ǿ
-  integer :: nz  !  3 ǿ
-  real :: dx(size(x))  ! x γʻҴֳ [m]
-  real :: dy(size(y))  ! y γʻҴֳ [m]
-  real :: dz(size(z))  ! z γʻҴֳ [m]
+  integer :: nx  ! 第 1 要素数
+  integer :: ny  ! 第 2 要素数
+  integer :: nz  ! 第 3 要素数
+  real :: dx(size(x))  ! x 方向の格子間隔 [m]
+  real :: dy(size(y))  ! y 方向の格子間隔 [m]
+  real :: dz(size(z))  ! z 方向の格子間隔 [m]
   real :: dsh(size(x),size(y),size(z))
   real :: dsv(size(x),size(y),size(z))
   real :: lh(size(x),size(y),size(z))
@@ -195,7 +195,7 @@ subroutine EDC_TKE( types, dt, x, y, z, pt, tke, nuth, nutv, nuhh, nuhv, undef )
   real :: tmp, ck
   intrinsic :: min, max
   logical, dimension(size(x),size(y),size(z)) :: undeflag
-  real, parameter :: kmin=0.125   ! nu κͤ kmin / dt (By CReSS)
+  real, parameter :: kmin=0.125   ! nu の最大値は kmin / dt (By CReSS)
 
   nx=size(x)
   ny=size(y)
@@ -203,7 +203,7 @@ subroutine EDC_TKE( types, dt, x, y, z, pt, tke, nuth, nutv, nuhh, nuhv, undef )
 
   ck=kmin/dt
 
-  undeflag=.false.  ! undef ץ󤬤ʤȤϾ false.
+  undeflag=.false.  ! undef オプションがないときは常に false.
 
   do i=2,nx-1
      dx(i)=0.5*(x(i+1)-x(i-1))
@@ -222,8 +222,8 @@ subroutine EDC_TKE( types, dt, x, y, z, pt, tke, nuth, nutv, nuhh, nuhv, undef )
   dz(1)=z(2)-z(1)
   dz(nz)=z(nz)-z(nz-1)
 
-! ľ ptb Υ֥ȥХ鿶ư׻.
-! ʹ, undef Τ, ʤʬ.
+! 鉛直方向に ptb のブラントバイサラ振動数を計算する.
+! 以降, undef のあり, なしで分ける.
   if(present(undef))then
 
 !$omp parallel default(shared)
@@ -284,10 +284,10 @@ subroutine EDC_TKE( types, dt, x, y, z, pt, tke, nuth, nutv, nuhh, nuhv, undef )
 
   end if
 
-!-- ʹ, undeflag ˤä, undef ץΤʤ˴ؤ餺,
-!-- η׻Ƿ׻Ǥ.
+!-- 以降, undeflag によって, undef オプションのあるなしに関わらず,
+!-- 統一の計算式で計算できる.
 
-  if(types(1:1)=='i')then  ! ήξ
+  if(types(1:1)=='i')then  ! 等方性乱流の場合
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i,j,k)
      do k=1,nz
@@ -311,7 +311,7 @@ subroutine EDC_TKE( types, dt, x, y, z, pt, tke, nuth, nutv, nuhh, nuhv, undef )
 !$omp end do
 !$omp end parallel
 
-  else if(types(1:1)=='r')then  ! ήξ
+  else if(types(1:1)=='r')then  ! 非等方性乱流の場合
 
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i,j,k)
@@ -350,10 +350,10 @@ subroutine EDC_TKE( types, dt, x, y, z, pt, tke, nuth, nutv, nuhh, nuhv, undef )
               nuth(i,j,k)=min(nuth(i,j,k),ck*(dsh(i,j,k)**2))
               nutv(i,j,k)=min(nutv(i,j,k),ck*(dsv(i,j,k)**2))
 
-              if(types(1:1)=='i')then  ! ήξ
+              if(types(1:1)=='i')then  ! 等方性乱流の場合
                  nuhh(i,j,k)=nuth(i,j,k)*(1.0+2.0*(lv(i,j,k)/dsv(i,j,k)))
                  nuhv(i,j,k)=nutv(i,j,k)*(1.0+2.0*(lv(i,j,k)/dsv(i,j,k)))
-              else if(types(1:1)=='r')then  ! ήξ
+              else if(types(1:1)=='r')then  ! 非等方性乱流の場合
                  nuhh(i,j,k)=3.0*nuth(i,j,k)
                  nuhv(i,j,k)=nutv(i,j,k)*(1.0+2.0*(lv(i,j,k)/dsv(i,j,k)))
               end if
@@ -378,38 +378,38 @@ end subroutine EDC_TKE
 subroutine EDC_SMA( types, dt, x, y, z, u, v, w, pt, nuth, nutv, nuhh, nuhv, undef )
   use Phys_Const
   implicit none
-! ޥ󥹥ˤ뱲Ǵ׻.
-  character(1), intent(in) :: types  ! ήμλ.
-  ! ήξ = 'i', ήξ = 'r'.
-  real, intent(in) :: dt    ! ֥ƥå [s]
-  real, intent(in) :: x(:)  ! x κɸѿ [m]
-  real, intent(in) :: y(:)  ! y κɸѿ [m]
-  real, intent(in) :: z(:)  ! z κɸѿ [m]
-  real, intent(in) :: u(size(x),size(y),size(z))  ! x ® [m/s]
-  real, intent(in) :: v(size(x),size(y),size(z))  ! y ® [m/s]
-  real, intent(in) :: w(size(x),size(y),size(z))  ! z ® [m/s]
-  real, intent(in) :: pt(size(x),size(y),size(z))  ! ܾβ [K]
-  real, intent(inout) :: nuth(size(x),size(y),size(z))  ! ʿǴ [m^2/s]
-  real, intent(inout) :: nutv(size(x),size(y),size(z))  ! ľǴ [m^2/s]
-  real, intent(inout) :: nuhh(size(x),size(y),size(z))  ! ʿȻ [m^2/s]
-  real, intent(inout) :: nuhv(size(x),size(y),size(z))  ! ľȻ [m^2/s]
-  real, intent(in), optional :: undef   ! ̤
+! スマゴリンスキースキームによる渦粘性係数を計算する.
+  character(1), intent(in) :: types  ! 乱流の種類の指定.
+  ! 等方性乱流の場合 = 'i', 非等方性乱流の場合 = 'r'.
+  real, intent(in) :: dt    ! 時間ステップ [s]
+  real, intent(in) :: x(:)  ! x 方向の座標変数 [m]
+  real, intent(in) :: y(:)  ! y 方向の座標変数 [m]
+  real, intent(in) :: z(:)  ! z 方向の座標変数 [m]
+  real, intent(in) :: u(size(x),size(y),size(z))  ! x 方向の速度 [m/s]
+  real, intent(in) :: v(size(x),size(y),size(z))  ! y 方向の速度 [m/s]
+  real, intent(in) :: w(size(x),size(y),size(z))  ! z 方向の速度 [m/s]
+  real, intent(in) :: pt(size(x),size(y),size(z))  ! 基本場の温位 [K]
+  real, intent(inout) :: nuth(size(x),size(y),size(z))  ! 水平渦粘性係数 [m^2/s]
+  real, intent(inout) :: nutv(size(x),size(y),size(z))  ! 鉛直渦粘性係数 [m^2/s]
+  real, intent(inout) :: nuhh(size(x),size(y),size(z))  ! 水平渦拡散係数 [m^2/s]
+  real, intent(inout) :: nuhv(size(x),size(y),size(z))  ! 鉛直渦拡散係数 [m^2/s]
+  real, intent(in), optional :: undef   ! 未定義値
   real :: BV(size(x),size(y),size(z))
   real, parameter :: alpha=1.0e-6
   integer :: i, j, k
-  integer :: nx  !  1 ǿ
-  integer :: ny  !  2 ǿ
-  integer :: nz  !  3 ǿ
-  real :: dx(size(x))  ! x γʻҴֳ [m]
-  real :: dy(size(y))  ! y γʻҴֳ [m]
-  real :: dz(size(z))  ! z γʻҴֳ [m]
+  integer :: nx  ! 第 1 要素数
+  integer :: ny  ! 第 2 要素数
+  integer :: nz  ! 第 3 要素数
+  real :: dx(size(x))  ! x 方向の格子間隔 [m]
+  real :: dy(size(y))  ! y 方向の格子間隔 [m]
+  real :: dz(size(z))  ! z 方向の格子間隔 [m]
   real, dimension(size(x),size(y),size(z)) :: dsh, dsv, def, tmp
   real :: ck, coea
   intrinsic :: min, max
   logical, dimension(size(x),size(y),size(z)) :: undeflag
-  real, parameter :: kmin=0.125   ! nu κͤ kmin / dt (By CReSS)
-  real, parameter :: csnum=0.21   ! ޥ󥹥
-  real, parameter :: Praiv=3.0    ! ץȥ () εտ.
+  real, parameter :: kmin=0.125   ! nu の最大値は kmin / dt (By CReSS)
+  real, parameter :: csnum=0.21   ! スマゴリンスキー定数
+  real, parameter :: Praiv=3.0    ! プラントル数 (定数) の逆数.
 
   nx=size(x)
   ny=size(y)
@@ -422,7 +422,7 @@ subroutine EDC_SMA( types, dt, x, y, z, u, v, w, pt, nuth, nutv, nuhh, nuhv, und
   ck=kmin/dt
   coea=2.0/3.0
 
-  undeflag=.false.  ! undef ץ󤬤ʤȤϾ false.
+  undeflag=.false.  ! undef オプションがないときは常に false.
 
   do i=2,nx-1
      dx(i)=0.5*(x(i+1)-x(i-1))
@@ -441,8 +441,8 @@ subroutine EDC_SMA( types, dt, x, y, z, u, v, w, pt, nuth, nutv, nuhh, nuhv, und
   dz(1)=z(2)-z(1)
   dz(nz)=z(nz)-z(nz-1)
 
-! ľ ptb Υ֥ȥХ鿶ư׻.
-! ʹ, undef Τ, ʤʬ.
+! 鉛直方向に ptb のブラントバイサラ振動数を計算する.
+! 以降, undef のあり, なしで分ける.
   if(present(undef))then
 
 !$omp parallel default(shared)
@@ -533,10 +533,10 @@ subroutine EDC_SMA( types, dt, x, y, z, u, v, w, pt, nuth, nutv, nuhh, nuhv, und
 
   end if
 
-!-- ʹ, undeflag ˤä, undef ץΤʤ˴ؤ餺,
-!-- η׻Ƿ׻Ǥ.
+!-- 以降, undeflag によって, undef オプションのあるなしに関わらず,
+!-- 統一の計算式で計算できる.
 
-  if(types(1:1)=='i')then  ! ήξ
+  if(types(1:1)=='i')then  ! 等方性乱流の場合
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i,j,k)
      do k=1,nz
@@ -552,7 +552,7 @@ subroutine EDC_SMA( types, dt, x, y, z, u, v, w, pt, nuth, nutv, nuhh, nuhv, und
 !$omp end do
 !$omp end parallel
 
-  else if(types(1:1)=='r')then  ! ήξ
+  else if(types(1:1)=='r')then  ! 非等方性乱流の場合
 
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i,j,k)
@@ -585,11 +585,11 @@ subroutine EDC_SMA( types, dt, x, y, z, u, v, w, pt, nuth, nutv, nuhh, nuhv, und
 !-- CReSS original
               nuth(i,j,k)=min(nuth(i,j,k),ck*sqrt(dx(i)*dy(j)))
 
-              if(types(1:1)=='i')then  ! ήξ
+              if(types(1:1)=='i')then  ! 等方性乱流の場合
                  nutv(i,j,k)=nuth(i,j,k)
                  nuhh(i,j,k)=Praiv*nuth(i,j,k)
                  nuhv(i,j,k)=nuhh(i,j,k)
-              else if(types(1:1)=='r')then  ! ήξ
+              else if(types(1:1)=='r')then  ! 非等方性乱流の場合
                  nutv(i,j,k)=((csnum*dsv(i,j,k))**2)*(def(i,j,k)-BV(i,j,k)*Praiv)
                  if(nutv(i,j,k)<0.0)then
                     nutv(i,j,k)=0.0
@@ -734,16 +734,16 @@ end subroutine EDC_SMA
 !--------------------------------------------------------
 
 subroutine Brunt_Freq( z, pt, BV, undeff )
-! ֥ȥХ鿶ư 2 ׻.
+! ブラントバイサラ振動数の 2 乗を計算する.
   use Phys_Const
   implicit none
-  real, intent(in) :: z(:)  ! z κɸѿ [m]
-  real, intent(in) :: pt(size(z))  !  [K]
-  real, intent(inout) :: BV(size(z))  ! ֥ȥХ鿶ư [1/s]
+  real, intent(in) :: z(:)  ! z 方向の座標変数 [m]
+  real, intent(in) :: pt(size(z))  ! 温位 [K]
+  real, intent(inout) :: BV(size(z))  ! ブラントバイサラ振動数 [1/s]
   real, intent(in), optional :: undeff
   integer :: i, j, k
-  integer :: nz  !  3 ǿ
-  real :: dz  ! z γʻҴֳ [m]
+  integer :: nz  ! 第 3 要素数
+  real :: dz  ! z 方向の格子間隔 [m]
 
   if(present(undeff))then
 
@@ -755,7 +755,7 @@ subroutine Brunt_Freq( z, pt, BV, undeff )
 
   end if
 
-!-- ʲ, grad_1d ˤä undef ƤΤ, BV Ƚ.
+!-- 以下, grad_1d によって undef 点が増えているので, BV で判定.
   do k=1,nz
      if(present(undeff))then
         if(BV(k)==undeff)then
@@ -774,25 +774,25 @@ end subroutine
 !--------------------------------------------------------
 
 subroutine Ertel_PV( x, y, z, u, v, w, rho, pt, cor, pv, undeff, sx, sy, sz, cord )
-! ƥΥݥƥ󥷥뱲٤׻
+! エルテルのポテンシャル渦度を計算する
   implicit none
-  real, intent(in) :: x(:)  ! x κɸѿ [m]
-  real, intent(in) :: y(:)  ! y κɸѿ [m]
-  real, intent(in) :: z(:)  ! z κɸѿ [m]
-  real, intent(in) :: u(size(x),size(y),size(z))  ! ®پ x ʬ [m/s]
-  real, intent(in) :: v(size(x),size(y),size(z))  ! ®پ y ʬ [m/s]
-  real, intent(in) :: w(size(x),size(y),size(z))  ! ®پ z ʬ [m/s]
-  real, intent(in) :: rho(size(z))  ! ̩پ [kg/m^3]
-  real, intent(in) :: pt(size(x),size(y),size(z))  ! ̾ [K]
-  real, intent(in) :: cor(size(x),size(y))  ! ꥪѥ᡼ [/s]
+  real, intent(in) :: x(:)  ! x 方向の座標変数 [m]
+  real, intent(in) :: y(:)  ! y 方向の座標変数 [m]
+  real, intent(in) :: z(:)  ! z 方向の座標変数 [m]
+  real, intent(in) :: u(size(x),size(y),size(z))  ! 速度場の x 成分 [m/s]
+  real, intent(in) :: v(size(x),size(y),size(z))  ! 速度場の y 成分 [m/s]
+  real, intent(in) :: w(size(x),size(y),size(z))  ! 速度場の z 成分 [m/s]
+  real, intent(in) :: rho(size(z))  ! 密度場 [kg/m^3]
+  real, intent(in) :: pt(size(x),size(y),size(z))  ! 温位場 [K]
+  real, intent(in) :: cor(size(x),size(y))  ! コリオリパラメータ [/s]
   real, intent(inout) :: pv(size(x),size(y),size(z))  ! PV [Km^2/kgs]
   real, intent(in), optional :: undeff
-  real, intent(in), optional :: sx(size(x),size(y),size(z))  ! 󥰥ե
-  real, intent(in), optional :: sy(size(x),size(y),size(z))  ! 󥰥ե
-  real, intent(in), optional :: sz(size(x),size(y),size(z))  ! 󥰥ե
-  character(1), intent(in), optional :: cord   ! ľɸ
-                              ! 'z', 'p' =  [m],  [Pa]
-                              ! ǥե = 'z'
+  real, intent(in), optional :: sx(size(x),size(y),size(z))  ! スケーリングファクター
+  real, intent(in), optional :: sy(size(x),size(y),size(z))  ! スケーリングファクター
+  real, intent(in), optional :: sz(size(x),size(y),size(z))  ! スケーリングファクター
+  character(1), intent(in), optional :: cord   ! 鉛直座標系
+                              ! 'z', 'p' = 幾何高度 [m], 圧力 [Pa]
+                              ! デフォルト = 'z'
   real :: tmp1(size(x),size(y),size(z))
   real :: tmp2(size(x),size(y),size(z))
   real :: tmp3(size(x),size(y),size(z))
@@ -801,9 +801,9 @@ subroutine Ertel_PV( x, y, z, u, v, w, rho, pt, cor, pv, undeff, sx, sy, sz, cor
   real :: tmp6(size(x),size(y),size(z))
   real :: tmp7(size(x),size(y),size(z))
   integer :: i, j, k
-  integer :: nx  !  1 ǿ
-  integer :: ny  !  2 ǿ
-  integer :: nz  !  3 ǿ
+  integer :: nx  ! 第 1 要素数
+  integer :: ny  ! 第 2 要素数
+  integer :: nz  ! 第 3 要素数
   real :: scalex(size(x),size(y),size(z))
   real :: scaley(size(x),size(y),size(z))
   real :: scalez(size(x),size(y),size(z))
@@ -874,22 +874,22 @@ subroutine Ertel_PV( x, y, z, u, v, w, rho, pt, cor, pv, undeff, sx, sy, sz, cor
   end if
 
   if(present(undeff))then
-!  ̤ζָۤ׻.
+!  温位の空間勾配を計算.
      call grad_3d( x, y, z, pt, tmp1, tmp2, tmp3, undeff,  &
   &                    scalex, scaley, scalez )
-!  3  rotation ׻.
+!  3 次元 rotation を計算.
      call curl_3d( x, y, z, u, v, w, tmp4, tmp5, tmp6, undeff,  & 
   &               scalex, scaley, scalez )
-!  omega  grad pt Ѥ׻
+!  omega と grad pt の内積を計算
      call dot_prod_3d( tmp4, tmp5, tmp6, tmp1, tmp2, tmp3, tmp7, undeff )
   else
-!  ̤ζָۤ׻.
+!  温位の空間勾配を計算.
      call grad_3d( x, y, z, pt, tmp1, tmp2, tmp3,  &
   &                    hx=scalex, hy=scaley, hz=scalez )
-!  3  rotation ׻.
+!  3 次元 rotation を計算.
      call curl_3d( x, y, z, u, v, w, tmp4, tmp5, tmp6,  & 
   &               hx=scalex, hy=scaley, hz=scalez )
-!  omega  grad pt Ѥ׻
+!  omega と grad pt の内積を計算
      call dot_prod_3d( tmp4, tmp5, tmp6, tmp1, tmp2, tmp3, tmp7 )
   end if
 
@@ -905,7 +905,7 @@ subroutine Ertel_PV( x, y, z, u, v, w, rho, pt, cor, pv, undeff, sx, sy, sz, cor
                  pv(i,j,k)=undeff
               else
                  pv(i,j,k)=(tmp7(i,j,k)+cor(i,j)*tmp3(i,j,k))/rho(k)
-                 ! ׻Τб٤ʤΤ, ꥪ­碌.
+                 ! 計算するのは絶対渦度なので, コリオリを足し合わせ.
               end if
            end do
         end do
@@ -935,27 +935,27 @@ subroutine Ertel_PV( x, y, z, u, v, w, rho, pt, cor, pv, undeff, sx, sy, sz, cor
 end subroutine
 
 !--------------------------------------------------------
-!-- ʹߤϸκƥåȥǥ󥰤κŬɬ
-!-- ޥ˥奢벽Ϥޤ.
-!-- ؿȤƤѤƤϤʤ.
+!-- 以降は原式の再チェックとコーディングの最適化必要
+!-- マニュアル化はまだ.
+!-- 関数としては利用してはいけない.
 !--------------------------------------------------------
 
 subroutine HEPV( x, y, z, u, v, rhoc, pt, cor, pv, undeff, sx, sy )
-! ϳضΩķϤǤ, ǤդαľɸϤˤ
-! ƥΥݥƥ󥷥뱲٤׻.
+! 静力学近似が成り立つ系での, 任意の鉛直座標系における
+! エルテルのポテンシャル渦度を計算する.
   implicit none
-  real, intent(in) :: x(:)  ! x κɸѿ [MKS unit]
-  real, intent(in) :: y(:)  ! y κɸѿ [MKS unit]
-  real, intent(in) :: z(:)  ! z κɸѿ [MKS unit]
-  real, intent(in) :: u(size(x),size(y),size(z))  ! ®پ x ʬ [m/s]
-  real, intent(in) :: v(size(x),size(y),size(z))  ! ®پ y ʬ [m/s]
-  real, intent(in) :: rhoc(size(x),size(y),size(z))  !Ťդ̩ [MKS unit]
-  real, intent(in) :: pt(size(x),size(y),size(z))  ! 顼¸
-  real, intent(in) :: cor(size(x),size(y))  ! ꥪѥ᡼ [/s]
+  real, intent(in) :: x(:)  ! x 方向の座標変数 [MKS unit]
+  real, intent(in) :: y(:)  ! y 方向の座標変数 [MKS unit]
+  real, intent(in) :: z(:)  ! z 方向の座標変数 [MKS unit]
+  real, intent(in) :: u(size(x),size(y),size(z))  ! 速度場の x 成分 [m/s]
+  real, intent(in) :: v(size(x),size(y),size(z))  ! 速度場の y 成分 [m/s]
+  real, intent(in) :: rhoc(size(x),size(y),size(z))  !重み付き密度 [MKS unit]
+  real, intent(in) :: pt(size(x),size(y),size(z))  ! スカラー保存量
+  real, intent(in) :: cor(size(x),size(y))  ! コリオリパラメータ [/s]
   real, intent(inout) :: pv(size(x),size(y),size(z))  ! PV [Km^2/kgs]
   real, intent(in), optional :: undeff
-  real, intent(in), optional :: sx(size(x),size(y))  ! 󥰥ե
-  real, intent(in), optional :: sy(size(x),size(y))  ! 󥰥ե
+  real, intent(in), optional :: sx(size(x),size(y))  ! スケーリングファクター
+  real, intent(in), optional :: sy(size(x),size(y))  ! スケーリングファクター
   real :: tmp1(size(x),size(y),size(z))
   real :: tmp2(size(x),size(y),size(z))
   real :: tmp3(size(x),size(y),size(z))
@@ -964,9 +964,9 @@ subroutine HEPV( x, y, z, u, v, rhoc, pt, cor, pv, undeff, sx, sy )
   real :: tmp6(size(x),size(y),size(z))
   real :: tmp7(size(x),size(y),size(z))
   integer :: i, j, k
-  integer :: nx  !  1 ǿ
-  integer :: ny  !  2 ǿ
-  integer :: nz  !  3 ǿ
+  integer :: nx  ! 第 1 要素数
+  integer :: ny  ! 第 2 要素数
+  integer :: nz  ! 第 3 要素数
   real :: scalex(size(x),size(y))
   real :: scaley(size(x),size(y))
 
@@ -1003,7 +1003,7 @@ subroutine HEPV( x, y, z, u, v, rhoc, pt, cor, pv, undeff, sx, sy )
   end if
 
   if(present(undeff))then
-  !  顼¸̤ζָ, rotation ׻.
+  !  スカラー保存量の空間勾配, rotation を計算.
 !$omp parallel default(shared)
 !$omp do schedule(runtime) private(k)
      do k=1,nz
@@ -1040,7 +1040,7 @@ subroutine HEPV( x, y, z, u, v, rhoc, pt, cor, pv, undeff, sx, sy )
 !$omp end do
 !$omp end parallel
 
-  !  omega  grad pt Ѥ׻
+  !  omega と grad pt の内積を計算
      call dot_prod_3d( tmp4, tmp5, tmp6, tmp1, tmp2, tmp3, tmp7, undeff )
 
 !$omp parallel default(shared)
@@ -1063,7 +1063,7 @@ subroutine HEPV( x, y, z, u, v, rhoc, pt, cor, pv, undeff, sx, sy )
 
   else
 
-  !  顼¸̤ζָ, rotation ׻.
+  !  スカラー保存量の空間勾配, rotation を計算.
 !$omp parallel default(shared)
 !$omp do schedule(runtime) private(k)
      do k=1,nz
@@ -1096,7 +1096,7 @@ subroutine HEPV( x, y, z, u, v, rhoc, pt, cor, pv, undeff, sx, sy )
 !$omp end do
 !$omp end parallel
 
-  !  omega  grad pt Ѥ׻
+  !  omega と grad pt の内積を計算
      call dot_prod_3d( tmp4, tmp5, tmp6, tmp1, tmp2, tmp3, tmp7 )
 
 !$omp parallel default(shared)
@@ -1128,9 +1128,9 @@ subroutine HQGPV( x, y, z, phi, t_ref, cor, qgpv, undef, hx, hy, rhoc )
 
   implicit none
 
-  real, intent(in) :: x(:)  ! x κɸѿ [MKS unit]
-  real, intent(in) :: y(:)  ! y κɸѿ [MKS unit]
-  real, intent(in) :: z(:)  ! z κɸѿ [MKS unit] (Z or P)
+  real, intent(in) :: x(:)  ! x 方向の座標変数 [MKS unit]
+  real, intent(in) :: y(:)  ! y 方向の座標変数 [MKS unit]
+  real, intent(in) :: z(:)  ! z 方向の座標変数 [MKS unit] (Z or P)
   real, intent(in) :: t_ref(size(z))   ! (potential) temperature for basic [K]
                       ! p-coord : temp, z-coord : potential temp.
   real, intent(in) :: cor(size(x),size(y))  ! coriolis parameter [s-1]
@@ -1138,8 +1138,8 @@ subroutine HQGPV( x, y, z, phi, t_ref, cor, qgpv, undef, hx, hy, rhoc )
                       ! p-coord : geopotential [J/kg], z-coord : pressure [Pa].
   real, intent(inout) :: qgpv(size(x),size(y),size(z))   ! QGPV [s-1]
   real, intent(in), optional :: undef
-  real, intent(in), optional :: hx(size(x),size(y))  ! 󥰥ե
-  real, intent(in), optional :: hy(size(x),size(y))  ! 󥰥ե
+  real, intent(in), optional :: hx(size(x),size(y))  ! スケーリングファクター
+  real, intent(in), optional :: hy(size(x),size(y))  ! スケーリングファクター
   real, intent(in), optional :: rhoc(size(z))  ! basic den. for z-coord. [kg/m3]
 
   integer :: nx, ny, nz, i, j, k
